import React from 'react';

const RESPONSE_HEADERS_DEFAULT = {
    "Access-Control-Allow-Origin": "*",
    "Access-Control-Allow-Headers": "*",
    "Access-Control-Allow-Credentials": "true",
    "Access-Control-Allow-Methods": "GET,HEAD,PUT,POST,DELETE,PATCH",
    "content-type": "application/json"
};
const RESPONSE_MESSAGES = {
    200: "Success",
    204: "No Content",
    400: "Bad request",
    401: "Forbidden",
    404: "Not found",
    429: "Too many requests",
    500: "Internal Server Error"
};

/**
 * Responses
 */
const parseInput = (input) => typeof input === "string" || typeof input === "number" ? { message: input } : (input || {});
const res_200 = (input, options = null) => res(input ? parseInput(input) : RESPONSE_MESSAGES[200], options || 200);
const res_204 = (input, options = null) => res(input ? parseInput(input) : RESPONSE_MESSAGES[204], options || 204);
const res_400 = (input, options = null) => res(input ? parseInput(input) : RESPONSE_MESSAGES[400], options || 400);
const res_401 = (input, options = null) => res(input ? parseInput(input) : RESPONSE_MESSAGES[401], options || 401);
const res_404 = (input, options = null) => res(input ? parseInput(input) : RESPONSE_MESSAGES[404], options || 404);
const res_429 = (input, options = null) => res(input ? parseInput(input) : RESPONSE_MESSAGES[429], options || 429);
const res_500 = (input, options = null) => res(input ? parseInput(input) : RESPONSE_MESSAGES[500], options || 500);
const res = (input, options = {}) => {
    const data = parseInput(input);
    return new Response(JSON.stringify({ ...data }, undefined, apiker.debug ? 4 : undefined), {
        headers: apiker.responseHeaders,
        ...(Number.isInteger(options) ? { status: options } : options)
    });
};
const resRaw = (htmlContent, contentType = "text/html") => {
    const headers = apiker.responseHeaders;
    headers.set("content-type", `${contentType};charset=UTF-8`);
    return new Response(htmlContent, { headers });
};

const apikerPagesStatic = `var pages=function(e,t,a,n,r){"use strict";function l(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var s=l(e),o=l(a),i=l(n),u=l(r),c=function(){return c=Object.assign||function(e){for(var t,a=1,n=arguments.length;a<n;a++)for(var r in t=arguments[a])Object.prototype.hasOwnProperty.call(t,r)&&(e[r]=t[r]);return e},c.apply(this,arguments)};"function"==typeof SuppressedError&&SuppressedError,o.default(),i.default();var d=[{id:"login",displayName:"Login"}],m=[{id:"banUser",displayName:"Ban User"},{id:"unbanUser",displayName:"Unban User"},{id:"searchBans",displayName:"Search Bans"},{id:"sendEmail",displayName:"Send Email"},{id:"updateUser",displayName:"Update User"},{id:"deleteUser",displayName:"Delete User"}],f=function(e){var t=(void 0===e?{}:e).children;return s.default.createElement("nav",{className:"navbar navbar-expand-lg navbar-light px-3"},s.default.createElement("a",{className:"navbar-brand",href:"#"},s.default.createElement("img",{src:"data:image/svg+xml,%3c%3fxml version='1.0' encoding='UTF-8'%3f%3e%3csvg id='Layer_2' data-name='Layer 2' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 6.66 7.35'%3e %3cdefs%3e %3cstyle%3e .cls-1 %7b fill: %232e3191%3b %7d %3c/style%3e %3c/defs%3e %3cg id='Layer_23' data-name='Layer 23'%3e %3cpath class='cls-1' d='m3.2%2c0h.13l3.33%2c7.35H0L3.2%2c0Zm1.01%2c5.27l-.52-1.26c-.21-.51-.44-1.31-.44-1.31%2c0%2c0-.21.79-.43%2c1.31l-.52%2c1.26h1.92Z'/%3e %3c/g%3e%3c/svg%3e",height:"59",width:"52"})),t)},p=function(e){var t=(void 0===e?{}:e).children;return s.default.createElement("div",{className:"content mt-5"},s.default.createElement("div",{className:"container"},s.default.createElement("div",{className:"row justify-content-md-center"},s.default.createElement("div",{className:"col-lg-6"},t))))},g=function(e){var t;return(null===(t=null===globalThis||void 0===globalThis?void 0:globalThis.initializeAppHelper)||void 0===t?void 0:t.call(globalThis,e))||{}},h=function(e){var t=s.default.useState(!1),a=t[0],n=t[1],r=e.dialog,l=e.pageName,o=void 0===l?"":l,i=r||{},u=i.className,d=i.message,m=g(o).setProps;return s.default.useEffect((function(){r&&(n(!0),setTimeout((function(){n(!1)}),2e3))}),[r]),s.default.createElement("div",null,s.default.createElement("div",{className:"alert ".concat(u," mt-0 mb-0 alert-dismissible fade ").concat(a?"show":""),role:"alert"},s.default.createElement("strong",null,"Status:")," ",d,s.default.createElement("button",{type:"button",className:"btn-close",onClick:function(){m(c(c({},e),{dialog:void 0}))}})))},v={forgotPassword:'<html><head></head><body><h1>Email Reset</h1><div><p>If you received this email, it means that you\\'ve used the Reset Password feature. If so, click the following link to proceed:</p><p><a href="{resetUrl}">Reset User Email</a></p><p>If you have not initiated this request, please disregard this message. The link will expire in 5 minutes.</p></div></body></html>',verifyAccount:'<html><head></head><body><h1>Verify Account</h1><div><p>If you received this email, it means that you\\'ve created an account at {appName}. If so, click the following link to activate your account:</p><p><a href="{activateUrl}">Activate account</a></p><p>If you have not initiated this request, please disregard this message. The link will expire in 5 minutes.</p></div></body></html>'},b=function(e){var t=e.onButtonClick,a=e.onChange,n=e.buttonLabel,r=e.value;return s.default.useEffect((function(){var e=function(){var e=document.querySelector("#input-group-1 input"),t=document.querySelector("#input-group-1 button"),a=parseFloat(t.offsetWidth);e.style.maxWidth="calc(100% - ".concat(a,"px - 15px)")};window.addEventListener("resize",e),e()}),[]),s.default.createElement("div",{className:"input-group mt-2",id:"input-group-1"},s.default.createElement("input",{className:"form-control form-control-lg",id:"userEmail",type:"email",placeholder:"User Email",onChange:a,value:r}),s.default.createElement("button",{className:"btn btn-outline-secondary",type:"button",onClick:t},n))},y={login:function(e){var t=e.isSetup,a=e.pageName,n=void 0===a?"":a,r=e.csrfToken,l=void 0===r?"":r,o=g(n).setProps;return s.default.createElement("div",{className:"action-wrapper"},t&&s.default.createElement("div",{className:"alert alert-primary mb-0",role:"alert"},"Welcome to Apiker! Please setup your account in order to manage your app."),s.default.createElement("form",{className:"login-form",onSubmit:function(){var t=new FormData;Array.from(document.querySelectorAll("input")).forEach((function(e){var a=e.getAttribute("id");t.append(a,e.value)})),fetch("/admp/login",{method:"post",body:t,headers:{"X-Apiker-Csrf":l}}).then((function(e){return e.json().then((function(t){return{status:e.status,body:t}}))})).then((function(t){var a=200===t.status,n=a?void 0:e.action,r=a?"Sucess! You can now select a new action":"Failure returned by the endpoint.";o(c(c({},e),{action:n,actions:m,dialog:{className:a?"alert-primary":"alert-danger",message:r}}))})).catch((function(t){o(c(c({},e),{dialog:{className:"alert-danger",message:null==t?void 0:t.message}}))}))}},s.default.createElement("input",{className:"form-control form-control-lg mt-2",id:"email",type:"email",placeholder:"Email"}),s.default.createElement("input",{className:"form-control form-control-lg mt-2",id:"password",type:"password",placeholder:"Password"}),s.default.createElement("button",{className:"btn btn-primary mt-2 action-btn",type:"submit"},t?"Setup User":"Submit")))},banUser:function(e){var t=e.pageName,a=void 0===t?"":t,n=e.csrfToken,r=void 0===n?"":n,l=g(a).setProps;return s.default.createElement("div",{className:"action-wrapper"},s.default.createElement("form",{className:"login-form",onSubmit:function(){var t=new FormData;Array.from(document.querySelectorAll("input")).forEach((function(e){var a=e.getAttribute("id");t.append(a,e.value)})),fetch("/admp/bans",{method:"post",body:t,headers:{"X-Apiker-Csrf":r}}).then((function(e){return e.json().then((function(t){return{status:e.status,body:t}}))})).then((function(t){var a=200===t.status,n=a?"Action performed successfully":"Failure returned by the endpoint.";l(c(c({},e),{dialog:{className:a?"alert-primary":"alert-danger",message:n}}))})).catch((function(t){l(c(c({},e),{dialog:{className:"alert-danger",message:null==t?void 0:t.message}}))}))}},s.default.createElement("input",{className:"form-control form-control-lg mt-2",id:"userId",type:"text",placeholder:"User ID"}),s.default.createElement("button",{className:"btn btn-primary mt-2 action-btn",type:"submit"},"Submit")))},unbanUser:function(e){var t=e.pageName,a=void 0===t?"":t,n=e.csrfToken,r=void 0===n?"":n,l=g(a).setProps;return s.default.createElement("div",{className:"action-wrapper"},s.default.createElement("form",{className:"login-form",onSubmit:function(){var t=new FormData;Array.from(document.querySelectorAll("input")).forEach((function(e){var a=e.getAttribute("id");t.append(a,e.value)})),fetch("/admp/bans",{method:"delete",body:t,headers:{"X-Apiker-Csrf":r}}).then((function(e){return e.json().then((function(t){return{status:e.status,body:t}}))})).then((function(t){var a=200===t.status,n=a?"Action performed successfully":"Failure returned by the endpoint.";l(c(c({},e),{dialog:{className:a?"alert-primary":"alert-danger",message:n}}))})).catch((function(t){l(c(c({},e),{dialog:{className:"alert-danger",message:null==t?void 0:t.message}}))}))}},s.default.createElement("input",{className:"form-control form-control-lg mt-2",id:"userId",type:"text",placeholder:"User ID"}),s.default.createElement("button",{className:"btn btn-primary mt-2 action-btn",type:"submit"},"Submit")))},searchBans:function(e){var t=e.pageName,a=void 0===t?"":t,n=e.csrfToken,r=void 0===n?"":n,l=g(a).setProps,o=s.default.useState([]),i=o[0],u=o[1];return s.default.createElement("div",{className:"action-wrapper"},s.default.createElement("form",{className:"login-form",onSubmit:function(){var t={};Array.from(document.querySelectorAll("input")).forEach((function(e){var a=e.getAttribute("id");t[a]=e.value})),t.userId||l(c(c({},e),{dialog:{className:"alert-danger",message:"You must provide an user id"}})),fetch("/admp/bans/".concat(t.userId),{method:"get",headers:{"X-Apiker-Csrf":r}}).then((function(e){return e.json().then((function(t){return{status:e.status,body:t}}))})).then((function(t){var a=t.status,n=t.body,r=(void 0===n?{}:n).entries,s=200===a,o=(void 0===r?[]:r).map((function(e){return{time:e.time,id:e.id,clientId:e.clientId,countryCode:e.countryCode,pathname:e.pathname,issuedBy:e.issuedBy}})),i=s?"Action performed successfully":"Failure returned by the endpoint.";l(c(c({},e),{dialog:{className:s?"alert-primary":"alert-danger",message:i}})),u(o)})).catch((function(t){l(c(c({},e),{dialog:{className:"alert-danger",message:null==t?void 0:t.message}}))}))}},s.default.createElement("input",{className:"form-control form-control-lg mt-2",id:"userId",type:"text",placeholder:"User ID"}),s.default.createElement("button",{className:"btn btn-primary mt-2 action-btn",type:"submit"},"Submit")),i&&i.length?i.map((function(e){var t=e.time,a=e.id,n=e.clientId,r=e.countryCode,l=e.pathname,o=e.issuedBy;return s.default.createElement("div",{className:"results-container"},s.default.createElement("div",{className:"results-item"},s.default.createElement("ul",null,s.default.createElement("li",null,s.default.createElement("span",{className:"title"},"time")," ",s.default.createElement("span",{className:"text",title:new Date(t).toLocaleString()},new Date(t).toLocaleString())),s.default.createElement("li",null,s.default.createElement("span",{className:"title"},"id")," ",s.default.createElement("span",{className:"text",title:a},a)),s.default.createElement("li",null,s.default.createElement("span",{className:"title"},"clientId")," ",s.default.createElement("span",{className:"text",title:n},n)),s.default.createElement("li",null,s.default.createElement("span",{className:"title"},"countryCode")," ",s.default.createElement("span",{className:"text",title:r},r)),s.default.createElement("li",null,s.default.createElement("span",{className:"title"},"pathname")," ",s.default.createElement("span",{className:"text",title:l},l)),s.default.createElement("li",null,s.default.createElement("span",{className:"title"},"issuedBy")," ",s.default.createElement("span",{className:"text",title:o},o)))))})):null)},sendEmail:function(e){var t=s.default.useState(),a=t[0],n=t[1],r=e.pageName,l=void 0===r?"":r,o=e.csrfToken,i=void 0===o?"":o,u=g(l).setProps,d=s.default.createElement("div",{className:"btn-group mt-2"},s.default.createElement("button",{className:"btn btn-transparent btn-lg dropdown-toggle action-dropdown",type:"button",id:"main-dropdown","data-bs-toggle":"dropdown","aria-expanded":"false"},a||"Email template"),s.default.createElement("ul",{className:"dropdown-menu","aria-labelledby":"main-dropdown"},Object.keys(v).map((function(e){return s.default.createElement("li",{key:e},s.default.createElement("a",{className:"dropdown-item",href:"#",onClick:function(){n(e)}},e))}))));return s.default.createElement("div",{className:"action-wrapper"},s.default.createElement("div",{className:"alert alert-warning mb-0 mt-2",role:"alert"},s.default.createElement("b",null,"Note:"),' This option requires the "email" and "authRoutes" options to be enabled.'),s.default.createElement("form",{className:"login-form",onSubmit:function(){var t=new FormData;a&&(Array.from(document.querySelectorAll("input")).forEach((function(e){var a=e.getAttribute("id");t.append(a,e.value)})),t.append("template",a),fetch("/admp/email",{method:"post",body:t,headers:{"X-Apiker-Csrf":i}}).then((function(e){return e.json().then((function(t){return{status:e.status,body:t}}))})).then((function(t){var a=t.status,n=200===a||201===a,r=n?"Action performed successfully":"Failure returned by the endpoint.";u(c(c({},e),{dialog:{className:n?"alert-primary":"alert-danger",message:r}}))})).catch((function(t){u(c(c({},e),{dialog:{className:"alert-danger",message:null==t?void 0:t.message}}))})))}},s.default.createElement("input",{className:"form-control form-control-lg mt-2",id:"userEmail",type:"email",placeholder:"User Email"}),d,a?s.default.createElement("pre",{className:"m-0 mt-2"},s.default.createElement("code",null,v[a])):null,s.default.createElement("button",{className:"btn btn-primary mt-2 action-btn",type:"submit"},"Submit")))},updateUser:function(e){var t=s.default.useRef(""),a=s.default.useState(""),n=a[0],r=a[1],l=s.default.useState(""),o=l[0],i=l[1],u=e.pageName,d=void 0===u?"":u,m=e.csrfToken,f=void 0===m?"":m,p=g(d).setProps,h=function(e,t){var a;try{a=JSON.parse(e)}catch(e){}if(a){var n=JSON.stringify(a);r(n),t&&t(n)}};return console.log("partialUser",n),s.default.createElement("div",{className:"action-wrapper"},s.default.createElement("form",{className:"login-form",onSubmit:function(){if(o.trim())if(t.current&&n&&t.current!==n){var a=new FormData;Array.from(document.querySelectorAll("input")).forEach((function(e){var t=e.getAttribute("id");a.append(t,e.value)})),a.append("updatedUser",n),fetch("/admp/user",{method:"put",body:a,headers:{"X-Apiker-Csrf":f}}).then((function(e){return e.json().then((function(t){return{status:e.status,body:t}}))})).then((function(t){var a=200===t.status,n=a?"Action performed successfully":"Failure returned by the endpoint.";p(c(c({},e),{dialog:{className:a?"alert-primary":"alert-danger",message:n}}))})).catch((function(t){p(c(c({},e),{dialog:{className:"alert-danger",message:null==t?void 0:t.message}}))}))}else p(c(c({},e),{dialog:{className:"alert-danger",message:"Please fill out the fields correctly"}}));else p(c(c({},e),{dialog:{className:"alert-danger",message:"You must provide the user email"}}))}},s.default.createElement(b,{value:o,onButtonClick:function(){console.log("onUserEmailChange",o),fetch("/admp/user?"+new URLSearchParams({userEmail:o}),{method:"get",headers:{"X-Apiker-Csrf":f}}).then((function(e){return e.json().then((function(t){return{status:e.status,body:t}}))})).then((function(a){var n=a.status,r=a.body,l=(void 0===r?{}:r).partialUser;if(200===n)if(l){var s=JSON.stringify(l);h(s,(function(e){t.current=e})),p(c(c({},e),{dialog:{className:"alert-primary",message:"Action performed successfully"}}))}else p(c(c({},e),{dialog:{className:"alert-danger",message:"Endpoint error"}}));else p(c(c({},e),{dialog:{className:"alert-danger",message:"User not found!"}}));console.log(a)})).catch((function(e){console.log(e)}))},onChange:function(e){return i(e.target.value)},buttonLabel:"Find"}),n?s.default.createElement("textarea",{className:"m-0 mt-2",onChange:function(e){return h(e.target.value)},value:JSON.stringify(JSON.parse(n),null,2)}):null,s.default.createElement("button",{className:"btn btn-primary mt-2 action-btn",type:"submit"},"Submit")))},deleteUser:function(e){var t=s.default.useState(!1),a=t[0],n=t[1],r=s.default.useState(!1),l=r[0],o=r[1],i=e.pageName,u=void 0===i?"":i,d=e.csrfToken,m=void 0===d?"":d,f=g(u).setProps;return s.default.createElement("div",{className:"action-wrapper"},s.default.createElement("form",{className:"login-form",onSubmit:function(){var t;if((null===(t=document.getElementById("userEmail"))||void 0===t?void 0:t.value).trim())if(a&&l){var r=new FormData;Array.from(document.querySelectorAll("input")).forEach((function(e){var t=e.getAttribute("id");r.append(t,e.value)})),fetch("/admp/user",{method:"delete",body:r,headers:{"X-Apiker-Csrf":m}}).then((function(e){return e.json().then((function(t){return{status:e.status,body:t}}))})).then((function(t){var a=200===t.status,n=a?"Action performed successfully":"Failure returned by the endpoint.";f(c(c({},e),{dialog:{className:a?"alert-primary":"alert-danger",message:n}}))})).catch((function(t){f(c(c({},e),{dialog:{className:"alert-danger",message:null==t?void 0:t.message}}))}))}else n(!0);else f(c(c({},e),{dialog:{className:"alert-danger",message:"You must provide the user email"}}))}},s.default.createElement("input",{className:"form-control form-control-lg mt-2",id:"userEmail",type:"text",placeholder:"User Email"}),l||!a?s.default.createElement("button",{className:"btn btn-primary mt-2 action-btn",type:"submit"},"Submit"):s.default.createElement("button",{className:"btn btn-danger mt-2 action-btn",type:"button",onClick:function(){o(!0)}},"Are you sure? This cannot be undone")))}};return{AdminPanelPage:function(e){var t=e.userSignedIp,a=e.isAdminLoggedIn,n=e.action,r=e.actions,l=void 0===r?d:r,o=e.dialog,i=e.pageName,u=g(void 0===i?"":i).setProps,v=n?y[n.id]:null;a&&(l=m);var b=s.default.createElement("div",{className:"btn-group"},s.default.createElement("button",{className:"btn btn-transparent btn-lg dropdown-toggle action-dropdown",type:"button",id:"main-dropdown","data-bs-toggle":"dropdown","aria-expanded":"false"},n?n.displayName:"Select action"),s.default.createElement("ul",{className:"dropdown-menu","aria-labelledby":"main-dropdown"},l.map((function(t){var a=t.id,n=t.displayName;return s.default.createElement("li",{key:a},s.default.createElement("a",{className:"dropdown-item",href:"#",onClick:function(){return function(t){u(c(c({},e),{action:t,dialog:void 0}))}(t)}},n))}))));return s.default.createElement(s.default.Fragment,null,s.default.createElement(f,null,o&&s.default.createElement(h,c({},e))),s.default.createElement(p,null,b,v&&s.default.createElement(v,c({},e)),t&&s.default.createElement("div",{className:"signed-ip"},"Your ID: ",t)))},ReactDOM:u.default}}(React,0,(function(){}),(function(){}),ReactDOM);`;

/**
 * Tokenize input string.
 */
function lexer(str) {
    var tokens = [];
    var i = 0;
    while (i < str.length) {
        var char = str[i];
        if (char === "*" || char === "+" || char === "?") {
            tokens.push({ type: "MODIFIER", index: i, value: str[i++] });
            continue;
        }
        if (char === "\\") {
            tokens.push({ type: "ESCAPED_CHAR", index: i++, value: str[i++] });
            continue;
        }
        if (char === "{") {
            tokens.push({ type: "OPEN", index: i, value: str[i++] });
            continue;
        }
        if (char === "}") {
            tokens.push({ type: "CLOSE", index: i, value: str[i++] });
            continue;
        }
        if (char === ":") {
            var name = "";
            var j = i + 1;
            while (j < str.length) {
                var code = str.charCodeAt(j);
                if (
                // `0-9`
                (code >= 48 && code <= 57) ||
                    // `A-Z`
                    (code >= 65 && code <= 90) ||
                    // `a-z`
                    (code >= 97 && code <= 122) ||
                    // `_`
                    code === 95) {
                    name += str[j++];
                    continue;
                }
                break;
            }
            if (!name)
                throw new TypeError("Missing parameter name at ".concat(i));
            tokens.push({ type: "NAME", index: i, value: name });
            i = j;
            continue;
        }
        if (char === "(") {
            var count = 1;
            var pattern = "";
            var j = i + 1;
            if (str[j] === "?") {
                throw new TypeError("Pattern cannot start with \"?\" at ".concat(j));
            }
            while (j < str.length) {
                if (str[j] === "\\") {
                    pattern += str[j++] + str[j++];
                    continue;
                }
                if (str[j] === ")") {
                    count--;
                    if (count === 0) {
                        j++;
                        break;
                    }
                }
                else if (str[j] === "(") {
                    count++;
                    if (str[j + 1] !== "?") {
                        throw new TypeError("Capturing groups are not allowed at ".concat(j));
                    }
                }
                pattern += str[j++];
            }
            if (count)
                throw new TypeError("Unbalanced pattern at ".concat(i));
            if (!pattern)
                throw new TypeError("Missing pattern at ".concat(i));
            tokens.push({ type: "PATTERN", index: i, value: pattern });
            i = j;
            continue;
        }
        tokens.push({ type: "CHAR", index: i, value: str[i++] });
    }
    tokens.push({ type: "END", index: i, value: "" });
    return tokens;
}
/**
 * Parse a string for the raw tokens.
 */
function parse$1(str, options) {
    if (options === void 0) { options = {}; }
    var tokens = lexer(str);
    var _a = options.prefixes, prefixes = _a === void 0 ? "./" : _a;
    var defaultPattern = "[^".concat(escapeString(options.delimiter || "/#?"), "]+?");
    var result = [];
    var key = 0;
    var i = 0;
    var path = "";
    var tryConsume = function (type) {
        if (i < tokens.length && tokens[i].type === type)
            return tokens[i++].value;
    };
    var mustConsume = function (type) {
        var value = tryConsume(type);
        if (value !== undefined)
            return value;
        var _a = tokens[i], nextType = _a.type, index = _a.index;
        throw new TypeError("Unexpected ".concat(nextType, " at ").concat(index, ", expected ").concat(type));
    };
    var consumeText = function () {
        var result = "";
        var value;
        while ((value = tryConsume("CHAR") || tryConsume("ESCAPED_CHAR"))) {
            result += value;
        }
        return result;
    };
    while (i < tokens.length) {
        var char = tryConsume("CHAR");
        var name = tryConsume("NAME");
        var pattern = tryConsume("PATTERN");
        if (name || pattern) {
            var prefix = char || "";
            if (prefixes.indexOf(prefix) === -1) {
                path += prefix;
                prefix = "";
            }
            if (path) {
                result.push(path);
                path = "";
            }
            result.push({
                name: name || key++,
                prefix: prefix,
                suffix: "",
                pattern: pattern || defaultPattern,
                modifier: tryConsume("MODIFIER") || "",
            });
            continue;
        }
        var value = char || tryConsume("ESCAPED_CHAR");
        if (value) {
            path += value;
            continue;
        }
        if (path) {
            result.push(path);
            path = "";
        }
        var open = tryConsume("OPEN");
        if (open) {
            var prefix = consumeText();
            var name_1 = tryConsume("NAME") || "";
            var pattern_1 = tryConsume("PATTERN") || "";
            var suffix = consumeText();
            mustConsume("CLOSE");
            result.push({
                name: name_1 || (pattern_1 ? key++ : ""),
                pattern: name_1 && !pattern_1 ? defaultPattern : pattern_1,
                prefix: prefix,
                suffix: suffix,
                modifier: tryConsume("MODIFIER") || "",
            });
            continue;
        }
        mustConsume("END");
    }
    return result;
}
/**
 * Create path match function from `path-to-regexp` spec.
 */
function match(str, options) {
    var keys = [];
    var re = pathToRegexp(str, keys, options);
    return regexpToFunction(re, keys, options);
}
/**
 * Create a path match function from `path-to-regexp` output.
 */
function regexpToFunction(re, keys, options) {
    if (options === void 0) { options = {}; }
    var _a = options.decode, decode = _a === void 0 ? function (x) { return x; } : _a;
    return function (pathname) {
        var m = re.exec(pathname);
        if (!m)
            return false;
        var path = m[0], index = m.index;
        var params = Object.create(null);
        var _loop_1 = function (i) {
            if (m[i] === undefined)
                return "continue";
            var key = keys[i - 1];
            if (key.modifier === "*" || key.modifier === "+") {
                params[key.name] = m[i].split(key.prefix + key.suffix).map(function (value) {
                    return decode(value, key);
                });
            }
            else {
                params[key.name] = decode(m[i], key);
            }
        };
        for (var i = 1; i < m.length; i++) {
            _loop_1(i);
        }
        return { path: path, index: index, params: params };
    };
}
/**
 * Escape a regular expression string.
 */
function escapeString(str) {
    return str.replace(/([.+*?=^!:${}()[\]|/\\])/g, "\\$1");
}
/**
 * Get the flags for a regexp from the options.
 */
function flags(options) {
    return options && options.sensitive ? "" : "i";
}
/**
 * Pull out keys from a regexp.
 */
function regexpToRegexp(path, keys) {
    if (!keys)
        return path;
    var groupsRegex = /\((?:\?<(.*?)>)?(?!\?)/g;
    var index = 0;
    var execResult = groupsRegex.exec(path.source);
    while (execResult) {
        keys.push({
            // Use parenthesized substring match if available, index otherwise
            name: execResult[1] || index++,
            prefix: "",
            suffix: "",
            modifier: "",
            pattern: "",
        });
        execResult = groupsRegex.exec(path.source);
    }
    return path;
}
/**
 * Transform an array into a regexp.
 */
function arrayToRegexp(paths, keys, options) {
    var parts = paths.map(function (path) { return pathToRegexp(path, keys, options).source; });
    return new RegExp("(?:".concat(parts.join("|"), ")"), flags(options));
}
/**
 * Create a path regexp from string input.
 */
function stringToRegexp(path, keys, options) {
    return tokensToRegexp(parse$1(path, options), keys, options);
}
/**
 * Expose a function for taking tokens and returning a RegExp.
 */
function tokensToRegexp(tokens, keys, options) {
    if (options === void 0) { options = {}; }
    var _a = options.strict, strict = _a === void 0 ? false : _a, _b = options.start, start = _b === void 0 ? true : _b, _c = options.end, end = _c === void 0 ? true : _c, _d = options.encode, encode = _d === void 0 ? function (x) { return x; } : _d, _e = options.delimiter, delimiter = _e === void 0 ? "/#?" : _e, _f = options.endsWith, endsWith = _f === void 0 ? "" : _f;
    var endsWithRe = "[".concat(escapeString(endsWith), "]|$");
    var delimiterRe = "[".concat(escapeString(delimiter), "]");
    var route = start ? "^" : "";
    // Iterate over the tokens and create our regexp string.
    for (var _i = 0, tokens_1 = tokens; _i < tokens_1.length; _i++) {
        var token = tokens_1[_i];
        if (typeof token === "string") {
            route += escapeString(encode(token));
        }
        else {
            var prefix = escapeString(encode(token.prefix));
            var suffix = escapeString(encode(token.suffix));
            if (token.pattern) {
                if (keys)
                    keys.push(token);
                if (prefix || suffix) {
                    if (token.modifier === "+" || token.modifier === "*") {
                        var mod = token.modifier === "*" ? "?" : "";
                        route += "(?:".concat(prefix, "((?:").concat(token.pattern, ")(?:").concat(suffix).concat(prefix, "(?:").concat(token.pattern, "))*)").concat(suffix, ")").concat(mod);
                    }
                    else {
                        route += "(?:".concat(prefix, "(").concat(token.pattern, ")").concat(suffix, ")").concat(token.modifier);
                    }
                }
                else {
                    if (token.modifier === "+" || token.modifier === "*") {
                        route += "((?:".concat(token.pattern, ")").concat(token.modifier, ")");
                    }
                    else {
                        route += "(".concat(token.pattern, ")").concat(token.modifier);
                    }
                }
            }
            else {
                route += "(?:".concat(prefix).concat(suffix, ")").concat(token.modifier);
            }
        }
    }
    if (end) {
        if (!strict)
            route += "".concat(delimiterRe, "?");
        route += !options.endsWith ? "$" : "(?=".concat(endsWithRe, ")");
    }
    else {
        var endToken = tokens[tokens.length - 1];
        var isEndDelimited = typeof endToken === "string"
            ? delimiterRe.indexOf(endToken[endToken.length - 1]) > -1
            : endToken === undefined;
        if (!strict) {
            route += "(?:".concat(delimiterRe, "(?=").concat(endsWithRe, "))?");
        }
        if (!isEndDelimited) {
            route += "(?=".concat(delimiterRe, "|").concat(endsWithRe, ")");
        }
    }
    return new RegExp(route, flags(options));
}
/**
 * Normalize the given path string, returning a regular expression.
 *
 * An empty array can be passed in for the keys, which will hold the
 * placeholder key descriptions. For example, using `/user/:id`, `keys` will
 * contain `[{ name: 'id', delimiter: '/', optional: false, repeat: false }]`.
 */
function pathToRegexp(path, keys, options) {
    if (path instanceof RegExp)
        return regexpToRegexp(path, keys);
    if (Array.isArray(path))
        return arrayToRegexp(path, keys, options);
    return stringToRegexp(path, keys, options);
}

const getStateMethods = (defaultObjectName, matches) => (objectName = defaultObjectName, objectId) => {
    /**
     * If there's an existing object state mapping, using that as default
     */
    if (!objectId) {
        objectId = parseObjectStateMapping(apiker.objectStateMapping[objectName], matches) || OBMT.DEFAULT;
    }
    const obj = getEnvObject(objectName, objectId);
    const callback = (operationName) => {
        if (apiker.debug) {
            console.log("APIKER ::", operationName, objectName, objectId);
        }
    };
    return {
        get: (obj ? getObjectState(obj, () => callback("get")) : () => { }),
        put: (obj ? putObjectState(obj, () => callback("put")) : () => { }),
        delete: (obj ? deleteObjectState(obj, () => callback("delete")) : () => { }),
        deleteAll: (obj ? deleteAllObjectState(obj, () => callback("deleteAll")) : () => { }),
        list: (obj ? listObjectState(obj, () => callback("list")) : () => { }),
    };
};
const parseObjectStateMapping = (objectStateMapping, matches) => {
    let value = objectStateMapping;
    if (objectStateMapping === OBMT.SIGNEDIP) {
        value = getSignedIp();
    }
    else if (objectStateMapping === OBMT.CLIENTID) {
        value = getClientId();
    }
    else if (objectStateMapping === OBMT.IP) {
        value = getRawIp();
    }
    else if (!!objectStateMapping) {
        // If the mapping still hasn't been matched, matching it with one of the route parameters 
        value = matches?.params[objectStateMapping] || objectStateMapping;
    }
    /**
     * Adding mapping to headers for debug purposes
     */
    if (apiker.debug) {
        console.log("objectStateMapping", objectStateMapping);
        console.log("StateMappingValue", value);
    }
    return value;
};
const deleteObjectState = (obj, callback) => async (propertyName) => {
    const result = await obj.fetch("/delete", {
        method: "POST",
        body: JSON.stringify({
            propertyName
        }),
        headers: {
            "Content-Type": "application/json"
        },
    });
    const body = await result.text();
    const parsedBody = JSON.parse(body || null);
    if (callback) {
        callback();
    }
    if (apiker.debug) {
        console.log('deleteObjectState', propertyName, parsedBody);
    }
    return parsedBody;
};
const deleteAllObjectState = (obj, callback) => async () => {
    const result = await obj.fetch("/deleteall", {
        method: "POST"
    });
    const body = await result.text();
    const parsedBody = JSON.parse(body || null);
    if (callback) {
        callback();
    }
    if (apiker.debug) {
        console.log('deleteAllObjectState', parsedBody);
    }
    return parsedBody;
};
const getObjectState = (obj, callback) => async (propertyName) => {
    const result = await obj.fetch("/get", {
        method: "POST",
        body: JSON.stringify({
            propertyName
        }),
        headers: {
            "Content-Type": "application/json"
        },
    });
    const body = await result.text();
    const parsedBody = JSON.parse(body || null);
    if (callback) {
        callback();
    }
    if (apiker.debug) {
        console.log('getObjectState', propertyName, parsedBody);
    }
    return parsedBody;
};
const listObjectState = (obj, callback) => async (payload) => {
    const result = await obj.fetch("/list", {
        method: "POST",
        body: payload ? JSON.stringify(payload) : "",
        headers: {
            "Content-Type": "application/json"
        },
    });
    const body = await result.text();
    const parsedBody = JSON.parse(body || null);
    if (callback) {
        callback();
    }
    if (apiker.debug && !payload?.prefix?.includes("firewall")) {
        console.log('listObjectState', payload, parsedBody);
    }
    return parsedBody;
};
const putObjectState = (obj, callback) => async (payload) => {
    const result = await obj.fetch("/put", {
        method: "POST",
        body: JSON.stringify(payload),
        headers: {
            "Content-Type": "application/json"
        },
    });
    const body = await result.text();
    const parsedBody = JSON.parse(body || null);
    if (callback) {
        callback();
    }
    if (apiker.debug) {
        console.log('putObjectState', payload, parsedBody);
    }
    return JSON.parse(body || null);
};
const getEnvObject = (objectName, objectId) => {
    const id = apiker.env[objectName]?.idFromName(objectId);
    const obj = apiker.env[objectName]?.get(id);
    return obj;
};

const REQUEST_LIMIT_AMOUNT_PER_HOUR = 50;

const addUniqueLogEntry = async (prefix, additionalParams = {}, objectName = OBN.LOGS, signedIp = undefined, clientId = undefined) => {
    const entries = await getUserLogEntries(prefix, 1, objectName, signedIp);
    if (entries?.length) {
        return;
    }
    await addLogEntry(prefix, additionalParams, objectName, signedIp, clientId);
};
const addLogEntry = async (prefix, additionalParams = {}, objectName = OBN.LOGS, signedIp = undefined, clientId = undefined) => {
    if (apiker.objects.includes(objectName)) {
        const { state } = apiker.requestParams;
        const { objectId = null } = additionalParams;
        const propertyName = getUserLogPropertyName(prefix, signedIp) + Date.now();
        const logParams = getLogParams(propertyName, signedIp, clientId, additionalParams);
        await state(objectName, objectId).put({ [propertyName]: logParams });
    }
};
const getLogParams = (propertyName, signedIp = getSignedIp(), clientId = getClientId(), additionalParams = {}) => {
    const { headers, request } = apiker.requestParams;
    const countryCode = headers.get("CF-IPCountry");
    const url = new URL(request.url);
    const pathname = url.pathname;
    return {
        propertyName,
        time: Date.now(),
        id: signedIp,
        clientId,
        countryCode,
        pathname,
        ...additionalParams
    };
};
const getUserLogPropertyName = (prefix, signedIp = getSignedIp()) => {
    const propertyName = `${prefix}:${signedIp}`;
    return propertyName;
};
const getUserLogEntries = async (prefix, limit = 10, objectName = OBN.LOGS, signedIp = undefined) => {
    const propertyName = getUserLogPropertyName(prefix, signedIp);
    return getLogEntries(propertyName, limit, objectName);
};
const getLogEntries = async (prefix, limit = 10, objectName = OBN.LOGS) => {
    const { state } = apiker.requestParams;
    const payload = {
        prefix,
        reverse: true,
        noCache: objectName !== OBN.LOGS,
    };
    if (limit) {
        payload.limit = limit;
    }
    const entries = await state(objectName).list(payload);
    return Object.values(entries);
};
const deleteAllLogsInObject = async (objectName, signedIp) => {
    const { state } = apiker.requestParams;
    return await state(objectName, signedIp).deleteAll();
};
const deleteUserLogEntries = async (prefix, objectName = OBN.LOGS, signedIp = undefined) => {
    const userPrefix = getUserLogPropertyName(prefix, signedIp);
    return await deleteLogEntries(userPrefix, objectName);
};
const deleteLogEntries = async (prefix, objectName = OBN.LOGS) => {
    const { state } = apiker.requestParams;
    const entries = await getLogEntries(prefix, null, objectName);
    const promises = entries.map(({ propertyName }) => state(objectName).delete(propertyName));
    return Promise.all(promises);
};
const getAllLogEntries = async (objectName = OBN.LOGS, limit = null, objectId) => {
    const { state } = apiker.requestParams;
    const payload = {
        reverse: true,
        noCache: objectName !== OBN.LOGS
    };
    if (limit) {
        payload.limit = limit;
    }
    const entries = await state(objectName, objectId).list(payload);
    return Object.values(entries);
};

const hourInMs = 3600000;
const rateLimitRequest = async (prefix, params, handlerFn, limit = REQUEST_LIMIT_AMOUNT_PER_HOUR, timeLapse = hourInMs, onLimitReached = res_429) => {
    if (apiker.objects.includes(OBN.RATELIMIT)) {
        const { rateLimitReached, requestCount } = await isRateLimitReached(prefix, limit, timeLapse);
        const rateLimitRemaining = limit - requestCount;
        apiker.responseHeaders.append("X-RateLimit-Limit", limit.toString());
        apiker.responseHeaders.append("X-RateLimit-Remaining", rateLimitRemaining.toString());
        if (rateLimitReached) {
            return onLimitReached();
        }
        else {
            await addLogEntry(prefix, {}, OBN.RATELIMIT);
        }
        /**
         * Handle RateLimit purging
         * TODO: This relies on the common object. To be rewritten
         */
        // const lastRateLimitPurge = await state().get("lastRateLimitPurge");
        // if(!lastRateLimitPurge){
        //     state().put({ lastRateLimitPurge: Date.now() });
        // } else {
        //     if(Date.now() - lastRateLimitPurge >= hourInMs){
        //         state(OBN.RATELIMIT).deleteAll();
        //         state().put({ lastRateLimitPurge: Date.now() });
        //     }
        // }
    }
    if (handlerFn) {
        return handlerFn(params);
    }
};
const isRateLimitReached = async (prefix, limit, timeLapse) => {
    const requestValues = await getUserLogEntries(prefix, limit, OBN.RATELIMIT);
    const requestTimes = requestValues.map(requestValue => (Number.isInteger(requestValue)) ? requestValue : requestValue.time);
    const requestCount = requestTimes.filter(value => {
        return (value && Date.now() - value < timeLapse);
    }).length;
    const earliestValue = requestTimes[limit - 1];
    return {
        rateLimitReached: earliestValue && Date.now() - earliestValue < timeLapse,
        requestCount
    };
};

const FIREWALL_ENDPOINT = "https://api.cloudflare.com/client/v4/user/firewall/access_rules/rules";
const FIREWALL_REQUESTS_MINUTE = 100;
const FIREWALL_RATELIMIT_PREFIX = 'firewall';

const firewallBanIP = async (ip) => {
    if (!ip) {
        return;
    }
    if (!apiker.env.CLOUDFLARE_WAF_KEY) {
        throw new Error("CLOUDFLARE_WAF_KEY must be defined in the env when using firewall: true. Please consult the documentation");
    }
    await fetch(FIREWALL_ENDPOINT, {
        method: "POST",
        body: JSON.stringify({
            mode: "block",
            configuration: { target: "ip", value: ip },
            notes: `Banned by Apiker. id: ${getSignedIp()}`
        }),
        headers: {
            "Content-Type": "application/json",
            Authorization: `Bearer ${apiker.env.CLOUDFLARE_WAF_KEY}`
        },
    });
};
const getFirewallBannedEntryId = async (ip) => {
    if (!ip) {
        return "";
    }
    if (!apiker.env.CLOUDFLARE_WAF_KEY) {
        throw new Error("CLOUDFLARE_WAF_KEY must be defined in the env when using firewall: true. Please consult the documentation");
    }
    const result = await fetch(FIREWALL_ENDPOINT + new URLSearchParams({
        mode: "block",
        "configuration.target": "ip",
        "configuration.value": ip
    }), {
        method: "GET",
        headers: {
            Authorization: `Bearer ${apiker.env.CLOUDFLARE_WAF_KEY}`
        },
    });
    return result[0].id;
};
const firewallUnbanIP = async (ip) => {
    if (!ip) {
        return;
    }
    if (!apiker.env.CLOUDFLARE_WAF_KEY) {
        throw new Error("CLOUDFLARE_WAF_KEY must be defined in the env when using firewall: true. Please consult the documentation");
    }
    const entryId = await getFirewallBannedEntryId(ip);
    if (!entryId) {
        return;
    }
    const result = await fetch(`${FIREWALL_ENDPOINT}/${entryId}`, {
        method: "DELETE",
        headers: {
            Authorization: `Bearer ${apiker.env.CLOUDFLARE_WAF_KEY}`
        },
    });
    return result;
};

const firewallMiddleware = (params) => {
    const { headers } = apiker.requestParams;
    const ip = headers.get("CF-Connecting-IP");
    const minuteInMs = 60000;
    const limitRequestsPerMinute = typeof apiker.firewall === "object" ? apiker.firewall.limitRequestsPerMinute : null;
    return rateLimitRequest(FIREWALL_RATELIMIT_PREFIX, params, undefined, limitRequestsPerMinute || FIREWALL_REQUESTS_MINUTE, minuteInMs, async () => {
        const user = await getCurrentUser();
        if (user?.role !== "admin") {
            await banEntity(getSignedIp());
            await firewallBanIP(ip);
            // Since we've banned the user, we can delete all related rate limit entries
            const { state } = apiker.requestParams;
            state(OBN.RATELIMIT).deleteAll();
            return res_429();
        }
    });
};

const forwardToMiddleware = async (params, middlewares = []) => {
    try {
        for (let index = 0; index < middlewares.length; index++) {
            const middleware = middlewares[index];
            const response = await middleware(params);
            if (response) {
                return response;
            }
        }
        return res_204();
    }
    catch (e) {
        return new Response(e.message);
    }
};

const TIMINGS = {
    REQUEST_START: "requestStart"
};

const measureTiming = (timingName) => {
    const time = Date.now();
    apiker.timings[timingName] = time;
    return time;
};
const elapsedSinceRequestStart = () => {
    return Date.now() - apiker.timings[TIMINGS.REQUEST_START];
};

const bansMiddleware = async () => {
    if (await isEntityBanned(getSignedIp())) {
        return res_401();
    }
};

/**
 * Handles incoming Cloudflare Worker requests
 */
const handleEntryRequest = async (request, env) => {
    measureTiming(TIMINGS.REQUEST_START);
    try {
        apiker.setProps({ env });
        apiker.responseHeaders = new Headers(RESPONSE_HEADERS_DEFAULT);
        apiker.responseParams = new ResponseParams();
        const url = new URL(request.url);
        const { pathname } = url;
        let handlerFn = () => res_404();
        const body = await readRequestBody(request);
        const headers = request.headers;
        let params = { request, body, headers };
        /**
         * Check if path matches with a defined route
         */
        Object.keys(apiker.routes).some((routeName) => {
            const fn = match(routeName, { decode: decodeURIComponent });
            const matches = fn(pathname);
            if (matches) {
                const handler = apiker.routes[routeName];
                if (typeof handler === "function") {
                    handlerFn = handler;
                }
                else if (typeof handler === "string") {
                    const [handlerClass, handlerMethod] = handler.split(".");
                    handlerFn = (new apiker.controllers[handlerClass]())[handlerMethod];
                }
                const state = getStateMethods(apiker.defaultObjectName, matches);
                params = { ...params, matches, state };
            }
            else {
                const state = getStateMethods(apiker.defaultObjectName);
                params = { ...params, state };
            }
            return !!matches;
        });
        apiker.requestParams = params;
        /**
         * Middleware
         */
        const middlewares = [];
        /** Apiker firewall bans */
        if (apiker.firewall) {
            middlewares.push(firewallMiddleware);
        }
        /** Bans */
        middlewares.push(bansMiddleware);
        /** Handler */
        middlewares.push(handlerFn);
        return forwardToMiddleware(params, middlewares);
    }
    catch (e) {
        return new Response(e.message);
    }
};
const readRequestBody = async (request) => {
    let resBody;
    try {
        const contentType = request.headers.get("content-type") || "";
        if (contentType.includes("application/json")) {
            const resText = await request.text();
            resBody = resText ? JSON.parse(resText) : null;
        }
        else if (contentType.includes("application/text")) {
            resBody = request.text();
        }
        else if (contentType.includes("text/html")) {
            resBody = request.text();
        }
        else if (contentType.includes("form")) {
            const formData = await request.formData();
            const body = Object.fromEntries(formData);
            resBody = body || {};
        }
        else {
            const textContent = await request.text();
            resBody = textContent || null;
        }
    }
    catch (e) {
        console.error("ERR readRequestBody", resBody);
        throw new Error("An exception occurred while parsing the request body");
    }
    return resBody;
};

class ObjectBase {
    state;
    constructor(state) {
        this.state = state;
    }
    fetch = async (request) => {
        const url = new URL(request.url);
        const { pathname } = url;
        const requestBody = await readRequestBody(request);
        if (pathname.startsWith("/get")) {
            return new Response(JSON.stringify(await this.state.storage.get(requestBody.propertyName)));
        }
        else if (pathname.startsWith("/put")) {
            await Promise.all(Object.keys(requestBody).map(propertyName => this.state.storage.put(propertyName, requestBody[propertyName])));
            return res("Success");
        }
        else if (pathname.startsWith("/deleteall")) {
            await this.state.storage.deleteAll();
            return res("Success");
        }
        else if (pathname.startsWith("/delete")) {
            await this.state.storage.delete(requestBody.propertyName);
            return res("Success");
        }
        else if (pathname.startsWith("/list")) {
            const resList = Object.fromEntries(await this.state.storage.list(requestBody));
            const resJson = JSON.stringify(resList);
            return new Response(resJson);
        }
        else {
            return res_404();
        }
    };
}

const OBN = {
    COMMON: "Common",
    USERS: "Users",
    EMAILTOUUID: "EmailToUUID",
    RATELIMIT: "RateLimit",
    LOGS: "Logs",
    BANS: "Bans"
};
const OBMT = {
    DEFAULT: "default",
    SIGNEDIP: "signedIp",
    CLIENTID: "clientId",
    IP: "ip"
};

const MIN_STR_LEN = 5;
const MAX_STR_LEN = 20;

const isEmail = (email) => {
    return !!email && isRequiredLength(email, 3, 50) && /\w+([-+.']\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*/.test(email);
};
const isRequiredLength = (str, minLegth = MIN_STR_LEN, maxLength = MAX_STR_LEN) => {
    return !!str && str.length >= minLegth && str.length <= maxLength;
};

const AUTH_TOKEN_DURATION_MINS_DEFAULT = 30;
const REGISTER_REQUEST_LIMIT_AMOUNT_PER_HOUR = 3;
const AUTH_PREFIX = "auth";
const AUTH_REGISTER_PREFIX = "auth-register";
const AUTH_ERRORS = {
    USER_EXISTS: "User already exists",
    ID_GEN_ERROR: "Error generating an user Id"
};

var cookie = {};

/*!
 * cookie
 * Copyright(c) 2012-2014 Roman Shtylman
 * Copyright(c) 2015 Douglas Christopher Wilson
 * MIT Licensed
 */

/**
 * Module exports.
 * @public
 */

var parse_1 = cookie.parse = parse;
cookie.serialize = serialize;

/**
 * Module variables.
 * @private
 */

var decode = decodeURIComponent;
var encode = encodeURIComponent;

/**
 * RegExp to match field-content in RFC 7230 sec 3.2
 *
 * field-content = field-vchar [ 1*( SP / HTAB ) field-vchar ]
 * field-vchar   = VCHAR / obs-text
 * obs-text      = %x80-FF
 */

var fieldContentRegExp = /^[\u0009\u0020-\u007e\u0080-\u00ff]+$/;

/**
 * Parse a cookie header.
 *
 * Parse the given cookie header string into an object
 * The object has the various cookies as keys(names) => values
 *
 * @param {string} str
 * @param {object} [options]
 * @return {object}
 * @public
 */

function parse(str, options) {
  if (typeof str !== 'string') {
    throw new TypeError('argument str must be a string');
  }

  var obj = {};
  var opt = options || {};
  var pairs = str.split(';');
  var dec = opt.decode || decode;

  for (var i = 0; i < pairs.length; i++) {
    var pair = pairs[i];
    var index = pair.indexOf('=');

    // skip things that don't look like key=value
    if (index < 0) {
      continue;
    }

    var key = pair.substring(0, index).trim();

    // only assign once
    if (undefined == obj[key]) {
      var val = pair.substring(index + 1, pair.length).trim();

      // quoted values
      if (val[0] === '"') {
        val = val.slice(1, -1);
      }

      obj[key] = tryDecode(val, dec);
    }
  }

  return obj;
}

/**
 * Serialize data into a cookie header.
 *
 * Serialize the a name value pair into a cookie string suitable for
 * http headers. An optional options object specified cookie parameters.
 *
 * serialize('foo', 'bar', { httpOnly: true })
 *   => "foo=bar; httpOnly"
 *
 * @param {string} name
 * @param {string} val
 * @param {object} [options]
 * @return {string}
 * @public
 */

function serialize(name, val, options) {
  var opt = options || {};
  var enc = opt.encode || encode;

  if (typeof enc !== 'function') {
    throw new TypeError('option encode is invalid');
  }

  if (!fieldContentRegExp.test(name)) {
    throw new TypeError('argument name is invalid');
  }

  var value = enc(val);

  if (value && !fieldContentRegExp.test(value)) {
    throw new TypeError('argument val is invalid');
  }

  var str = name + '=' + value;

  if (null != opt.maxAge) {
    var maxAge = opt.maxAge - 0;

    if (isNaN(maxAge) || !isFinite(maxAge)) {
      throw new TypeError('option maxAge is invalid')
    }

    str += '; Max-Age=' + Math.floor(maxAge);
  }

  if (opt.domain) {
    if (!fieldContentRegExp.test(opt.domain)) {
      throw new TypeError('option domain is invalid');
    }

    str += '; Domain=' + opt.domain;
  }

  if (opt.path) {
    if (!fieldContentRegExp.test(opt.path)) {
      throw new TypeError('option path is invalid');
    }

    str += '; Path=' + opt.path;
  }

  if (opt.expires) {
    if (typeof opt.expires.toUTCString !== 'function') {
      throw new TypeError('option expires is invalid');
    }

    str += '; Expires=' + opt.expires.toUTCString();
  }

  if (opt.httpOnly) {
    str += '; HttpOnly';
  }

  if (opt.secure) {
    str += '; Secure';
  }

  if (opt.sameSite) {
    var sameSite = typeof opt.sameSite === 'string'
      ? opt.sameSite.toLowerCase() : opt.sameSite;

    switch (sameSite) {
      case true:
        str += '; SameSite=Strict';
        break;
      case 'lax':
        str += '; SameSite=Lax';
        break;
      case 'strict':
        str += '; SameSite=Strict';
        break;
      case 'none':
        str += '; SameSite=None';
        break;
      default:
        throw new TypeError('option sameSite is invalid');
    }
  }

  return str;
}

/**
 * Try decoding a string using a decoding function.
 *
 * @param {string} str
 * @param {function} decode
 * @private
 */

function tryDecode(str, decode) {
  try {
    return decode(str);
  } catch (e) {
    return str;
  }
}

/**
 * Crypto-js, amended to work with Cloudflare Workers
 * Uses the native crypto.getRandomValues() instead of requiring the crypto node package
 * https://github.com/brix/crypto-js
 */
function cryptojs(){return function(){var t,e,r,i,n,o,s,c,a,h,l,f,u,d,p,_,v,y,g,B,w,k,S,m,x,b,H,z,A,C,D,R,E,M,F,P,W,O,U,I,K,X,j,L,N,T,Z,q,G,V,$,J,Q,Y,tt,et,rt,it,nt,ot,st,ct,at,ht,lt,ft,ut,dt,pt,_t,vt,yt,gt,Bt,wt,kt,St,mt=mt||function(t){var e=Object.create||function(t){var e;return r.prototype=t,e=new r,r.prototype=null,e;};function r(){}var i={},n=i.lib={},o=n.Base={extend:function(t){var r=e(this);return t&&r.mixIn(t),r.hasOwnProperty("init")&&this.init!==r.init||(r.init=function(){r.$super.init.apply(this,arguments);}),(r.init.prototype=r).$super=this,r;},create:function(){var t=this.extend();return t.init.apply(t,arguments),t;},init:function(){},mixIn:function(t){for(var e in t)t.hasOwnProperty(e)&&(this[e]=t[e]);t.hasOwnProperty("toString")&&(this.toString=t.toString);},clone:function(){return this.init.prototype.extend(this);}},s=n.WordArray=o.extend({init:function(t,e){t=this.words=t||[],this.sigBytes=null!=e?e:4*t.length;},toString:function(t){return (t||a).stringify(this);},concat:function(t){var e=this.words,r=t.words,i=this.sigBytes,n=t.sigBytes;if(this.clamp(),i%4)for(var o=0;o<n;o++){var s=r[o>>>2]>>>24-o%4*8&255;e[i+o>>>2]|=s<<24-(i+o)%4*8;}else for(o=0;o<n;o+=4)e[i+o>>>2]=r[o>>>2];return this.sigBytes+=n,this;},clamp:function(){var e=this.words,r=this.sigBytes;e[r>>>2]&=4294967295<<32-r%4*8,e.length=t.ceil(r/4);},clone:function(){var t=o.clone.call(this);return t.words=this.words.slice(0),t;},random:function(t){for(var e=[],r=0;r<t;r+=4)e.push(crypto.getRandomValues(new Uint32Array(1))[0]);return new s.init(e,t);}}),c=i.enc={},a=c.Hex={stringify:function(t){for(var e=t.words,r=t.sigBytes,i=[],n=0;n<r;n++){var o=e[n>>>2]>>>24-n%4*8&255;i.push((o>>>4).toString(16)),i.push((15&o).toString(16));}return i.join("");},parse:function(t){for(var e=t.length,r=[],i=0;i<e;i+=2)r[i>>>3]|=parseInt(t.substr(i,2),16)<<24-i%8*4;return new s.init(r,e/2);}},h=c.Latin1={stringify:function(t){for(var e=t.words,r=t.sigBytes,i=[],n=0;n<r;n++){var o=e[n>>>2]>>>24-n%4*8&255;i.push(String.fromCharCode(o));}return i.join("");},parse:function(t){for(var e=t.length,r=[],i=0;i<e;i++)r[i>>>2]|=(255&t.charCodeAt(i))<<24-i%4*8;return new s.init(r,e);}},l=c.Utf8={stringify:function(t){try{return decodeURIComponent(escape(h.stringify(t)));}catch(t){throw new Error("Malformed UTF-8 data");}},parse:function(t){return h.parse(unescape(encodeURIComponent(t)));}},f=n.BufferedBlockAlgorithm=o.extend({reset:function(){this._data=new s.init,this._nDataBytes=0;},_append:function(t){"string"==typeof t&&(t=l.parse(t)),this._data.concat(t),this._nDataBytes+=t.sigBytes;},_process:function(e){var r,i=this._data,n=i.words,o=i.sigBytes,c=this.blockSize,a=o/(4*c),h=(a=e?t.ceil(a):t.max((0|a)-this._minBufferSize,0))*c,l=t.min(4*h,o);if(h){for(var f=0;f<h;f+=c)this._doProcessBlock(n,f);r=n.splice(0,h),i.sigBytes-=l;}return new s.init(r,l);},clone:function(){var t=o.clone.call(this);return t._data=this._data.clone(),t;},_minBufferSize:0}),u=(n.Hasher=f.extend({cfg:o.extend(),init:function(t){this.cfg=this.cfg.extend(t),this.reset();},reset:function(){f.reset.call(this),this._doReset();},update:function(t){return this._append(t),this._process(),this;},finalize:function(t){return t&&this._append(t),this._doFinalize();},blockSize:16,_createHelper:function(t){return function(e,r){return new t.init(r).finalize(e);};},_createHmacHelper:function(t){return function(e,r){return new u.HMAC.init(t,r).finalize(e);};}}),i.algo={});return i;}(Math);function xt(t,e,r){return t^e^r;}function bt(t,e,r){return t&e|~t&r;}function Ht(t,e,r){return (t|~e)^r;}function zt(t,e,r){return t&r|e&~r;}function At(t,e,r){return t^(e|~r);}function Ct(t,e){return t<<e|t>>>32-e;}function Dt(t,e,r,i){var n,o=this._iv;o?(n=o.slice(0),this._iv=void 0):n=this._prevBlock,i.encryptBlock(n,0);for(var s=0;s<r;s++)t[e+s]^=n[s];}function Rt(t){if(255==(t>>24&255)){var e=t>>16&255,r=t>>8&255,i=255&t;255===e?(e=0,255===r?(r=0,255===i?i=0:++i):++r):++e,t=0,t+=e<<16,t+=r<<8,t+=i;}else t+=1<<24;return t;}function Et(){for(var t=this._X,e=this._C,r=0;r<8;r++)ft[r]=e[r];for(e[0]=e[0]+1295307597+this._b|0,e[1]=e[1]+3545052371+(e[0]>>>0<ft[0]>>>0?1:0)|0,e[2]=e[2]+886263092+(e[1]>>>0<ft[1]>>>0?1:0)|0,e[3]=e[3]+1295307597+(e[2]>>>0<ft[2]>>>0?1:0)|0,e[4]=e[4]+3545052371+(e[3]>>>0<ft[3]>>>0?1:0)|0,e[5]=e[5]+886263092+(e[4]>>>0<ft[4]>>>0?1:0)|0,e[6]=e[6]+1295307597+(e[5]>>>0<ft[5]>>>0?1:0)|0,e[7]=e[7]+3545052371+(e[6]>>>0<ft[6]>>>0?1:0)|0,this._b=e[7]>>>0<ft[7]>>>0?1:0,r=0;r<8;r++){var i=t[r]+e[r],n=65535&i,o=i>>>16,s=((n*n>>>17)+n*o>>>15)+o*o,c=((4294901760&i)*i|0)+((65535&i)*i|0);ut[r]=s^c;}t[0]=ut[0]+(ut[7]<<16|ut[7]>>>16)+(ut[6]<<16|ut[6]>>>16)|0,t[1]=ut[1]+(ut[0]<<8|ut[0]>>>24)+ut[7]|0,t[2]=ut[2]+(ut[1]<<16|ut[1]>>>16)+(ut[0]<<16|ut[0]>>>16)|0,t[3]=ut[3]+(ut[2]<<8|ut[2]>>>24)+ut[1]|0,t[4]=ut[4]+(ut[3]<<16|ut[3]>>>16)+(ut[2]<<16|ut[2]>>>16)|0,t[5]=ut[5]+(ut[4]<<8|ut[4]>>>24)+ut[3]|0,t[6]=ut[6]+(ut[5]<<16|ut[5]>>>16)+(ut[4]<<16|ut[4]>>>16)|0,t[7]=ut[7]+(ut[6]<<8|ut[6]>>>24)+ut[5]|0;}function Mt(){for(var t=this._X,e=this._C,r=0;r<8;r++)wt[r]=e[r];for(e[0]=e[0]+1295307597+this._b|0,e[1]=e[1]+3545052371+(e[0]>>>0<wt[0]>>>0?1:0)|0,e[2]=e[2]+886263092+(e[1]>>>0<wt[1]>>>0?1:0)|0,e[3]=e[3]+1295307597+(e[2]>>>0<wt[2]>>>0?1:0)|0,e[4]=e[4]+3545052371+(e[3]>>>0<wt[3]>>>0?1:0)|0,e[5]=e[5]+886263092+(e[4]>>>0<wt[4]>>>0?1:0)|0,e[6]=e[6]+1295307597+(e[5]>>>0<wt[5]>>>0?1:0)|0,e[7]=e[7]+3545052371+(e[6]>>>0<wt[6]>>>0?1:0)|0,this._b=e[7]>>>0<wt[7]>>>0?1:0,r=0;r<8;r++){var i=t[r]+e[r],n=65535&i,o=i>>>16,s=((n*n>>>17)+n*o>>>15)+o*o,c=((4294901760&i)*i|0)+((65535&i)*i|0);kt[r]=s^c;}t[0]=kt[0]+(kt[7]<<16|kt[7]>>>16)+(kt[6]<<16|kt[6]>>>16)|0,t[1]=kt[1]+(kt[0]<<8|kt[0]>>>24)+kt[7]|0,t[2]=kt[2]+(kt[1]<<16|kt[1]>>>16)+(kt[0]<<16|kt[0]>>>16)|0,t[3]=kt[3]+(kt[2]<<8|kt[2]>>>24)+kt[1]|0,t[4]=kt[4]+(kt[3]<<16|kt[3]>>>16)+(kt[2]<<16|kt[2]>>>16)|0,t[5]=kt[5]+(kt[4]<<8|kt[4]>>>24)+kt[3]|0,t[6]=kt[6]+(kt[5]<<16|kt[5]>>>16)+(kt[4]<<16|kt[4]>>>16)|0,t[7]=kt[7]+(kt[6]<<8|kt[6]>>>24)+kt[5]|0;}return t=mt.lib.WordArray,mt.enc.Base64={stringify:function(t){var e=t.words,r=t.sigBytes,i=this._map;t.clamp();for(var n=[],o=0;o<r;o+=3)for(var s=(e[o>>>2]>>>24-o%4*8&255)<<16|(e[o+1>>>2]>>>24-(o+1)%4*8&255)<<8|e[o+2>>>2]>>>24-(o+2)%4*8&255,c=0;c<4&&o+.75*c<r;c++)n.push(i.charAt(s>>>6*(3-c)&63));var a=i.charAt(64);if(a)for(;n.length%4;)n.push(a);return n.join("");},parse:function(e){var r=e.length,i=this._map,n=this._reverseMap;if(!n){n=this._reverseMap=[];for(var o=0;o<i.length;o++)n[i.charCodeAt(o)]=o;}var s=i.charAt(64);if(s){var c=e.indexOf(s);-1!==c&&(r=c);}return function(e,r,i){for(var n=[],o=0,s=0;s<r;s++)if(s%4){var c=i[e.charCodeAt(s-1)]<<s%4*2|i[e.charCodeAt(s)]>>>6-s%4*2;n[o>>>2]|=c<<24-o%4*8,o++;}return t.create(n,o);}(e,r,n);},_map:"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="},function(t){var e=mt,r=e.lib,i=r.WordArray,n=r.Hasher,o=e.algo,s=[];!function(){for(var e=0;e<64;e++)s[e]=4294967296*t.abs(t.sin(e+1))|0;}();var c=o.MD5=n.extend({_doReset:function(){this._hash=new i.init([1732584193,4023233417,2562383102,271733878]);},_doProcessBlock:function(t,e){for(var r=0;r<16;r++){var i=e+r,n=t[i];t[i]=16711935&(n<<8|n>>>24)|4278255360&(n<<24|n>>>8);}var o=this._hash.words,c=t[e+0],u=t[e+1],d=t[e+2],p=t[e+3],_=t[e+4],v=t[e+5],y=t[e+6],g=t[e+7],B=t[e+8],w=t[e+9],k=t[e+10],S=t[e+11],m=t[e+12],x=t[e+13],b=t[e+14],H=t[e+15],z=o[0],A=o[1],C=o[2],D=o[3];z=f(z=l(z=l(z=l(z=l(z=h(z=h(z=h(z=h(z=a(z=a(z=a(z=a(z,A,C,D,c,7,s[0]),A=a(A,C=a(C,D=a(D,z,A,C,u,12,s[1]),z,A,d,17,s[2]),D,z,p,22,s[3]),C,D,_,7,s[4]),A=a(A,C=a(C,D=a(D,z,A,C,v,12,s[5]),z,A,y,17,s[6]),D,z,g,22,s[7]),C,D,B,7,s[8]),A=a(A,C=a(C,D=a(D,z,A,C,w,12,s[9]),z,A,k,17,s[10]),D,z,S,22,s[11]),C,D,m,7,s[12]),A=a(A,C=a(C,D=a(D,z,A,C,x,12,s[13]),z,A,b,17,s[14]),D,z,H,22,s[15]),C,D,u,5,s[16]),A=h(A,C=h(C,D=h(D,z,A,C,y,9,s[17]),z,A,S,14,s[18]),D,z,c,20,s[19]),C,D,v,5,s[20]),A=h(A,C=h(C,D=h(D,z,A,C,k,9,s[21]),z,A,H,14,s[22]),D,z,_,20,s[23]),C,D,w,5,s[24]),A=h(A,C=h(C,D=h(D,z,A,C,b,9,s[25]),z,A,p,14,s[26]),D,z,B,20,s[27]),C,D,x,5,s[28]),A=h(A,C=h(C,D=h(D,z,A,C,d,9,s[29]),z,A,g,14,s[30]),D,z,m,20,s[31]),C,D,v,4,s[32]),A=l(A,C=l(C,D=l(D,z,A,C,B,11,s[33]),z,A,S,16,s[34]),D,z,b,23,s[35]),C,D,u,4,s[36]),A=l(A,C=l(C,D=l(D,z,A,C,_,11,s[37]),z,A,g,16,s[38]),D,z,k,23,s[39]),C,D,x,4,s[40]),A=l(A,C=l(C,D=l(D,z,A,C,c,11,s[41]),z,A,p,16,s[42]),D,z,y,23,s[43]),C,D,w,4,s[44]),A=l(A,C=l(C,D=l(D,z,A,C,m,11,s[45]),z,A,H,16,s[46]),D,z,d,23,s[47]),C,D,c,6,s[48]),A=f(A=f(A=f(A=f(A,C=f(C,D=f(D,z,A,C,g,10,s[49]),z,A,b,15,s[50]),D,z,v,21,s[51]),C=f(C,D=f(D,z=f(z,A,C,D,m,6,s[52]),A,C,p,10,s[53]),z,A,k,15,s[54]),D,z,u,21,s[55]),C=f(C,D=f(D,z=f(z,A,C,D,B,6,s[56]),A,C,H,10,s[57]),z,A,y,15,s[58]),D,z,x,21,s[59]),C=f(C,D=f(D,z=f(z,A,C,D,_,6,s[60]),A,C,S,10,s[61]),z,A,d,15,s[62]),D,z,w,21,s[63]),o[0]=o[0]+z|0,o[1]=o[1]+A|0,o[2]=o[2]+C|0,o[3]=o[3]+D|0;},_doFinalize:function(){var e=this._data,r=e.words,i=8*this._nDataBytes,n=8*e.sigBytes;r[n>>>5]|=128<<24-n%32;var o=t.floor(i/4294967296),s=i;r[15+(64+n>>>9<<4)]=16711935&(o<<8|o>>>24)|4278255360&(o<<24|o>>>8),r[14+(64+n>>>9<<4)]=16711935&(s<<8|s>>>24)|4278255360&(s<<24|s>>>8),e.sigBytes=4*(r.length+1),this._process();for(var c=this._hash,a=c.words,h=0;h<4;h++){var l=a[h];a[h]=16711935&(l<<8|l>>>24)|4278255360&(l<<24|l>>>8);}return c;},clone:function(){var t=n.clone.call(this);return t._hash=this._hash.clone(),t;}});function a(t,e,r,i,n,o,s){var c=t+(e&r|~e&i)+n+s;return (c<<o|c>>>32-o)+e;}function h(t,e,r,i,n,o,s){var c=t+(e&i|r&~i)+n+s;return (c<<o|c>>>32-o)+e;}function l(t,e,r,i,n,o,s){var c=t+(e^r^i)+n+s;return (c<<o|c>>>32-o)+e;}function f(t,e,r,i,n,o,s){var c=t+(r^(e|~i))+n+s;return (c<<o|c>>>32-o)+e;}e.MD5=n._createHelper(c),e.HmacMD5=n._createHmacHelper(c);}(Math),r=(e=mt).lib,i=r.WordArray,n=r.Hasher,o=e.algo,s=[],c=o.SHA1=n.extend({_doReset:function(){this._hash=new i.init([1732584193,4023233417,2562383102,271733878,3285377520]);},_doProcessBlock:function(t,e){for(var r=this._hash.words,i=r[0],n=r[1],o=r[2],c=r[3],a=r[4],h=0;h<80;h++){if(h<16)s[h]=0|t[e+h];else {var l=s[h-3]^s[h-8]^s[h-14]^s[h-16];s[h]=l<<1|l>>>31;}var f=(i<<5|i>>>27)+a+s[h];f+=h<20?1518500249+(n&o|~n&c):h<40?1859775393+(n^o^c):h<60?(n&o|n&c|o&c)-1894007588:(n^o^c)-899497514,a=c,c=o,o=n<<30|n>>>2,n=i,i=f;}r[0]=r[0]+i|0,r[1]=r[1]+n|0,r[2]=r[2]+o|0,r[3]=r[3]+c|0,r[4]=r[4]+a|0;},_doFinalize:function(){var t=this._data,e=t.words,r=8*this._nDataBytes,i=8*t.sigBytes;return e[i>>>5]|=128<<24-i%32,e[14+(64+i>>>9<<4)]=Math.floor(r/4294967296),e[15+(64+i>>>9<<4)]=r,t.sigBytes=4*e.length,this._process(),this._hash;},clone:function(){var t=n.clone.call(this);return t._hash=this._hash.clone(),t;}}),e.SHA1=n._createHelper(c),e.HmacSHA1=n._createHmacHelper(c),function(t){var e=mt,r=e.lib,i=r.WordArray,n=r.Hasher,o=e.algo,s=[],c=[];!function(){function e(e){for(var r=t.sqrt(e),i=2;i<=r;i++)if(!(e%i))return;return 1;}function r(t){return 4294967296*(t-(0|t))|0;}for(var i=2,n=0;n<64;)e(i)&&(n<8&&(s[n]=r(t.pow(i,.5))),c[n]=r(t.pow(i,1/3)),n++),i++;}();var a=[],h=o.SHA256=n.extend({_doReset:function(){this._hash=new i.init(s.slice(0));},_doProcessBlock:function(t,e){for(var r=this._hash.words,i=r[0],n=r[1],o=r[2],s=r[3],h=r[4],l=r[5],f=r[6],u=r[7],d=0;d<64;d++){if(d<16)a[d]=0|t[e+d];else {var p=a[d-15],_=(p<<25|p>>>7)^(p<<14|p>>>18)^p>>>3,v=a[d-2],y=(v<<15|v>>>17)^(v<<13|v>>>19)^v>>>10;a[d]=_+a[d-7]+y+a[d-16];}var g=i&n^i&o^n&o,B=(i<<30|i>>>2)^(i<<19|i>>>13)^(i<<10|i>>>22),w=u+((h<<26|h>>>6)^(h<<21|h>>>11)^(h<<7|h>>>25))+(h&l^~h&f)+c[d]+a[d];u=f,f=l,l=h,h=s+w|0,s=o,o=n,n=i,i=w+(B+g)|0;}r[0]=r[0]+i|0,r[1]=r[1]+n|0,r[2]=r[2]+o|0,r[3]=r[3]+s|0,r[4]=r[4]+h|0,r[5]=r[5]+l|0,r[6]=r[6]+f|0,r[7]=r[7]+u|0;},_doFinalize:function(){var e=this._data,r=e.words,i=8*this._nDataBytes,n=8*e.sigBytes;return r[n>>>5]|=128<<24-n%32,r[14+(64+n>>>9<<4)]=t.floor(i/4294967296),r[15+(64+n>>>9<<4)]=i,e.sigBytes=4*r.length,this._process(),this._hash;},clone:function(){var t=n.clone.call(this);return t._hash=this._hash.clone(),t;}});e.SHA256=n._createHelper(h),e.HmacSHA256=n._createHmacHelper(h);}(Math),function(){var t=mt.lib.WordArray,e=mt.enc;function r(t){return t<<8&4278255360|t>>>8&16711935;}e.Utf16=e.Utf16BE={stringify:function(t){for(var e=t.words,r=t.sigBytes,i=[],n=0;n<r;n+=2){var o=e[n>>>2]>>>16-n%4*8&65535;i.push(String.fromCharCode(o));}return i.join("");},parse:function(e){for(var r=e.length,i=[],n=0;n<r;n++)i[n>>>1]|=e.charCodeAt(n)<<16-n%2*16;return t.create(i,2*r);}},e.Utf16LE={stringify:function(t){for(var e=t.words,i=t.sigBytes,n=[],o=0;o<i;o+=2){var s=r(e[o>>>2]>>>16-o%4*8&65535);n.push(String.fromCharCode(s));}return n.join("");},parse:function(e){for(var i=e.length,n=[],o=0;o<i;o++)n[o>>>1]|=r(e.charCodeAt(o)<<16-o%2*16);return t.create(n,2*i);}};}(),function(){if("function"==typeof ArrayBuffer){var t=mt.lib.WordArray,e=t.init;(t.init=function(t){if(t instanceof ArrayBuffer&&(t=new Uint8Array(t)),(t instanceof Int8Array||"undefined"!=typeof Uint8ClampedArray&&t instanceof Uint8ClampedArray||t instanceof Int16Array||t instanceof Uint16Array||t instanceof Int32Array||t instanceof Uint32Array||t instanceof Float32Array||t instanceof Float64Array)&&(t=new Uint8Array(t.buffer,t.byteOffset,t.byteLength)),t instanceof Uint8Array){for(var r=t.byteLength,i=[],n=0;n<r;n++)i[n>>>2]|=t[n]<<24-n%4*8;e.call(this,i,r);}else e.apply(this,arguments);}).prototype=t;}}(),h=(a=mt).lib,l=h.WordArray,f=h.Hasher,u=a.algo,d=l.create([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,7,4,13,1,10,6,15,3,12,0,9,5,2,14,11,8,3,10,14,4,9,15,8,1,2,7,0,6,13,11,5,12,1,9,11,10,0,8,12,4,13,3,7,15,14,5,6,2,4,0,5,9,7,12,2,10,14,1,3,8,11,6,15,13]),p=l.create([5,14,7,0,9,2,11,4,13,6,15,8,1,10,3,12,6,11,3,7,0,13,5,10,14,15,8,12,4,9,1,2,15,5,1,3,7,14,6,9,11,8,12,2,10,0,4,13,8,6,4,1,3,11,15,0,5,12,2,13,9,7,10,14,12,15,10,4,1,5,8,7,6,2,13,14,0,3,9,11]),_=l.create([11,14,15,12,5,8,7,9,11,13,14,15,6,7,9,8,7,6,8,13,11,9,7,15,7,12,15,9,11,7,13,12,11,13,6,7,14,9,13,15,14,8,13,6,5,12,7,5,11,12,14,15,14,15,9,8,9,14,5,6,8,6,5,12,9,15,5,11,6,8,13,12,5,12,13,14,11,8,5,6]),v=l.create([8,9,9,11,13,15,15,5,7,7,8,11,14,14,12,6,9,13,15,7,12,8,9,11,7,7,12,7,6,15,13,11,9,7,15,11,8,6,6,14,12,13,5,14,13,13,7,5,15,5,8,11,14,14,6,14,6,9,12,9,12,5,15,8,8,5,12,9,12,5,14,6,8,13,6,5,15,13,11,11]),y=l.create([0,1518500249,1859775393,2400959708,2840853838]),g=l.create([1352829926,1548603684,1836072691,2053994217,0]),B=u.RIPEMD160=f.extend({_doReset:function(){this._hash=l.create([1732584193,4023233417,2562383102,271733878,3285377520]);},_doProcessBlock:function(t,e){for(var r=0;r<16;r++){var i=e+r,n=t[i];t[i]=16711935&(n<<8|n>>>24)|4278255360&(n<<24|n>>>8);}var o,s,c,a,h,l,f,u,B,w,k,S=this._hash.words,m=y.words,x=g.words,b=d.words,H=p.words,z=_.words,A=v.words;for(l=o=S[0],f=s=S[1],u=c=S[2],B=a=S[3],w=h=S[4],r=0;r<80;r+=1)k=o+t[e+b[r]]|0,k+=r<16?xt(s,c,a)+m[0]:r<32?bt(s,c,a)+m[1]:r<48?Ht(s,c,a)+m[2]:r<64?zt(s,c,a)+m[3]:At(s,c,a)+m[4],k=(k=Ct(k|=0,z[r]))+h|0,o=h,h=a,a=Ct(c,10),c=s,s=k,k=l+t[e+H[r]]|0,k+=r<16?At(f,u,B)+x[0]:r<32?zt(f,u,B)+x[1]:r<48?Ht(f,u,B)+x[2]:r<64?bt(f,u,B)+x[3]:xt(f,u,B)+x[4],k=(k=Ct(k|=0,A[r]))+w|0,l=w,w=B,B=Ct(u,10),u=f,f=k;k=S[1]+c+B|0,S[1]=S[2]+a+w|0,S[2]=S[3]+h+l|0,S[3]=S[4]+o+f|0,S[4]=S[0]+s+u|0,S[0]=k;},_doFinalize:function(){var t=this._data,e=t.words,r=8*this._nDataBytes,i=8*t.sigBytes;e[i>>>5]|=128<<24-i%32,e[14+(64+i>>>9<<4)]=16711935&(r<<8|r>>>24)|4278255360&(r<<24|r>>>8),t.sigBytes=4*(e.length+1),this._process();for(var n=this._hash,o=n.words,s=0;s<5;s++){var c=o[s];o[s]=16711935&(c<<8|c>>>24)|4278255360&(c<<24|c>>>8);}return n;},clone:function(){var t=f.clone.call(this);return t._hash=this._hash.clone(),t;}}),a.RIPEMD160=f._createHelper(B),a.HmacRIPEMD160=f._createHmacHelper(B),w=mt.lib.Base,k=mt.enc.Utf8,mt.algo.HMAC=w.extend({init:function(t,e){t=this._hasher=new t.init,"string"==typeof e&&(e=k.parse(e));var r=t.blockSize,i=4*r;e.sigBytes>i&&(e=t.finalize(e)),e.clamp();for(var n=this._oKey=e.clone(),o=this._iKey=e.clone(),s=n.words,c=o.words,a=0;a<r;a++)s[a]^=1549556828,c[a]^=909522486;n.sigBytes=o.sigBytes=i,this.reset();},reset:function(){var t=this._hasher;t.reset(),t.update(this._iKey);},update:function(t){return this._hasher.update(t),this;},finalize:function(t){var e=this._hasher,r=e.finalize(t);return e.reset(),e.finalize(this._oKey.clone().concat(r));}}),x=(m=(S=mt).lib).Base,b=m.WordArray,z=(H=S.algo).SHA1,A=H.HMAC,C=H.PBKDF2=x.extend({cfg:x.extend({keySize:4,hasher:z,iterations:1}),init:function(t){this.cfg=this.cfg.extend(t);},compute:function(t,e){for(var r=this.cfg,i=A.create(r.hasher,t),n=b.create(),o=b.create([1]),s=n.words,c=o.words,a=r.keySize,h=r.iterations;s.length<a;){var l=i.update(e).finalize(o);i.reset();for(var f=l.words,u=f.length,d=l,p=1;p<h;p++){d=i.finalize(d),i.reset();for(var _=d.words,v=0;v<u;v++)f[v]^=_[v];}n.concat(l),c[0]++;}return n.sigBytes=4*a,n;}}),S.PBKDF2=function(t,e,r){return C.create(r).compute(t,e);},E=(R=(D=mt).lib).Base,M=R.WordArray,P=(F=D.algo).MD5,W=F.EvpKDF=E.extend({cfg:E.extend({keySize:4,hasher:P,iterations:1}),init:function(t){this.cfg=this.cfg.extend(t);},compute:function(t,e){for(var r,i=this.cfg,n=i.hasher.create(),o=M.create(),s=o.words,c=i.keySize,a=i.iterations;s.length<c;){r&&n.update(r),r=n.update(t).finalize(e),n.reset();for(var h=1;h<a;h++)r=n.finalize(r),n.reset();o.concat(r);}return o.sigBytes=4*c,o;}}),D.EvpKDF=function(t,e,r){return W.create(r).compute(t,e);},U=(O=mt).lib.WordArray,I=O.algo,K=I.SHA256,X=I.SHA224=K.extend({_doReset:function(){this._hash=new U.init([3238371032,914150663,812702999,4144912697,4290775857,1750603025,1694076839,3204075428]);},_doFinalize:function(){var t=K._doFinalize.call(this);return t.sigBytes-=4,t;}}),O.SHA224=K._createHelper(X),O.HmacSHA224=K._createHmacHelper(X),j=mt.lib,L=j.Base,N=j.WordArray,(T=mt.x64={}).Word=L.extend({init:function(t,e){this.high=t,this.low=e;}}),T.WordArray=L.extend({init:function(t,e){t=this.words=t||[],this.sigBytes=null!=e?e:8*t.length;},toX32:function(){for(var t=this.words,e=t.length,r=[],i=0;i<e;i++){var n=t[i];r.push(n.high),r.push(n.low);}return N.create(r,this.sigBytes);},clone:function(){for(var t=L.clone.call(this),e=t.words=this.words.slice(0),r=e.length,i=0;i<r;i++)e[i]=e[i].clone();return t;}}),function(t){var e=mt,r=e.lib,i=r.WordArray,n=r.Hasher,o=e.x64.Word,s=e.algo,c=[],a=[],h=[];!function(){for(var t=1,e=0,r=0;r<24;r++){c[t+5*e]=(r+1)*(r+2)/2%64;var i=(2*t+3*e)%5;t=e%5,e=i;}for(t=0;t<5;t++)for(e=0;e<5;e++)a[t+5*e]=e+(2*t+3*e)%5*5;for(var n=1,s=0;s<24;s++){for(var l=0,f=0,u=0;u<7;u++){if(1&n){var d=(1<<u)-1;d<32?f^=1<<d:l^=1<<d-32;}128&n?n=n<<1^113:n<<=1;}h[s]=o.create(l,f);}}();var l=[];!function(){for(var t=0;t<25;t++)l[t]=o.create();}();var f=s.SHA3=n.extend({cfg:n.cfg.extend({outputLength:512}),_doReset:function(){for(var t=this._state=[],e=0;e<25;e++)t[e]=new o.init;this.blockSize=(1600-2*this.cfg.outputLength)/32;},_doProcessBlock:function(t,e){for(var r=this._state,i=this.blockSize/2,n=0;n<i;n++){var o=t[e+2*n],s=t[e+2*n+1];o=16711935&(o<<8|o>>>24)|4278255360&(o<<24|o>>>8),s=16711935&(s<<8|s>>>24)|4278255360&(s<<24|s>>>8),(A=r[n]).high^=s,A.low^=o;}for(var f=0;f<24;f++){for(var u=0;u<5;u++){for(var d=0,p=0,_=0;_<5;_++)d^=(A=r[u+5*_]).high,p^=A.low;var v=l[u];v.high=d,v.low=p;}for(u=0;u<5;u++){var y=l[(u+4)%5],g=l[(u+1)%5],B=g.high,w=g.low;for(d=y.high^(B<<1|w>>>31),p=y.low^(w<<1|B>>>31),_=0;_<5;_++)(A=r[u+5*_]).high^=d,A.low^=p;}for(var k=1;k<25;k++){var S=(A=r[k]).high,m=A.low,x=c[k];p=x<32?(d=S<<x|m>>>32-x,m<<x|S>>>32-x):(d=m<<x-32|S>>>64-x,S<<x-32|m>>>64-x);var b=l[a[k]];b.high=d,b.low=p;}var H=l[0],z=r[0];for(H.high=z.high,H.low=z.low,u=0;u<5;u++)for(_=0;_<5;_++){var A=r[k=u+5*_],C=l[k],D=l[(u+1)%5+5*_],R=l[(u+2)%5+5*_];A.high=C.high^~D.high&R.high,A.low=C.low^~D.low&R.low;}A=r[0];var E=h[f];A.high^=E.high,A.low^=E.low;}},_doFinalize:function(){var e=this._data,r=e.words,n=(this._nDataBytes,8*e.sigBytes),o=32*this.blockSize;r[n>>>5]|=1<<24-n%32,r[(t.ceil((1+n)/o)*o>>>5)-1]|=128,e.sigBytes=4*r.length,this._process();for(var s=this._state,c=this.cfg.outputLength/8,a=c/8,h=[],l=0;l<a;l++){var f=s[l],u=f.high,d=f.low;u=16711935&(u<<8|u>>>24)|4278255360&(u<<24|u>>>8),d=16711935&(d<<8|d>>>24)|4278255360&(d<<24|d>>>8),h.push(d),h.push(u);}return new i.init(h,c);},clone:function(){for(var t=n.clone.call(this),e=t._state=this._state.slice(0),r=0;r<25;r++)e[r]=e[r].clone();return t;}});e.SHA3=n._createHelper(f),e.HmacSHA3=n._createHmacHelper(f);}(Math),function(){var t=mt,e=t.lib.Hasher,r=t.x64,i=r.Word,n=r.WordArray,o=t.algo;function s(){return i.create.apply(i,arguments);}var c=[s(1116352408,3609767458),s(1899447441,602891725),s(3049323471,3964484399),s(3921009573,2173295548),s(961987163,4081628472),s(1508970993,3053834265),s(2453635748,2937671579),s(2870763221,3664609560),s(3624381080,2734883394),s(310598401,1164996542),s(607225278,1323610764),s(1426881987,3590304994),s(1925078388,4068182383),s(2162078206,991336113),s(2614888103,633803317),s(3248222580,3479774868),s(3835390401,2666613458),s(4022224774,944711139),s(264347078,2341262773),s(604807628,2007800933),s(770255983,1495990901),s(1249150122,1856431235),s(1555081692,3175218132),s(1996064986,2198950837),s(2554220882,3999719339),s(2821834349,766784016),s(2952996808,2566594879),s(3210313671,3203337956),s(3336571891,1034457026),s(3584528711,2466948901),s(113926993,3758326383),s(338241895,168717936),s(666307205,1188179964),s(773529912,1546045734),s(1294757372,1522805485),s(1396182291,2643833823),s(1695183700,2343527390),s(1986661051,1014477480),s(2177026350,1206759142),s(2456956037,344077627),s(2730485921,1290863460),s(2820302411,3158454273),s(3259730800,3505952657),s(3345764771,106217008),s(3516065817,3606008344),s(3600352804,1432725776),s(4094571909,1467031594),s(275423344,851169720),s(430227734,3100823752),s(506948616,1363258195),s(659060556,3750685593),s(883997877,3785050280),s(958139571,3318307427),s(1322822218,3812723403),s(1537002063,2003034995),s(1747873779,3602036899),s(1955562222,1575990012),s(2024104815,1125592928),s(2227730452,2716904306),s(2361852424,442776044),s(2428436474,593698344),s(2756734187,3733110249),s(3204031479,2999351573),s(3329325298,3815920427),s(3391569614,3928383900),s(3515267271,566280711),s(3940187606,3454069534),s(4118630271,4000239992),s(116418474,1914138554),s(174292421,2731055270),s(289380356,3203993006),s(460393269,320620315),s(685471733,587496836),s(852142971,1086792851),s(1017036298,365543100),s(1126000580,2618297676),s(1288033470,3409855158),s(1501505948,4234509866),s(1607167915,987167468),s(1816402316,1246189591)],a=[];!function(){for(var t=0;t<80;t++)a[t]=s();}();var h=o.SHA512=e.extend({_doReset:function(){this._hash=new n.init([new i.init(1779033703,4089235720),new i.init(3144134277,2227873595),new i.init(1013904242,4271175723),new i.init(2773480762,1595750129),new i.init(1359893119,2917565137),new i.init(2600822924,725511199),new i.init(528734635,4215389547),new i.init(1541459225,327033209)]);},_doProcessBlock:function(t,e){for(var r=this._hash.words,i=r[0],n=r[1],o=r[2],s=r[3],h=r[4],l=r[5],f=r[6],u=r[7],d=i.high,p=i.low,_=n.high,v=n.low,y=o.high,g=o.low,B=s.high,w=s.low,k=h.high,S=h.low,m=l.high,x=l.low,b=f.high,H=f.low,z=u.high,A=u.low,C=d,D=p,R=_,E=v,M=y,F=g,P=B,W=w,O=k,U=S,I=m,K=x,X=b,j=H,L=z,N=A,T=0;T<80;T++){var Z,q,G=a[T];if(T<16)q=G.high=0|t[e+2*T],Z=G.low=0|t[e+2*T+1];else {var V=a[T-15],$=V.high,J=V.low,Q=($>>>1|J<<31)^($>>>8|J<<24)^$>>>7,Y=(J>>>1|$<<31)^(J>>>8|$<<24)^(J>>>7|$<<25),tt=a[T-2],et=tt.high,rt=tt.low,it=(et>>>19|rt<<13)^(et<<3|rt>>>29)^et>>>6,nt=(rt>>>19|et<<13)^(rt<<3|et>>>29)^(rt>>>6|et<<26),ot=a[T-7],st=ot.high,ct=ot.low,at=a[T-16],ht=at.high,lt=at.low;q=(q=(q=Q+st+((Z=Y+ct)>>>0<Y>>>0?1:0))+it+((Z+=nt)>>>0<nt>>>0?1:0))+ht+((Z+=lt)>>>0<lt>>>0?1:0),G.high=q,G.low=Z;}var ft,ut=O&I^~O&X,dt=U&K^~U&j,pt=C&R^C&M^R&M,_t=D&E^D&F^E&F,vt=(C>>>28|D<<4)^(C<<30|D>>>2)^(C<<25|D>>>7),yt=(D>>>28|C<<4)^(D<<30|C>>>2)^(D<<25|C>>>7),gt=(O>>>14|U<<18)^(O>>>18|U<<14)^(O<<23|U>>>9),Bt=(U>>>14|O<<18)^(U>>>18|O<<14)^(U<<23|O>>>9),wt=c[T],kt=wt.high,St=wt.low,mt=L+gt+((ft=N+Bt)>>>0<N>>>0?1:0),xt=yt+_t;L=X,N=j,X=I,j=K,I=O,K=U,O=P+(mt=(mt=(mt=mt+ut+((ft+=dt)>>>0<dt>>>0?1:0))+kt+((ft+=St)>>>0<St>>>0?1:0))+q+((ft+=Z)>>>0<Z>>>0?1:0))+((U=W+ft|0)>>>0<W>>>0?1:0)|0,P=M,W=F,M=R,F=E,R=C,E=D,C=mt+(vt+pt+(xt>>>0<yt>>>0?1:0))+((D=ft+xt|0)>>>0<ft>>>0?1:0)|0;}p=i.low=p+D,i.high=d+C+(p>>>0<D>>>0?1:0),v=n.low=v+E,n.high=_+R+(v>>>0<E>>>0?1:0),g=o.low=g+F,o.high=y+M+(g>>>0<F>>>0?1:0),w=s.low=w+W,s.high=B+P+(w>>>0<W>>>0?1:0),S=h.low=S+U,h.high=k+O+(S>>>0<U>>>0?1:0),x=l.low=x+K,l.high=m+I+(x>>>0<K>>>0?1:0),H=f.low=H+j,f.high=b+X+(H>>>0<j>>>0?1:0),A=u.low=A+N,u.high=z+L+(A>>>0<N>>>0?1:0);},_doFinalize:function(){var t=this._data,e=t.words,r=8*this._nDataBytes,i=8*t.sigBytes;return e[i>>>5]|=128<<24-i%32,e[30+(128+i>>>10<<5)]=Math.floor(r/4294967296),e[31+(128+i>>>10<<5)]=r,t.sigBytes=4*e.length,this._process(),this._hash.toX32();},clone:function(){var t=e.clone.call(this);return t._hash=this._hash.clone(),t;},blockSize:32});t.SHA512=e._createHelper(h),t.HmacSHA512=e._createHmacHelper(h);}(),q=(Z=mt).x64,G=q.Word,V=q.WordArray,$=Z.algo,J=$.SHA512,Q=$.SHA384=J.extend({_doReset:function(){this._hash=new V.init([new G.init(3418070365,3238371032),new G.init(1654270250,914150663),new G.init(2438529370,812702999),new G.init(355462360,4144912697),new G.init(1731405415,4290775857),new G.init(2394180231,1750603025),new G.init(3675008525,1694076839),new G.init(1203062813,3204075428)]);},_doFinalize:function(){var t=J._doFinalize.call(this);return t.sigBytes-=16,t;}}),Z.SHA384=J._createHelper(Q),Z.HmacSHA384=J._createHmacHelper(Q),mt.lib.Cipher||function(){var t=mt,e=t.lib,r=e.Base,i=e.WordArray,n=e.BufferedBlockAlgorithm,o=t.enc,s=(o.Utf8,o.Base64),c=t.algo.EvpKDF,a=e.Cipher=n.extend({cfg:r.extend(),createEncryptor:function(t,e){return this.create(this._ENC_XFORM_MODE,t,e);},createDecryptor:function(t,e){return this.create(this._DEC_XFORM_MODE,t,e);},init:function(t,e,r){this.cfg=this.cfg.extend(r),this._xformMode=t,this._key=e,this.reset();},reset:function(){n.reset.call(this),this._doReset();},process:function(t){return this._append(t),this._process();},finalize:function(t){return t&&this._append(t),this._doFinalize();},keySize:4,ivSize:4,_ENC_XFORM_MODE:1,_DEC_XFORM_MODE:2,_createHelper:function(t){return {encrypt:function(e,r,i){return h(r).encrypt(t,e,r,i);},decrypt:function(e,r,i){return h(r).decrypt(t,e,r,i);}};}});function h(t){return "string"==typeof t?w:g;}e.StreamCipher=a.extend({_doFinalize:function(){return this._process(!0);},blockSize:1});var l,f=t.mode={},u=e.BlockCipherMode=r.extend({createEncryptor:function(t,e){return this.Encryptor.create(t,e);},createDecryptor:function(t,e){return this.Decryptor.create(t,e);},init:function(t,e){this._cipher=t,this._iv=e;}}),d=f.CBC=((l=u.extend()).Encryptor=l.extend({processBlock:function(t,e){var r=this._cipher,i=r.blockSize;p.call(this,t,e,i),r.encryptBlock(t,e),this._prevBlock=t.slice(e,e+i);}}),l.Decryptor=l.extend({processBlock:function(t,e){var r=this._cipher,i=r.blockSize,n=t.slice(e,e+i);r.decryptBlock(t,e),p.call(this,t,e,i),this._prevBlock=n;}}),l);function p(t,e,r){var i,n=this._iv;n?(i=n,this._iv=void 0):i=this._prevBlock;for(var o=0;o<r;o++)t[e+o]^=i[o];}var _=(t.pad={}).Pkcs7={pad:function(t,e){for(var r=4*e,n=r-t.sigBytes%r,o=n<<24|n<<16|n<<8|n,s=[],c=0;c<n;c+=4)s.push(o);var a=i.create(s,n);t.concat(a);},unpad:function(t){var e=255&t.words[t.sigBytes-1>>>2];t.sigBytes-=e;}},v=(e.BlockCipher=a.extend({cfg:a.cfg.extend({mode:d,padding:_}),reset:function(){var t;a.reset.call(this);var e=this.cfg,r=e.iv,i=e.mode;this._xformMode==this._ENC_XFORM_MODE?t=i.createEncryptor:(t=i.createDecryptor,this._minBufferSize=1),this._mode&&this._mode.__creator==t?this._mode.init(this,r&&r.words):(this._mode=t.call(i,this,r&&r.words),this._mode.__creator=t);},_doProcessBlock:function(t,e){this._mode.processBlock(t,e);},_doFinalize:function(){var t,e=this.cfg.padding;return this._xformMode==this._ENC_XFORM_MODE?(e.pad(this._data,this.blockSize),t=this._process(!0)):(t=this._process(!0),e.unpad(t)),t;},blockSize:4}),e.CipherParams=r.extend({init:function(t){this.mixIn(t);},toString:function(t){return (t||this.formatter).stringify(this);}})),y=(t.format={}).OpenSSL={stringify:function(t){var e=t.ciphertext,r=t.salt;return (r?i.create([1398893684,1701076831]).concat(r).concat(e):e).toString(s);},parse:function(t){var e,r=s.parse(t),n=r.words;return 1398893684==n[0]&&1701076831==n[1]&&(e=i.create(n.slice(2,4)),n.splice(0,4),r.sigBytes-=16),v.create({ciphertext:r,salt:e});}},g=e.SerializableCipher=r.extend({cfg:r.extend({format:y}),encrypt:function(t,e,r,i){i=this.cfg.extend(i);var n=t.createEncryptor(r,i),o=n.finalize(e),s=n.cfg;return v.create({ciphertext:o,key:r,iv:s.iv,algorithm:t,mode:s.mode,padding:s.padding,blockSize:t.blockSize,formatter:i.format});},decrypt:function(t,e,r,i){return i=this.cfg.extend(i),e=this._parse(e,i.format),t.createDecryptor(r,i).finalize(e.ciphertext);},_parse:function(t,e){return "string"==typeof t?e.parse(t,this):t;}}),B=(t.kdf={}).OpenSSL={execute:function(t,e,r,n){n=n||i.random(8);var o=c.create({keySize:e+r}).compute(t,n),s=i.create(o.words.slice(e),4*r);return o.sigBytes=4*e,v.create({key:o,iv:s,salt:n});}},w=e.PasswordBasedCipher=g.extend({cfg:g.cfg.extend({kdf:B}),encrypt:function(t,e,r,i){var n=(i=this.cfg.extend(i)).kdf.execute(r,t.keySize,t.ivSize);i.iv=n.iv;var o=g.encrypt.call(this,t,e,n.key,i);return o.mixIn(n),o;},decrypt:function(t,e,r,i){i=this.cfg.extend(i),e=this._parse(e,i.format);var n=i.kdf.execute(r,t.keySize,t.ivSize,e.salt);return i.iv=n.iv,g.decrypt.call(this,t,e,n.key,i);}});}(),mt.mode.CFB=((Y=mt.lib.BlockCipherMode.extend()).Encryptor=Y.extend({processBlock:function(t,e){var r=this._cipher,i=r.blockSize;Dt.call(this,t,e,i,r),this._prevBlock=t.slice(e,e+i);}}),Y.Decryptor=Y.extend({processBlock:function(t,e){var r=this._cipher,i=r.blockSize,n=t.slice(e,e+i);Dt.call(this,t,e,i,r),this._prevBlock=n;}}),Y),mt.mode.ECB=((tt=mt.lib.BlockCipherMode.extend()).Encryptor=tt.extend({processBlock:function(t,e){this._cipher.encryptBlock(t,e);}}),tt.Decryptor=tt.extend({processBlock:function(t,e){this._cipher.decryptBlock(t,e);}}),tt),mt.pad.AnsiX923={pad:function(t,e){var r=t.sigBytes,i=4*e,n=i-r%i,o=r+n-1;t.clamp(),t.words[o>>>2]|=n<<24-o%4*8,t.sigBytes+=n;},unpad:function(t){var e=255&t.words[t.sigBytes-1>>>2];t.sigBytes-=e;}},mt.pad.Iso10126={pad:function(t,e){var r=4*e,i=r-t.sigBytes%r;t.concat(mt.lib.WordArray.random(i-1)).concat(mt.lib.WordArray.create([i<<24],1));},unpad:function(t){var e=255&t.words[t.sigBytes-1>>>2];t.sigBytes-=e;}},mt.pad.Iso97971={pad:function(t,e){t.concat(mt.lib.WordArray.create([2147483648],1)),mt.pad.ZeroPadding.pad(t,e);},unpad:function(t){mt.pad.ZeroPadding.unpad(t),t.sigBytes--;}},mt.mode.OFB=(rt=(et=mt.lib.BlockCipherMode.extend()).Encryptor=et.extend({processBlock:function(t,e){var r=this._cipher,i=r.blockSize,n=this._iv,o=this._keystream;n&&(o=this._keystream=n.slice(0),this._iv=void 0),r.encryptBlock(o,0);for(var s=0;s<i;s++)t[e+s]^=o[s];}}),et.Decryptor=rt,et),mt.pad.NoPadding={pad:function(){},unpad:function(){}},it=mt.lib.CipherParams,nt=mt.enc.Hex,mt.format.Hex={stringify:function(t){return t.ciphertext.toString(nt);},parse:function(t){var e=nt.parse(t);return it.create({ciphertext:e});}},function(){var t=mt,e=t.lib.BlockCipher,r=t.algo,i=[],n=[],o=[],s=[],c=[],a=[],h=[],l=[],f=[],u=[];!function(){for(var t=[],e=0;e<256;e++)t[e]=e<128?e<<1:e<<1^283;var r=0,d=0;for(e=0;e<256;e++){var p=d^d<<1^d<<2^d<<3^d<<4;p=p>>>8^255&p^99,i[r]=p;var _=t[n[p]=r],v=t[_],y=t[v],g=257*t[p]^16843008*p;o[r]=g<<24|g>>>8,s[r]=g<<16|g>>>16,c[r]=g<<8|g>>>24,a[r]=g,g=16843009*y^65537*v^257*_^16843008*r,h[p]=g<<24|g>>>8,l[p]=g<<16|g>>>16,f[p]=g<<8|g>>>24,u[p]=g,r?(r=_^t[t[t[y^_]]],d^=t[t[d]]):r=d=1;}}();var d=[0,1,2,4,8,16,32,64,128,27,54],p=r.AES=e.extend({_doReset:function(){if(!this._nRounds||this._keyPriorReset!==this._key){for(var t=this._keyPriorReset=this._key,e=t.words,r=t.sigBytes/4,n=4*(1+(this._nRounds=6+r)),o=this._keySchedule=[],s=0;s<n;s++)s<r?o[s]=e[s]:(p=o[s-1],s%r?6<r&&s%r==4&&(p=i[p>>>24]<<24|i[p>>>16&255]<<16|i[p>>>8&255]<<8|i[255&p]):(p=i[(p=p<<8|p>>>24)>>>24]<<24|i[p>>>16&255]<<16|i[p>>>8&255]<<8|i[255&p],p^=d[s/r|0]<<24),o[s]=o[s-r]^p);for(var c=this._invKeySchedule=[],a=0;a<n;a++){if(s=n-a,a%4)var p=o[s];else p=o[s-4];c[a]=a<4||s<=4?p:h[i[p>>>24]]^l[i[p>>>16&255]]^f[i[p>>>8&255]]^u[i[255&p]];}}},encryptBlock:function(t,e){this._doCryptBlock(t,e,this._keySchedule,o,s,c,a,i);},decryptBlock:function(t,e){var r=t[e+1];t[e+1]=t[e+3],t[e+3]=r,this._doCryptBlock(t,e,this._invKeySchedule,h,l,f,u,n),r=t[e+1],t[e+1]=t[e+3],t[e+3]=r;},_doCryptBlock:function(t,e,r,i,n,o,s,c){for(var a=this._nRounds,h=t[e]^r[0],l=t[e+1]^r[1],f=t[e+2]^r[2],u=t[e+3]^r[3],d=4,p=1;p<a;p++){var _=i[h>>>24]^n[l>>>16&255]^o[f>>>8&255]^s[255&u]^r[d++],v=i[l>>>24]^n[f>>>16&255]^o[u>>>8&255]^s[255&h]^r[d++],y=i[f>>>24]^n[u>>>16&255]^o[h>>>8&255]^s[255&l]^r[d++],g=i[u>>>24]^n[h>>>16&255]^o[l>>>8&255]^s[255&f]^r[d++];h=_,l=v,f=y,u=g;}_=(c[h>>>24]<<24|c[l>>>16&255]<<16|c[f>>>8&255]<<8|c[255&u])^r[d++],v=(c[l>>>24]<<24|c[f>>>16&255]<<16|c[u>>>8&255]<<8|c[255&h])^r[d++],y=(c[f>>>24]<<24|c[u>>>16&255]<<16|c[h>>>8&255]<<8|c[255&l])^r[d++],g=(c[u>>>24]<<24|c[h>>>16&255]<<16|c[l>>>8&255]<<8|c[255&f])^r[d++],t[e]=_,t[e+1]=v,t[e+2]=y,t[e+3]=g;},keySize:8});t.AES=e._createHelper(p);}(),function(){var t=mt,e=t.lib,r=e.WordArray,i=e.BlockCipher,n=t.algo,o=[57,49,41,33,25,17,9,1,58,50,42,34,26,18,10,2,59,51,43,35,27,19,11,3,60,52,44,36,63,55,47,39,31,23,15,7,62,54,46,38,30,22,14,6,61,53,45,37,29,21,13,5,28,20,12,4],s=[14,17,11,24,1,5,3,28,15,6,21,10,23,19,12,4,26,8,16,7,27,20,13,2,41,52,31,37,47,55,30,40,51,45,33,48,44,49,39,56,34,53,46,42,50,36,29,32],c=[1,2,4,6,8,10,12,14,15,17,19,21,23,25,27,28],a=[{0:8421888,268435456:32768,536870912:8421378,805306368:2,1073741824:512,1342177280:8421890,1610612736:8389122,1879048192:8388608,2147483648:514,2415919104:8389120,2684354560:33280,2952790016:8421376,3221225472:32770,3489660928:8388610,3758096384:0,4026531840:33282,134217728:0,402653184:8421890,671088640:33282,939524096:32768,1207959552:8421888,1476395008:512,1744830464:8421378,2013265920:2,2281701376:8389120,2550136832:33280,2818572288:8421376,3087007744:8389122,3355443200:8388610,3623878656:32770,3892314112:514,4160749568:8388608,1:32768,268435457:2,536870913:8421888,805306369:8388608,1073741825:8421378,1342177281:33280,1610612737:512,1879048193:8389122,2147483649:8421890,2415919105:8421376,2684354561:8388610,2952790017:33282,3221225473:514,3489660929:8389120,3758096385:32770,4026531841:0,134217729:8421890,402653185:8421376,671088641:8388608,939524097:512,1207959553:32768,1476395009:8388610,1744830465:2,2013265921:33282,2281701377:32770,2550136833:8389122,2818572289:514,3087007745:8421888,3355443201:8389120,3623878657:0,3892314113:33280,4160749569:8421378},{0:1074282512,16777216:16384,33554432:524288,50331648:1074266128,67108864:1073741840,83886080:1074282496,100663296:1073758208,117440512:16,134217728:540672,150994944:1073758224,167772160:1073741824,184549376:540688,201326592:524304,218103808:0,234881024:16400,251658240:1074266112,8388608:1073758208,25165824:540688,41943040:16,58720256:1073758224,75497472:1074282512,92274688:1073741824,109051904:524288,125829120:1074266128,142606336:524304,159383552:0,176160768:16384,192937984:1074266112,209715200:1073741840,226492416:540672,243269632:1074282496,260046848:16400,268435456:0,285212672:1074266128,301989888:1073758224,318767104:1074282496,335544320:1074266112,352321536:16,369098752:540688,385875968:16384,402653184:16400,419430400:524288,436207616:524304,452984832:1073741840,469762048:540672,486539264:1073758208,503316480:1073741824,520093696:1074282512,276824064:540688,293601280:524288,310378496:1074266112,327155712:16384,343932928:1073758208,360710144:1074282512,377487360:16,394264576:1073741824,411041792:1074282496,427819008:1073741840,444596224:1073758224,461373440:524304,478150656:0,494927872:16400,511705088:1074266128,528482304:540672},{0:260,1048576:0,2097152:67109120,3145728:65796,4194304:65540,5242880:67108868,6291456:67174660,7340032:67174400,8388608:67108864,9437184:67174656,10485760:65792,11534336:67174404,12582912:67109124,13631488:65536,14680064:4,15728640:256,524288:67174656,1572864:67174404,2621440:0,3670016:67109120,4718592:67108868,5767168:65536,6815744:65540,7864320:260,8912896:4,9961472:256,11010048:67174400,12058624:65796,13107200:65792,14155776:67109124,15204352:67174660,16252928:67108864,16777216:67174656,17825792:65540,18874368:65536,19922944:67109120,20971520:256,22020096:67174660,23068672:67108868,24117248:0,25165824:67109124,26214400:67108864,27262976:4,28311552:65792,29360128:67174400,30408704:260,31457280:65796,32505856:67174404,17301504:67108864,18350080:260,19398656:67174656,20447232:0,21495808:65540,22544384:67109120,23592960:256,24641536:67174404,25690112:65536,26738688:67174660,27787264:65796,28835840:67108868,29884416:67109124,30932992:67174400,31981568:4,33030144:65792},{0:2151682048,65536:2147487808,131072:4198464,196608:2151677952,262144:0,327680:4198400,393216:2147483712,458752:4194368,524288:2147483648,589824:4194304,655360:64,720896:2147487744,786432:2151678016,851968:4160,917504:4096,983040:2151682112,32768:2147487808,98304:64,163840:2151678016,229376:2147487744,294912:4198400,360448:2151682112,425984:0,491520:2151677952,557056:4096,622592:2151682048,688128:4194304,753664:4160,819200:2147483648,884736:4194368,950272:4198464,1015808:2147483712,1048576:4194368,1114112:4198400,1179648:2147483712,1245184:0,1310720:4160,1376256:2151678016,1441792:2151682048,1507328:2147487808,1572864:2151682112,1638400:2147483648,1703936:2151677952,1769472:4198464,1835008:2147487744,1900544:4194304,1966080:64,2031616:4096,1081344:2151677952,1146880:2151682112,1212416:0,1277952:4198400,1343488:4194368,1409024:2147483648,1474560:2147487808,1540096:64,1605632:2147483712,1671168:4096,1736704:2147487744,1802240:2151678016,1867776:4160,1933312:2151682048,1998848:4194304,2064384:4198464},{0:128,4096:17039360,8192:262144,12288:536870912,16384:537133184,20480:16777344,24576:553648256,28672:262272,32768:16777216,36864:537133056,40960:536871040,45056:553910400,49152:553910272,53248:0,57344:17039488,61440:553648128,2048:17039488,6144:553648256,10240:128,14336:17039360,18432:262144,22528:537133184,26624:553910272,30720:536870912,34816:537133056,38912:0,43008:553910400,47104:16777344,51200:536871040,55296:553648128,59392:16777216,63488:262272,65536:262144,69632:128,73728:536870912,77824:553648256,81920:16777344,86016:553910272,90112:537133184,94208:16777216,98304:553910400,102400:553648128,106496:17039360,110592:537133056,114688:262272,118784:536871040,122880:0,126976:17039488,67584:553648256,71680:16777216,75776:17039360,79872:537133184,83968:536870912,88064:17039488,92160:128,96256:553910272,100352:262272,104448:553910400,108544:0,112640:553648128,116736:16777344,120832:262144,124928:537133056,129024:536871040},{0:268435464,256:8192,512:270532608,768:270540808,1024:268443648,1280:2097152,1536:2097160,1792:268435456,2048:0,2304:268443656,2560:2105344,2816:8,3072:270532616,3328:2105352,3584:8200,3840:270540800,128:270532608,384:270540808,640:8,896:2097152,1152:2105352,1408:268435464,1664:268443648,1920:8200,2176:2097160,2432:8192,2688:268443656,2944:270532616,3200:0,3456:270540800,3712:2105344,3968:268435456,4096:268443648,4352:270532616,4608:270540808,4864:8200,5120:2097152,5376:268435456,5632:268435464,5888:2105344,6144:2105352,6400:0,6656:8,6912:270532608,7168:8192,7424:268443656,7680:270540800,7936:2097160,4224:8,4480:2105344,4736:2097152,4992:268435464,5248:268443648,5504:8200,5760:270540808,6016:270532608,6272:270540800,6528:270532616,6784:8192,7040:2105352,7296:2097160,7552:0,7808:268435456,8064:268443656},{0:1048576,16:33555457,32:1024,48:1049601,64:34604033,80:0,96:1,112:34603009,128:33555456,144:1048577,160:33554433,176:34604032,192:34603008,208:1025,224:1049600,240:33554432,8:34603009,24:0,40:33555457,56:34604032,72:1048576,88:33554433,104:33554432,120:1025,136:1049601,152:33555456,168:34603008,184:1048577,200:1024,216:34604033,232:1,248:1049600,256:33554432,272:1048576,288:33555457,304:34603009,320:1048577,336:33555456,352:34604032,368:1049601,384:1025,400:34604033,416:1049600,432:1,448:0,464:34603008,480:33554433,496:1024,264:1049600,280:33555457,296:34603009,312:1,328:33554432,344:1048576,360:1025,376:34604032,392:33554433,408:34603008,424:0,440:34604033,456:1049601,472:1024,488:33555456,504:1048577},{0:134219808,1:131072,2:134217728,3:32,4:131104,5:134350880,6:134350848,7:2048,8:134348800,9:134219776,10:133120,11:134348832,12:2080,13:0,14:134217760,15:133152,2147483648:2048,2147483649:134350880,2147483650:134219808,2147483651:134217728,2147483652:134348800,2147483653:133120,2147483654:133152,2147483655:32,2147483656:134217760,2147483657:2080,2147483658:131104,2147483659:134350848,2147483660:0,2147483661:134348832,2147483662:134219776,2147483663:131072,16:133152,17:134350848,18:32,19:2048,20:134219776,21:134217760,22:134348832,23:131072,24:0,25:131104,26:134348800,27:134219808,28:134350880,29:133120,30:2080,31:134217728,2147483664:131072,2147483665:2048,2147483666:134348832,2147483667:133152,2147483668:32,2147483669:134348800,2147483670:134217728,2147483671:134219808,2147483672:134350880,2147483673:134217760,2147483674:134219776,2147483675:0,2147483676:133120,2147483677:2080,2147483678:131104,2147483679:134350848}],h=[4160749569,528482304,33030144,2064384,129024,8064,504,2147483679],l=n.DES=i.extend({_doReset:function(){for(var t=this._key.words,e=[],r=0;r<56;r++){var i=o[r]-1;e[r]=t[i>>>5]>>>31-i%32&1;}for(var n=this._subKeys=[],a=0;a<16;a++){var h=n[a]=[],l=c[a];for(r=0;r<24;r++)h[r/6|0]|=e[(s[r]-1+l)%28]<<31-r%6,h[4+(r/6|0)]|=e[28+(s[r+24]-1+l)%28]<<31-r%6;for(h[0]=h[0]<<1|h[0]>>>31,r=1;r<7;r++)h[r]=h[r]>>>4*(r-1)+3;h[7]=h[7]<<5|h[7]>>>27;}var f=this._invSubKeys=[];for(r=0;r<16;r++)f[r]=n[15-r];},encryptBlock:function(t,e){this._doCryptBlock(t,e,this._subKeys);},decryptBlock:function(t,e){this._doCryptBlock(t,e,this._invSubKeys);},_doCryptBlock:function(t,e,r){this._lBlock=t[e],this._rBlock=t[e+1],f.call(this,4,252645135),f.call(this,16,65535),u.call(this,2,858993459),u.call(this,8,16711935),f.call(this,1,1431655765);for(var i=0;i<16;i++){for(var n=r[i],o=this._lBlock,s=this._rBlock,c=0,l=0;l<8;l++)c|=a[l][((s^n[l])&h[l])>>>0];this._lBlock=s,this._rBlock=o^c;}var d=this._lBlock;this._lBlock=this._rBlock,this._rBlock=d,f.call(this,1,1431655765),u.call(this,8,16711935),u.call(this,2,858993459),f.call(this,16,65535),f.call(this,4,252645135),t[e]=this._lBlock,t[e+1]=this._rBlock;},keySize:2,ivSize:2,blockSize:2});function f(t,e){var r=(this._lBlock>>>t^this._rBlock)&e;this._rBlock^=r,this._lBlock^=r<<t;}function u(t,e){var r=(this._rBlock>>>t^this._lBlock)&e;this._lBlock^=r,this._rBlock^=r<<t;}t.DES=i._createHelper(l);var d=n.TripleDES=i.extend({_doReset:function(){var t=this._key.words;if(2!==t.length&&4!==t.length&&t.length<6)throw new Error("Invalid key length - 3DES requires the key length to be 64, 128, 192 or >192.");var e=t.slice(0,2),i=t.length<4?t.slice(0,2):t.slice(2,4),n=t.length<6?t.slice(0,2):t.slice(4,6);this._des1=l.createEncryptor(r.create(e)),this._des2=l.createEncryptor(r.create(i)),this._des3=l.createEncryptor(r.create(n));},encryptBlock:function(t,e){this._des1.encryptBlock(t,e),this._des2.decryptBlock(t,e),this._des3.encryptBlock(t,e);},decryptBlock:function(t,e){this._des3.decryptBlock(t,e),this._des2.encryptBlock(t,e),this._des1.decryptBlock(t,e);},keySize:6,ivSize:2,blockSize:2});t.TripleDES=i._createHelper(d);}(),function(){var t=mt,e=t.lib.StreamCipher,r=t.algo,i=r.RC4=e.extend({_doReset:function(){for(var t=this._key,e=t.words,r=t.sigBytes,i=this._S=[],n=0;n<256;n++)i[n]=n;n=0;for(var o=0;n<256;n++){var s=n%r,c=e[s>>>2]>>>24-s%4*8&255;o=(o+i[n]+c)%256;var a=i[n];i[n]=i[o],i[o]=a;}this._i=this._j=0;},_doProcessBlock:function(t,e){t[e]^=n.call(this);},keySize:8,ivSize:0});function n(){for(var t=this._S,e=this._i,r=this._j,i=0,n=0;n<4;n++){r=(r+t[e=(e+1)%256])%256;var o=t[e];t[e]=t[r],t[r]=o,i|=t[(t[e]+t[r])%256]<<24-8*n;}return this._i=e,this._j=r,i;}t.RC4=e._createHelper(i);var o=r.RC4Drop=i.extend({cfg:i.cfg.extend({drop:192}),_doReset:function(){i._doReset.call(this);for(var t=this.cfg.drop;0<t;t--)n.call(this);}});t.RC4Drop=e._createHelper(o);}(),mt.mode.CTRGladman=(st=(ot=mt.lib.BlockCipherMode.extend()).Encryptor=ot.extend({processBlock:function(t,e){var r,i=this._cipher,n=i.blockSize,o=this._iv,s=this._counter;o&&(s=this._counter=o.slice(0),this._iv=void 0),0===((r=s)[0]=Rt(r[0]))&&(r[1]=Rt(r[1]));var c=s.slice(0);i.encryptBlock(c,0);for(var a=0;a<n;a++)t[e+a]^=c[a];}}),ot.Decryptor=st,ot),at=(ct=mt).lib.StreamCipher,ht=ct.algo,lt=[],ft=[],ut=[],dt=ht.Rabbit=at.extend({_doReset:function(){for(var t=this._key.words,e=this.cfg.iv,r=0;r<4;r++)t[r]=16711935&(t[r]<<8|t[r]>>>24)|4278255360&(t[r]<<24|t[r]>>>8);var i=this._X=[t[0],t[3]<<16|t[2]>>>16,t[1],t[0]<<16|t[3]>>>16,t[2],t[1]<<16|t[0]>>>16,t[3],t[2]<<16|t[1]>>>16],n=this._C=[t[2]<<16|t[2]>>>16,4294901760&t[0]|65535&t[1],t[3]<<16|t[3]>>>16,4294901760&t[1]|65535&t[2],t[0]<<16|t[0]>>>16,4294901760&t[2]|65535&t[3],t[1]<<16|t[1]>>>16,4294901760&t[3]|65535&t[0]];for(r=this._b=0;r<4;r++)Et.call(this);for(r=0;r<8;r++)n[r]^=i[r+4&7];if(e){var o=e.words,s=o[0],c=o[1],a=16711935&(s<<8|s>>>24)|4278255360&(s<<24|s>>>8),h=16711935&(c<<8|c>>>24)|4278255360&(c<<24|c>>>8),l=a>>>16|4294901760&h,f=h<<16|65535&a;for(n[0]^=a,n[1]^=l,n[2]^=h,n[3]^=f,n[4]^=a,n[5]^=l,n[6]^=h,n[7]^=f,r=0;r<4;r++)Et.call(this);}},_doProcessBlock:function(t,e){var r=this._X;Et.call(this),lt[0]=r[0]^r[5]>>>16^r[3]<<16,lt[1]=r[2]^r[7]>>>16^r[5]<<16,lt[2]=r[4]^r[1]>>>16^r[7]<<16,lt[3]=r[6]^r[3]>>>16^r[1]<<16;for(var i=0;i<4;i++)lt[i]=16711935&(lt[i]<<8|lt[i]>>>24)|4278255360&(lt[i]<<24|lt[i]>>>8),t[e+i]^=lt[i];},blockSize:4,ivSize:2}),ct.Rabbit=at._createHelper(dt),mt.mode.CTR=(_t=(pt=mt.lib.BlockCipherMode.extend()).Encryptor=pt.extend({processBlock:function(t,e){var r=this._cipher,i=r.blockSize,n=this._iv,o=this._counter;n&&(o=this._counter=n.slice(0),this._iv=void 0);var s=o.slice(0);r.encryptBlock(s,0),o[i-1]=o[i-1]+1|0;for(var c=0;c<i;c++)t[e+c]^=s[c];}}),pt.Decryptor=_t,pt),yt=(vt=mt).lib.StreamCipher,gt=vt.algo,Bt=[],wt=[],kt=[],St=gt.RabbitLegacy=yt.extend({_doReset:function(){for(var t=this._key.words,e=this.cfg.iv,r=this._X=[t[0],t[3]<<16|t[2]>>>16,t[1],t[0]<<16|t[3]>>>16,t[2],t[1]<<16|t[0]>>>16,t[3],t[2]<<16|t[1]>>>16],i=this._C=[t[2]<<16|t[2]>>>16,4294901760&t[0]|65535&t[1],t[3]<<16|t[3]>>>16,4294901760&t[1]|65535&t[2],t[0]<<16|t[0]>>>16,4294901760&t[2]|65535&t[3],t[1]<<16|t[1]>>>16,4294901760&t[3]|65535&t[0]],n=this._b=0;n<4;n++)Mt.call(this);for(n=0;n<8;n++)i[n]^=r[n+4&7];if(e){var o=e.words,s=o[0],c=o[1],a=16711935&(s<<8|s>>>24)|4278255360&(s<<24|s>>>8),h=16711935&(c<<8|c>>>24)|4278255360&(c<<24|c>>>8),l=a>>>16|4294901760&h,f=h<<16|65535&a;for(i[0]^=a,i[1]^=l,i[2]^=h,i[3]^=f,i[4]^=a,i[5]^=l,i[6]^=h,i[7]^=f,n=0;n<4;n++)Mt.call(this);}},_doProcessBlock:function(t,e){var r=this._X;Mt.call(this),Bt[0]=r[0]^r[5]>>>16^r[3]<<16,Bt[1]=r[2]^r[7]>>>16^r[5]<<16,Bt[2]=r[4]^r[1]>>>16^r[7]<<16,Bt[3]=r[6]^r[3]>>>16^r[1]<<16;for(var i=0;i<4;i++)Bt[i]=16711935&(Bt[i]<<8|Bt[i]>>>24)|4278255360&(Bt[i]<<24|Bt[i]>>>8),t[e+i]^=Bt[i];},blockSize:4,ivSize:2}),vt.RabbitLegacy=yt._createHelper(St),mt.pad.ZeroPadding={pad:function(t,e){var r=4*e;t.clamp(),t.sigBytes+=r-(t.sigBytes%r||r);},unpad:function(t){var e=t.words,r=t.sigBytes-1;for(r=t.sigBytes-1;0<=r;r--)if(e[r>>>2]>>>24-r%4*8&255){t.sigBytes=r+1;break;}}},mt;}()}

var global$1 = (typeof global !== "undefined" ? global :
  typeof self !== "undefined" ? self :
  typeof window !== "undefined" ? window : {});

// shim for using process in browser
// based off https://github.com/defunctzombie/node-process/blob/master/browser.js

function defaultSetTimout() {
    throw new Error('setTimeout has not been defined');
}
function defaultClearTimeout () {
    throw new Error('clearTimeout has not been defined');
}
var cachedSetTimeout = defaultSetTimout;
var cachedClearTimeout = defaultClearTimeout;
if (typeof global$1.setTimeout === 'function') {
    cachedSetTimeout = setTimeout;
}
if (typeof global$1.clearTimeout === 'function') {
    cachedClearTimeout = clearTimeout;
}

function runTimeout(fun) {
    if (cachedSetTimeout === setTimeout) {
        //normal enviroments in sane situations
        return setTimeout(fun, 0);
    }
    // if setTimeout wasn't available but was latter defined
    if ((cachedSetTimeout === defaultSetTimout || !cachedSetTimeout) && setTimeout) {
        cachedSetTimeout = setTimeout;
        return setTimeout(fun, 0);
    }
    try {
        // when when somebody has screwed with setTimeout but no I.E. maddness
        return cachedSetTimeout(fun, 0);
    } catch(e){
        try {
            // When we are in I.E. but the script has been evaled so I.E. doesn't trust the global object when called normally
            return cachedSetTimeout.call(null, fun, 0);
        } catch(e){
            // same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error
            return cachedSetTimeout.call(this, fun, 0);
        }
    }


}
function runClearTimeout(marker) {
    if (cachedClearTimeout === clearTimeout) {
        //normal enviroments in sane situations
        return clearTimeout(marker);
    }
    // if clearTimeout wasn't available but was latter defined
    if ((cachedClearTimeout === defaultClearTimeout || !cachedClearTimeout) && clearTimeout) {
        cachedClearTimeout = clearTimeout;
        return clearTimeout(marker);
    }
    try {
        // when when somebody has screwed with setTimeout but no I.E. maddness
        return cachedClearTimeout(marker);
    } catch (e){
        try {
            // When we are in I.E. but the script has been evaled so I.E. doesn't  trust the global object when called normally
            return cachedClearTimeout.call(null, marker);
        } catch (e){
            // same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error.
            // Some versions of I.E. have different rules for clearTimeout vs setTimeout
            return cachedClearTimeout.call(this, marker);
        }
    }



}
var queue = [];
var draining = false;
var currentQueue;
var queueIndex = -1;

function cleanUpNextTick() {
    if (!draining || !currentQueue) {
        return;
    }
    draining = false;
    if (currentQueue.length) {
        queue = currentQueue.concat(queue);
    } else {
        queueIndex = -1;
    }
    if (queue.length) {
        drainQueue();
    }
}

function drainQueue() {
    if (draining) {
        return;
    }
    var timeout = runTimeout(cleanUpNextTick);
    draining = true;

    var len = queue.length;
    while(len) {
        currentQueue = queue;
        queue = [];
        while (++queueIndex < len) {
            if (currentQueue) {
                currentQueue[queueIndex].run();
            }
        }
        queueIndex = -1;
        len = queue.length;
    }
    currentQueue = null;
    draining = false;
    runClearTimeout(timeout);
}
function nextTick(fun) {
    var args = new Array(arguments.length - 1);
    if (arguments.length > 1) {
        for (var i = 1; i < arguments.length; i++) {
            args[i - 1] = arguments[i];
        }
    }
    queue.push(new Item(fun, args));
    if (queue.length === 1 && !draining) {
        runTimeout(drainQueue);
    }
}
// v8 likes predictible objects
function Item(fun, array) {
    this.fun = fun;
    this.array = array;
}
Item.prototype.run = function () {
    this.fun.apply(null, this.array);
};
var title = 'browser';
var platform = 'browser';
var browser = true;
var env = {};
var argv = [];
var version = ''; // empty string to avoid regexp issues
var versions = {};
var release = {};
var config = {};

function noop() {}

var on = noop;
var addListener = noop;
var once = noop;
var off = noop;
var removeListener = noop;
var removeAllListeners = noop;
var emit = noop;

function binding(name) {
    throw new Error('process.binding is not supported');
}

function cwd () { return '/' }
function chdir (dir) {
    throw new Error('process.chdir is not supported');
}function umask() { return 0; }

// from https://github.com/kumavis/browser-process-hrtime/blob/master/index.js
var performance = global$1.performance || {};
var performanceNow =
  performance.now        ||
  performance.mozNow     ||
  performance.msNow      ||
  performance.oNow       ||
  performance.webkitNow  ||
  function(){ return (new Date()).getTime() };

// generate timestamp or delta
// see http://nodejs.org/api/process.html#process_process_hrtime
function hrtime(previousTimestamp){
  var clocktime = performanceNow.call(performance)*1e-3;
  var seconds = Math.floor(clocktime);
  var nanoseconds = Math.floor((clocktime%1)*1e9);
  if (previousTimestamp) {
    seconds = seconds - previousTimestamp[0];
    nanoseconds = nanoseconds - previousTimestamp[1];
    if (nanoseconds<0) {
      seconds--;
      nanoseconds += 1e9;
    }
  }
  return [seconds,nanoseconds]
}

var startTime = new Date();
function uptime() {
  var currentTime = new Date();
  var dif = currentTime - startTime;
  return dif / 1000;
}

var browser$1 = {
  nextTick: nextTick,
  title: title,
  browser: browser,
  env: env,
  argv: argv,
  version: version,
  versions: versions,
  on: on,
  addListener: addListener,
  once: once,
  off: off,
  removeListener: removeListener,
  removeAllListeners: removeAllListeners,
  emit: emit,
  binding: binding,
  cwd: cwd,
  chdir: chdir,
  umask: umask,
  hrtime: hrtime,
  platform: platform,
  release: release,
  config: config,
  uptime: uptime
};

var process = browser$1;

/*
 bcrypt.js (c) 2013 Daniel Wirtz <dcode@dcode.io>
 Released under the Apache License, Version 2.0
 see: https://github.com/dcodeIO/bcrypt.js for details
*/
function bcrypt(){function n(n){try{var r;return (self.crypto||self.msCrypto).getRandomValues(r=new Uint32Array(n)),Array.prototype.slice.call(r);}catch(n){}if(!s)throw Error("Neither WebCryptoAPI nor a crypto module is available. Use bcrypt.setRandomFallback to set an alternative");return s(n);}function r(n,r){for(var t=0,e=0,o=0,i=n.length;o<i;++o)n.charCodeAt(o)===r.charCodeAt(o)?++t:++e;return !(0>t)&&0===e;}function t(n,r){var t,e,o=0,i=[];if(0>=r||r>n.length)throw Error("Illegal len: "+r);for(;o<r;){if(t=255&n[o++],i.push(g[t>>2&63]),t=(3&t)<<4,o>=r){i.push(g[63&t]);break;}if(t|=(e=255&n[o++])>>4&15,i.push(g[63&t]),t=(15&e)<<2,o>=r){i.push(g[63&t]);break;}t|=(e=255&n[o++])>>6&3,i.push(g[63&t]),i.push(g[63&e]);}return i.join("");}function e(n,r){var t,e,o,i=0,l=n.length,u=0,f=[];if(0>=r)throw Error("Illegal len: "+r);for(;i<l-1&&u<r&&(t=(o=n.charCodeAt(i++))<p.length?p[o]:-1,e=(o=n.charCodeAt(i++))<p.length?p[o]:-1,-1!=t&&-1!=e)&&(o=t<<2>>>0,o|=(48&e)>>4,f.push(y(o)),!(++u>=r||i>=l))&&-1!=(t=(o=n.charCodeAt(i++))<p.length?p[o]:-1)&&(o=(15&e)<<4>>>0,o|=(60&t)>>2,f.push(y(o)),!(++u>=r||i>=l));)e=(o=n.charCodeAt(i++))<p.length?p[o]:-1,o=(3&t)<<6>>>0,o|=e,f.push(y(o)),++u;for(l=[],i=0;i<u;i++)l.push(f[i].charCodeAt(0));return l;}function o(n,r,t,e){for(var o,i=n[r],l=n[r+1],u=(i=i^t[0],0);14>=u;)o=e[i>>24&255],o+=e[256|i>>16&255],o^=e[512|i>>8&255],o=e[(l=l^(o+=e[768|255&i])^t[++u])>>24&255],o+=e[256|l>>16&255],o^=e[512|l>>8&255],i=i^(o+=e[768|255&l])^t[++u];return n[r]=l^t[17],n[r+1]=i,n;}function i(n,r){for(var t=0,e=0;4>t;++t)e=e<<8|255&n[r],r=(r+1)%n.length;return {key:e,a:r};}function l(n,r,t){for(var e,l=0,u=[0,0],f=r.length,a=t.length,s=0;s<f;s++)l=(e=i(n,l)).a,r[s]^=e.key;for(s=0;s<f;s+=2)u=o(u,0,r,t),r[s]=u[0],r[s+1]=u[1];for(s=0;s<a;s+=2)u=o(u,0,r,t),t[s]=u[0],t[s+1]=u[1];}function u(n,r,t,e,u){function f(){if(u&&u(d/t),!(d<t)){for(d=0;64>d;d++)for(g=0;g<c>>1;g++)o(s,g<<1,p,y);for(i=[],d=0;d<c;d++)i.push((s[d]>>24&255)>>>0),i.push((s[d]>>16&255)>>>0),i.push((s[d]>>8&255)>>>0),i.push((255&s[d])>>>0);return e?void e(null,i):i;}for(var i=Date.now();d<t&&(d+=1,l(n,p,y),l(r,p,y),!(100<Date.now()-i)););e&&h(f);}var a,s=m.slice(),c=s.length;if(4>t||31<t){if(a=Error("Illegal number of rounds (4-31): "+t),e)return void h(e.bind(this,a));throw a;}if(16!==r.length){if(a=Error("Illegal salt length: "+r.length+" != 16"),e)return void h(e.bind(this,a));throw a;}t=1<<t>>>0;var g,p=v.slice(),y=b.slice(),d=0;if(function(n,r,t,e){for(var l,u=0,f=[0,0],a=t.length,s=e.length,c=0;c<a;c++)u=(l=i(r,u)).a,t[c]^=l.key;for(c=u=0;c<a;c+=2)u=(l=i(n,u)).a,f[0]^=l.key,u=(l=i(n,u)).a,f[1]^=l.key,f=o(f,0,t,e),t[c]=f[0],t[c+1]=f[1];for(c=0;c<s;c+=2)u=(l=i(n,u)).a,f[0]^=l.key,u=(l=i(n,u)).a,f[1]^=l.key,f=o(f,0,t,e),e[c]=f[0],e[c+1]=f[1];}(r,n,p,y),void 0!==e)f();else for(;;)if(void 0!==(a=f()))return a||[];}function f(n,r,o,i){function l(n){var r=[];return r.push("$2"),"a"<=f&&r.push(f),r.push("$"),10>s&&r.push("0"),r.push(s.toString()),r.push("$"),r.push(t(c,c.length)),r.push(t(n,4*m.length-1)),r.join("");}if("string"!=typeof n||"string"!=typeof r){if(i=Error("Invalid string / salt: Not a string"),o)return void h(o.bind(this,i));throw i;}var f,a;if("$"!==r.charAt(0)||"2"!==r.charAt(1)){if(i=Error("Invalid salt version: "+r.substring(0,2)),o)return void h(o.bind(this,i));throw i;}if("$"===r.charAt(2))f=String.fromCharCode(0),a=3;else {if("a"!==(f=r.charAt(2))&&"b"!==f&&"y"!==f||"$"!==r.charAt(3)){if(i=Error("Invalid salt revision: "+r.substring(2,4)),o)return void h(o.bind(this,i));throw i;}a=4;}if("$"<r.charAt(a+2)){if(i=Error("Missing salt rounds"),o)return void h(o.bind(this,i));throw i;}var s=10*parseInt(r.substring(a,a+1),10)+parseInt(r.substring(a+1,a+2),10);r=r.substring(a+3,a+25),n=function(n){var r=[],t=0;return d.f((function(){return t>=n.length?null:n.charCodeAt(t++);}),(function(n){r.push(n);})),r;}(n+("a"<=f?"\0":""));var c=e(r,16);if(void 0===o)return l(u(n,c,s));u(n,c,s,(function(n,r){n?o(n,null):o(null,l(r));}),i);}var a={},s=null;try{n(1);}catch(n){}s=null,a.l=function(n){s=n;},a.genSaltSync=function(r,e){if("number"!=typeof(r=r||10))throw Error("Illegal arguments: "+typeof r+", "+typeof e);4>r?r=4:31<r&&(r=31);var o=[];return o.push("$2a$"),10>r&&o.push("0"),o.push(r.toString()),o.push("$"),o.push(t(n(16),16)),o.join("");},a.genSalt=function(n,r,t){function e(r){h((function(){if("number"!=typeof n)r(Error("Illegal arguments: "+typeof n));else try{r(null,a.genSaltSync(n));}catch(n){r(n);}}));}if("function"==typeof r&&(t=r,r=void 0),"function"==typeof n&&(t=n,n=10),!t)return new Promise((function(n,r){e((function(t,e){t?r(t):n(e);}));}));if("function"!=typeof t)throw Error("Illegal callback: "+typeof t);e(t);},a.hashSync=function(n,r){if(void 0===r&&(r=10),"number"==typeof r&&(r=a.genSaltSync(r)),"string"!=typeof n||"string"!=typeof r)throw Error("Illegal arguments: "+typeof n+", "+typeof r);return f(n,r);},a.hash=function(n,r,t,e){function o(t){"string"==typeof n&&"number"==typeof r?a.genSalt(r,(function(r,o){f(n,o,t,e);})):"string"==typeof n&&"string"==typeof r?f(n,r,t,e):h(t.bind(this,Error("Illegal arguments: "+typeof n+", "+typeof r)));}if(!t)return new Promise((function(n,r){o((function(t,e){t?r(t):n(e);}));}));if("function"!=typeof t)throw Error("Illegal callback: "+typeof t);o(t);},a.compareSync=function(n,t){if("string"!=typeof n||"string"!=typeof t)throw Error("Illegal arguments: "+typeof n+", "+typeof t);return 60===t.length&&r(a.hashSync(n,t.substr(0,t.length-31)),t);},a.compare=function(n,t,e,o){function i(e){"string"!=typeof n||"string"!=typeof t?h(e.bind(this,Error("Illegal arguments: "+typeof n+", "+typeof t))):60!==t.length?h(e.bind(this,null,!1)):a.hash(n,t.substr(0,29),(function(n,o){n?e(n):e(null,r(o,t));}),o);}if(!e)return new Promise((function(n,r){i((function(t,e){t?r(t):n(e);}));}));if("function"!=typeof e)throw Error("Illegal callback: "+typeof e);i(e);},a.getRounds=function(n){if("string"!=typeof n)throw Error("Illegal arguments: "+typeof n);return parseInt(n.split("$")[2],10);},a.getSalt=function(n){if("string"!=typeof n)throw Error("Illegal arguments: "+typeof n);if(60!==n.length)throw Error("Illegal hash length: "+n.length+" != 60");return n.substring(0,29);};var c,h="undefined"!=typeof process&&process&&"function"==typeof process.nextTick?"function"==typeof setImmediate?setImmediate:process.nextTick:setTimeout,g="./ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789".split(""),p=[-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,0,1,54,55,56,57,58,59,60,61,62,63,-1,-1,-1,-1,-1,-1,-1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,-1,-1,-1,-1,-1,-1,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,-1,-1,-1,-1,-1],y=String.fromCharCode,d=c={h:1114111,g:function(n,r){var t=null;for("number"==typeof n&&(t=n,n=function(){return null;});null!==t||null!==(t=n());)128>t?r(127&t):(2048>t?r(t>>6&31|192):(65536>t?r(t>>12&15|224):(r(t>>18&7|240),r(t>>12&63|128)),r(t>>6&63|128)),r(63&t|128)),t=null;},e:function(n,r){function t(n){n=n.slice(0,n.indexOf(null));var r=Error(n.toString());throw r.name="TruncatedError",r.bytes=n,r;}for(var e,o,i,l;null!==(e=n());)if(0==(128&e))r(e);else if(192==(224&e))null===(o=n())&&t([e,o]),r((31&e)<<6|63&o);else if(224==(240&e))null!==(o=n())&&null!==(i=n())||t([e,o,i]),r((15&e)<<12|(63&o)<<6|63&i);else {if(240!=(248&e))throw RangeError("Illegal starting byte: "+e);null!==(o=n())&&null!==(i=n())&&null!==(l=n())||t([e,o,i,l]),r((7&e)<<18|(63&o)<<12|(63&i)<<6|63&l);}},b:function(n,r){for(var t,e=null;null!==(t=null!==e?e:n());)55296<=t&&57343>=t&&null!==(e=n())&&56320<=e&&57343>=e?(r(1024*(t-55296)+e-56320+65536),e=null):r(t);null!==e&&r(e);},d:function(n,r){var t=null;for("number"==typeof n&&(t=n,n=function(){return null;});null!==t||null!==(t=n());)65535>=t?r(t):(r(55296+((t-=65536)>>10)),r(t%1024+56320)),t=null;},f:function(n,r){c.b(n,(function(n){c.g(n,r);}));},k:function(n,r){c.e(n,(function(n){c.d(n,r);}));},c:function(n){return 128>n?1:2048>n?2:65536>n?3:4;},j:function(n){for(var r,t=0;null!==(r=n());)t+=c.c(r);return t;},i:function(n){var r=0,t=0;return c.b(n,(function(n){++r,t+=c.c(n);})),[r,t];}};Date.now=Date.now||function(){return +new Date;};var v=[608135816,2242054355,320440878,57701188,2752067618,698298832,137296536,3964562569,1160258022,953160567,3193202383,887688300,3232508343,3380367581,1065670069,3041331479,2450970073,2306472731],b=[3509652390,2564797868,805139163,3491422135,3101798381,1780907670,3128725573,4046225305,614570311,3012652279,134345442,2240740374,1667834072,1901547113,2757295779,4103290238,227898511,1921955416,1904987480,2182433518,2069144605,3260701109,2620446009,720527379,3318853667,677414384,3393288472,3101374703,2390351024,1614419982,1822297739,2954791486,3608508353,3174124327,2024746970,1432378464,3864339955,2857741204,1464375394,1676153920,1439316330,715854006,3033291828,289532110,2706671279,2087905683,3018724369,1668267050,732546397,1947742710,3462151702,2609353502,2950085171,1814351708,2050118529,680887927,999245976,1800124847,3300911131,1713906067,1641548236,4213287313,1216130144,1575780402,4018429277,3917837745,3693486850,3949271944,596196993,3549867205,258830323,2213823033,772490370,2760122372,1774776394,2652871518,566650946,4142492826,1728879713,2882767088,1783734482,3629395816,2517608232,2874225571,1861159788,326777828,3124490320,2130389656,2716951837,967770486,1724537150,2185432712,2364442137,1164943284,2105845187,998989502,3765401048,2244026483,1075463327,1455516326,1322494562,910128902,469688178,1117454909,936433444,3490320968,3675253459,1240580251,122909385,2157517691,634681816,4142456567,3825094682,3061402683,2540495037,79693498,3249098678,1084186820,1583128258,426386531,1761308591,1047286709,322548459,995290223,1845252383,2603652396,3431023940,2942221577,3202600964,3727903485,1712269319,422464435,3234572375,1170764815,3523960633,3117677531,1434042557,442511882,3600875718,1076654713,1738483198,4213154764,2393238008,3677496056,1014306527,4251020053,793779912,2902807211,842905082,4246964064,1395751752,1040244610,2656851899,3396308128,445077038,3742853595,3577915638,679411651,2892444358,2354009459,1767581616,3150600392,3791627101,3102740896,284835224,4246832056,1258075500,768725851,2589189241,3069724005,3532540348,1274779536,3789419226,2764799539,1660621633,3471099624,4011903706,913787905,3497959166,737222580,2514213453,2928710040,3937242737,1804850592,3499020752,2949064160,2386320175,2390070455,2415321851,4061277028,2290661394,2416832540,1336762016,1754252060,3520065937,3014181293,791618072,3188594551,3933548030,2332172193,3852520463,3043980520,413987798,3465142937,3030929376,4245938359,2093235073,3534596313,375366246,2157278981,2479649556,555357303,3870105701,2008414854,3344188149,4221384143,3956125452,2067696032,3594591187,2921233993,2428461,544322398,577241275,1471733935,610547355,4027169054,1432588573,1507829418,2025931657,3646575487,545086370,48609733,2200306550,1653985193,298326376,1316178497,3007786442,2064951626,458293330,2589141269,3591329599,3164325604,727753846,2179363840,146436021,1461446943,4069977195,705550613,3059967265,3887724982,4281599278,3313849956,1404054877,2845806497,146425753,1854211946,1266315497,3048417604,3681880366,3289982499,290971e4,1235738493,2632868024,2414719590,3970600049,1771706367,1449415276,3266420449,422970021,1963543593,2690192192,3826793022,1062508698,1531092325,1804592342,2583117782,2714934279,4024971509,1294809318,4028980673,1289560198,2221992742,1669523910,35572830,157838143,1052438473,1016535060,1802137761,1753167236,1386275462,3080475397,2857371447,1040679964,2145300060,2390574316,1461121720,2956646967,4031777805,4028374788,33600511,2920084762,1018524850,629373528,3691585981,3515945977,2091462646,2486323059,586499841,988145025,935516892,3367335476,2599673255,2839830854,265290510,3972581182,2759138881,3795373465,1005194799,847297441,406762289,1314163512,1332590856,1866599683,4127851711,750260880,613907577,1450815602,3165620655,3734664991,3650291728,3012275730,3704569646,1427272223,778793252,1343938022,2676280711,2052605720,1946737175,3164576444,3914038668,3967478842,3682934266,1661551462,3294938066,4011595847,840292616,3712170807,616741398,312560963,711312465,1351876610,322626781,1910503582,271666773,2175563734,1594956187,70604529,3617834859,1007753275,1495573769,4069517037,2549218298,2663038764,504708206,2263041392,3941167025,2249088522,1514023603,1998579484,1312622330,694541497,2582060303,2151582166,1382467621,776784248,2618340202,3323268794,2497899128,2784771155,503983604,4076293799,907881277,423175695,432175456,1378068232,4145222326,3954048622,3938656102,3820766613,2793130115,2977904593,26017576,3274890735,3194772133,1700274565,1756076034,4006520079,3677328699,720338349,1533947780,354530856,688349552,3973924725,1637815568,332179504,3949051286,53804574,2852348879,3044236432,1282449977,3583942155,3416972820,4006381244,1617046695,2628476075,3002303598,1686838959,431878346,2686675385,1700445008,1080580658,1009431731,832498133,3223435511,2605976345,2271191193,2516031870,1648197032,4164389018,2548247927,300782431,375919233,238389289,3353747414,2531188641,2019080857,1475708069,455242339,2609103871,448939670,3451063019,1395535956,2413381860,1841049896,1491858159,885456874,4264095073,4001119347,1565136089,3898914787,1108368660,540939232,1173283510,2745871338,3681308437,4207628240,3343053890,4016749493,1699691293,1103962373,3625875870,2256883143,3830138730,1031889488,3479347698,1535977030,4236805024,3251091107,2132092099,1774941330,1199868427,1452454533,157007616,2904115357,342012276,595725824,1480756522,206960106,497939518,591360097,863170706,2375253569,3596610801,1814182875,2094937945,3421402208,1082520231,3463918190,2785509508,435703966,3908032597,1641649973,2842273706,3305899714,1510255612,2148256476,2655287854,3276092548,4258621189,236887753,3681803219,274041037,1734335097,3815195456,3317970021,1899903192,1026095262,4050517792,356393447,2410691914,3873677099,3682840055,3913112168,2491498743,4132185628,2489919796,1091903735,1979897079,3170134830,3567386728,3557303409,857797738,1136121015,1342202287,507115054,2535736646,337727348,3213592640,1301675037,2528481711,1895095763,1721773893,3216771564,62756741,2142006736,835421444,2531993523,1442658625,3659876326,2882144922,676362277,1392781812,170690266,3921047035,1759253602,3611846912,1745797284,664899054,1329594018,3901205900,3045908486,2062866102,2865634940,3543621612,3464012697,1080764994,553557557,3656615353,3996768171,991055499,499776247,1265440854,648242737,3940784050,980351604,3713745714,1749149687,3396870395,4211799374,3640570775,1161844396,3125318951,1431517754,545492359,4268468663,3499529547,1437099964,2702547544,3433638243,2581715763,2787789398,1060185593,1593081372,2418618748,4260947970,69676912,2159744348,86519011,2512459080,3838209314,1220612927,3339683548,133810670,1090789135,1078426020,1569222167,845107691,3583754449,4072456591,1091646820,628848692,1613405280,3757631651,526609435,236106946,48312990,2942717905,3402727701,1797494240,859738849,992217954,4005476642,2243076622,3870952857,3732016268,765654824,3490871365,2511836413,1685915746,3888969200,1414112111,2273134842,3281911079,4080962846,172450625,2569994100,980381355,4109958455,2819808352,2716589560,2568741196,3681446669,3329971472,1835478071,660984891,3704678404,4045999559,3422617507,3040415634,1762651403,1719377915,3470491036,2693910283,3642056355,3138596744,1364962596,2073328063,1983633131,926494387,3423689081,2150032023,4096667949,1749200295,3328846651,309677260,2016342300,1779581495,3079819751,111262694,1274766160,443224088,298511866,1025883608,3806446537,1145181785,168956806,3641502830,3584813610,1689216846,3666258015,3200248200,1692713982,2646376535,4042768518,1618508792,1610833997,3523052358,4130873264,2001055236,3610705100,2202168115,4028541809,2961195399,1006657119,2006996926,3186142756,1430667929,3210227297,1314452623,4074634658,4101304120,2273951170,1399257539,3367210612,3027628629,1190975929,2062231137,2333990788,2221543033,2438960610,1181637006,548689776,2362791313,3372408396,3104550113,3145860560,296247880,1970579870,3078560182,3769228297,1714227617,3291629107,3898220290,166772364,1251581989,493813264,448347421,195405023,2709975567,677966185,3703036547,1463355134,2715995803,1338867538,1343315457,2802222074,2684532164,233230375,2599980071,2000651841,3277868038,1638401717,4028070440,3237316320,6314154,819756386,300326615,590932579,1405279636,3267499572,3150704214,2428286686,3959192993,3461946742,1862657033,1266418056,963775037,2089974820,2263052895,1917689273,448879540,3550394620,3981727096,150775221,3627908307,1303187396,508620638,2975983352,2726630617,1817252668,1876281319,1457606340,908771278,3720792119,3617206836,2455994898,1729034894,1080033504,976866871,3556439503,2881648439,1522871579,1555064734,1336096578,3548522304,2579274686,3574697629,3205460757,3593280638,3338716283,3079412587,564236357,2993598910,1781952180,1464380207,3163844217,3332601554,1699332808,1393555694,1183702653,3581086237,1288719814,691649499,2847557200,2895455976,3193889540,2717570544,1781354906,1676643554,2592534050,3230253752,1126444790,2770207658,2633158820,2210423226,2615765581,2414155088,3127139286,673620729,2805611233,1269405062,4015350505,3341807571,4149409754,1057255273,2012875353,2162469141,2276492801,2601117357,993977747,3918593370,2654263191,753973209,36408145,2530585658,25011837,3520020182,2088578344,530523599,2918365339,1524020338,1518925132,3760827505,3759777254,1202760957,3985898139,3906192525,674977740,4174734889,2031300136,2019492241,3983892565,4153806404,3822280332,352677332,2297720250,60907813,90501309,3286998549,1016092578,2535922412,2839152426,457141659,509813237,4120667899,652014361,1966332200,2975202805,55981186,2327461051,676427537,3255491064,2882294119,3433927263,1307055953,942726286,933058658,2468411793,3933900994,4215176142,1361170020,2001714738,2830558078,3274259782,1222529897,1679025792,2729314320,3714953764,1770335741,151462246,3013232138,1682292957,1483529935,471910574,1539241949,458788160,3436315007,1807016891,3718408830,978976581,1043663428,3165965781,1927990952,4200891579,2372276910,3208408903,3533431907,1412390302,2931980059,4132332400,1947078029,3881505623,4168226417,2941484381,1077988104,1320477388,886195818,18198404,3786409e3,2509781533,112762804,3463356488,1866414978,891333506,18488651,661792760,1628790961,3885187036,3141171499,876946877,2693282273,1372485963,791857591,2686433993,3759982718,3167212022,3472953795,2716379847,445679433,3561995674,3504004811,3574258232,54117162,3331405415,2381918588,3769707343,4154350007,1140177722,4074052095,668550556,3214352940,367459370,261225585,2610173221,4209349473,3468074219,3265815641,314222801,3066103646,3808782860,282218597,3406013506,3773591054,379116347,1285071038,846784868,2669647154,3771962079,3550491691,2305946142,453669953,1268987020,3317592352,3279303384,3744833421,2610507566,3859509063,266596637,3847019092,517658769,3462560207,3443424879,370717030,4247526661,2224018117,4143653529,4112773975,2788324899,2477274417,1456262402,2901442914,1517677493,1846949527,2295493580,3734397586,2176403920,1280348187,1908823572,3871786941,846861322,1172426758,3287448474,3383383037,1655181056,3139813346,901632758,1897031941,2986607138,3066810236,3447102507,1393639104,373351379,950779232,625454576,3124240540,4148612726,2007998917,544563296,2244738638,2330496472,2058025392,1291430526,424198748,50039436,29584100,3605783033,2429876329,2791104160,1057563949,3255363231,3075367218,3463963227,1469046755,985887462],m=[1332899944,1700884034,1701343084,1684370003,1668446532,1869963892];return a.encodeBase64=t,a.decodeBase64=e,a;}

const CryptoJS = cryptojs();
const Bcrypt = bcrypt();
/**
 * Encodes an input into Base64
 * @param inputStr Base64 input to decode
 */
const encodeString = (inputStr) => {
    const wordArr = CryptoJS.enc.Utf8.parse(inputStr);
    const result = CryptoJS.enc.Base64.stringify(wordArr);
    return result;
};
/**
 * Decodes a Base64 input
 * @param inputStr Base64 input to decode
 */
const decodeString = (inputStr) => {
    const keyb64 = inputStr.toString(CryptoJS.enc.Base64);
    const result = CryptoJS.enc.Base64.parse(keyb64).toString(CryptoJS.enc.Utf8);
    return JSON.parse(result);
};
/**
 * Generates a JWT token
 * @param data Payload to include in the token
 * @param expirationInMinutes Expiration of the token (in minutes)
 */
const createJWT = (data, expirationInMinutes = 0) => {
    if (expirationInMinutes > 0) {
        data.exp = Date.now() + (expirationInMinutes * 60 * 1000);
    }
    const header = { alg: "HS256", typ: "JWT" };
    const headerStr = encodeString(JSON.stringify(header));
    const payloadStr = encodeString(JSON.stringify(data));
    const signature = sign(headerStr + "." + payloadStr);
    const result = `${headerStr}.${payloadStr}.${signature}`;
    return result;
};
/**
 * Parses a JWT token
 * @param token JWT token
 */
const parseJWT = (token, disableClientIdCheck) => {
    if (!token) {
        return;
    }
    const [header, payload, signature] = token.split(".");
    const headerPayloadStr = `${header}.${payload}`;
    /**
     * Check for signature early
     */
    if (signature === sign(headerPayloadStr)) {
        const resPayload = decodeString(payload);
        const isExpired = (resPayload.exp && Date.now() > resPayload.exp);
        const isSameClient = (disableClientIdCheck ||
            resPayload.clientId === getClientId() ||
            !resPayload.clientId);
        if (isSameClient && !isExpired) {
            return resPayload;
        }
    }
};
/**
 * Generates a bcrypt hash of a given message
 * @param message Message to hash
 */
const hash_bcrypt = (message) => {
    const salt = Bcrypt.genSaltSync(7);
    const hash = Bcrypt.hashSync(message, salt);
    return hash;
};
/**
 * Compares a raw value with a bcrypt hash
 * @param message Raw input to compare
 * @param hash Hash to compare against
 */
const compare_bcrypt = (message, hash) => {
    return Bcrypt.compareSync(message, hash);
};
/**
 * Creates a Base64 hash signed with the Apiker's installation secret key
 */
const sign = (message) => {
    if (!apiker.env.APIKER_SECRET_KEY) {
        throw new Error("env.APIKER_SECRET_KEY is undefined. Please consult the documentation");
    }
    const signature = CryptoJS.HmacSHA256(message, apiker.env.APIKER_SECRET_KEY);
    return CryptoJS.enc.Base64.stringify(signature);
};
/**
 * Creates a SHA256 hash signed with the Apiker's installation secret key
 */
const sign_sha256 = (message) => {
    if (!apiker.env.APIKER_SECRET_KEY) {
        throw new Error("env.APIKER_SECRET_KEY is undefined. Please consult the documentation");
    }
    return CryptoJS.HmacSHA256(message, apiker.env.APIKER_SECRET_KEY).toString(CryptoJS.enc.Hex);
};
/**
 * Creates a SHA1 hash signed with the Apiker's installation secret key
 */
const sign_sha1 = (message) => {
    if (!apiker.env.APIKER_SECRET_KEY) {
        throw new Error("env.APIKER_SECRET_KEY is undefined. Please consult the documentation");
    }
    return CryptoJS.HmacSHA1(message, apiker.env.APIKER_SECRET_KEY).toString(CryptoJS.enc.Hex);
};
/**
 * Creates a random SHA256 hash
 */
const randomHash = () => {
    const wordArray = CryptoJS.lib.WordArray.random(16);
    return CryptoJS.SHA256(wordArray).toString(CryptoJS.enc.Hex);
};
/**
 * Creates a random SHA1 hash
 */
const randomHash_SHA1 = () => {
    const wordArray = CryptoJS.lib.WordArray.random(16);
    return CryptoJS.SHA1(wordArray).toString(CryptoJS.enc.Hex);
};
/**
 * Generating a clientId
 * This value is returned to client and not stored
 */
const getClientId = () => {
    const { headers } = apiker.requestParams;
    const ip = headers.get("CF-Connecting-IP");
    const userAgent = headers.get("User-Agent") || "";
    const clientId = sign_sha1(ip + userAgent);
    return clientId;
};
/**
 * Retrieves the auth tokens from the request headers or cookies.
 */
const extractToken = () => {
    const { headers, request } = apiker.requestParams;
    const url = new URL(request.url);
    const params = new URLSearchParams(url.search);
    const authHeader = headers?.get("Authorization");
    const cookie = parse_1(headers?.get("Cookie") || "");
    const authCookie = cookie["apikerToken"] || "";
    const authParam = params.get("t") ? `Bearer ${params.get("t")}` : "";
    const authValue = (authHeader || authCookie || authParam);
    if (authValue?.includes("Bearer")) {
        return authValue.split(" ")[1];
    }
    else {
        return "";
    }
};
/**
 * Fetches the current user by checking for the auth token in the request headers or in the cookies.
 */
const getCurrentUser = async (disableClientIdCheck) => {
    const { state } = apiker.requestParams;
    const token = extractToken();
    if (!token) {
        return;
    }
    const payload = parseJWT(token, disableClientIdCheck);
    if (!payload) {
        return;
    }
    const { sub: userId } = payload;
    const user = await state(OBN.USERS, userId).get(userId);
    if (user?.password) {
        return user;
    }
};
/**
 * Checks whether a given user is an admin
 */
const isUserAdmin = async (userId = "") => {
    if (!userId)
        return false;
    const { state } = apiker.requestParams;
    const adminIds = await state(OBN.COMMON).get("adminIds");
    return adminIds.includes(userId);
};
/**
 * Checks whether the current user is an admin
 */
const isCurrentUserAdmin = async () => {
    const user = await getCurrentUser();
    return await isUserAdmin(user?.id);
};
/**
 * Generates auth tokens for a given user
 * @param userId The user's ID
 * @param expirationInMinutes The expiration time for the action token. The refresh token does not expire.
 */
const getTokens = (userId, expirationInMinutes = AUTH_TOKEN_DURATION_MINS_DEFAULT) => {
    const clientId = getClientId();
    const token = createJWT({ sub: userId, clientId }, expirationInMinutes);
    const refreshToken = createJWT({ sub: userId, clientId });
    return { userId, token, refreshToken };
};
/**
 * Gets the client's IP
 */
const getRawIp = () => {
    const { headers } = apiker.requestParams;
    return headers.get("CF-Connecting-IP");
};
/**
 * Gets the client's IP signed in SHA1 format.
 */
const getSignedIp = () => {
    return sign_sha1(getRawIp());
};

const registerUser = async ({ body }) => {
    const { email, password } = body;
    const user = await registerUserAction(email, password);
    if (!user?.id) {
        return res_400();
    }
    const tokens = getTokens(user?.id);
    if (tokens) {
        return res({ email: user.email, ...tokens });
    }
    else {
        return res_400();
    }
};
const registerUserAction = async (email, password, extraParams = {}) => {
    const { state } = apiker.requestParams;
    if (!isEmail(email) || !isRequiredLength(password)) {
        return;
    }
    /**
     * Check if user exists
     */
    const currentUserId = await state(OBN.EMAILTOUUID, email).get(email);
    if (currentUserId) {
        apiker.responseParams.setError(AUTH_ERRORS.USER_EXISTS);
        return;
    }
    const id = randomHash_SHA1();
    if (!id) {
        apiker.responseParams.setError(AUTH_ERRORS.ID_GEN_ERROR);
        return;
    }
    const signedPassword = hash_bcrypt(password);
    const user = {
        id,
        email,
        password: signedPassword,
        verified: false,
        createdAt: Date.now(),
        updatedAt: Date.now(),
        ...extraParams,
    };
    /**
     * Create user
     */
    await state(OBN.USERS, id).put({ [id]: user });
    /**
     * Create EmailToUUID entry
     */
    await state(OBN.EMAILTOUUID, email).put({ [email]: id });
    /**
     * If it's an admin, create an entry in admin table
     */
    if (extraParams.role === "admin") {
        const adminIds = await state(OBN.COMMON).get("adminIds") || [];
        adminIds.push(id);
        await state(OBN.COMMON).put({ adminIds });
    }
    return user;
};

const loginUser = async ({ body }) => {
    const { email, password } = body;
    const tokens = await loginUserAction(email, password);
    if (tokens) {
        return res(tokens);
    }
    else {
        return res_401();
    }
};
const loginUserAction = async (email, password) => {
    if (!isEmail(email) || !isRequiredLength(password)) {
        return;
    }
    const user = await checkUser(email, password);
    if (user?.password && compare_bcrypt(password, user.password)) {
        return { email: user.email, ...getTokens(user.id) };
    }
};
const checkUser = async (email, password) => {
    const { state } = apiker.requestParams;
    if (!isEmail(email) || !isRequiredLength(password)) {
        return;
    }
    /**
     * Check if user exists
     */
    const userId = await state(OBN.EMAILTOUUID, email).get(email);
    if (!userId) {
        return;
    }
    /**
     * Check user
     */
    const user = await state(OBN.USERS, userId).get(userId);
    if (user?.password && compare_bcrypt(password, user.password)) {
        return user;
    }
};

const refreshUser = async () => {
    const user = await getCurrentUser();
    if (user?.id) {
        return res(getTokens(user.id));
    }
    else {
        return res_400();
    }
};

const deleteUser = async ({ state }) => {
    const user = await getCurrentUser();
    if (!user?.id) {
        return res_400();
    }
    const success = await deleteUserAction(user);
    if (success) {
        return res_200();
    }
    else {
        return res_400();
    }
};
const deleteUserAction = async (user) => {
    const { state } = apiker.requestParams;
    await state(OBN.EMAILTOUUID, user.email).delete(user.email);
    await state(OBN.USERS, user.id).delete(user.id);
    return true;
};

const EMAIL_API_ENDPOINT = "https://api.brevo.com/v3/smtp/email";

const sendEmail = async (subject, content, to = [], sender = {
    name: apiker.email?.name || apiker.name,
    email: apiker.email?.senderEmail || ""
}) => {
    if (
    // Email option not active
    !apiker.email ||
        // No API key
        !apiker.env.BREVO_API_KEY ||
        // No receipients
        !to.length ||
        // Invalid emails
        !(isEmail(sender.email) && to.every(item => isEmail(item.email))) ||
        // Invalid sender name
        !sender.name) {
        return;
    }
    const bodyParams = {
        subject,
        sender,
        to,
        htmlContent: content
    };
    const response = await fetch(EMAIL_API_ENDPOINT, {
        body: JSON.stringify(bodyParams),
        headers: {
            'api-key': apiker.env.BREVO_API_KEY,
            'Content-Type': 'application/json',
            'Accept': 'application/json'
        },
        method: 'POST',
    });
    if (apiker.debug) {
        console.log("bodyParams", bodyParams);
        console.log("response", response);
    }
    return response;
};

const forgotPasswordTemplate = `<html>
        <head></head>
        <body>
            <h1>Email Reset</h1>
            <div>
                <p>If you received this email, it means that you've used the Reset Password feature. If so, click the following link to proceed:</p>
                <p><a href="{resetUrl}">Reset User Email</a></p>
                <p>If you have not initiated this request, please disregard this message. The link will expire in 5 minutes.</p>
            </div>
        </body>
    </html>`;
const newPasswordTemplate = `<html>
    <head></head>
    <body>
        <h1>New Password</h1>
        <div>
            <p>Your password has been reset successfully.</p>
            <p><b>New password</b>: {newPassword}</p>
            <p>If you have not initiated this request, please reach out to support.</p>
        </div>
    </body>
</html>`;

const verifyAccountTemplate = `<html>
        <head></head>
        <body>
            <h1>Verify Account</h1>
            <div>
                <p>If you received this email, it means that you've created an account at {appName}. If so, click the following link to activate your account:</p>
                <p><a href="{activateUrl}">Activate account</a></p>
                <p>If you have not initiated this request, please disregard this message. The link will expire in 5 minutes.</p>
            </div>
        </body>
    </html>`;
const verifyAccountSuccessTemplate = `<html>
    <head></head>
    <body>
        <h1>Account verified</h1>
        <div>
            <p>You have verified your account at {appName}.</p>
            <p>Have a great day!</p>
        </div>
    </body>
</html>`;

const forgotUser = async () => {
    const user = await getCurrentUser();
    if (!user?.id) {
        return res_401();
    }
    const res = await forgotUserAction(user.email);
    if (res) {
        return res;
    }
    else {
        return res_400();
    }
};
const forgotUserAction = async (email) => {
    const { state } = apiker.requestParams;
    const emailTitle = `${apiker.name} - Forgot Password`;
    if (!isEmail(email)) {
        return;
    }
    if (!apiker.env.APIKER_ROOT_URL) {
        throw new Error("env.APIKER_ROOT_URL is undefined. Please consult the documentation");
    }
    /**
     * Check if user exists
     */
    const currentUserId = await state(OBN.EMAILTOUUID, email).get(email);
    if (!currentUserId) {
        return;
    }
    /**
     * Create an auth token that will expire in 5 minutes
     */
    const { token: resetToken } = getTokens(currentUserId, 5);
    const recipients = [
        {
            name: `${apiker.name} User`,
            email
        }
    ];
    /**
     * Reset url
     */
    const resetUrl = `${apiker.env.APIKER_ROOT_URL}/auth/forgot/reset?t=${encodeURIComponent(resetToken)}`;
    const template = forgotPasswordTemplate.replace("{resetUrl}", resetUrl);
    const result = await sendEmail(emailTitle, template, recipients);
    return result;
};
/**
 * Forgot user reset action
 */
const forgotUserReset = async ({ state, request }) => {
    const url = new URL(request.url);
    const params = new URLSearchParams(url.search);
    const emailTitle = `${apiker.name} - New Password`;
    const authParam = params.get("t");
    if (!authParam) {
        return res_400();
    }
    /** We need to ensure that the token utilized was the token passed in the "t" param */
    const authToken = extractToken();
    if (authToken !== authParam) {
        return res_400("Token mismatch");
    }
    /** Get current user **Without Client ID Check!** */
    const user = await getCurrentUser(true);
    if (!user?.id) {
        return res_401();
    }
    /** Reset password */
    const newPassword = randomHash_SHA1().substring(0, 10);
    if (newPassword?.length < 10) {
        return res_500();
    }
    const signedPassword = hash_bcrypt(newPassword);
    const updatedUser = {
        ...user,
        password: signedPassword,
        updatedAt: Date.now()
    };
    const id = user.id;
    /** Update user */
    await state(OBN.USERS, id).put({ [id]: updatedUser });
    const recipients = [
        {
            name: `${apiker.name} User`,
            email: user.email
        }
    ];
    const template = newPasswordTemplate.replace("{newPassword}", newPassword);
    /**
     * Return an email with the user's new password
     */
    await sendEmail(emailTitle, template, recipients);
    return res_200();
};

const verifyUser = async () => {
    const user = await getCurrentUser();
    if (!user?.id) {
        return res_401();
    }
    const res = await verifyUserAction(user.email);
    if (res) {
        return res;
    }
    else {
        return res_400();
    }
};
const verifyUserAction = async (email) => {
    const { state } = apiker.requestParams;
    const emailTitle = `${apiker.name} - Verify User`;
    if (!isEmail(email)) {
        return;
    }
    if (!apiker.env.APIKER_ROOT_URL) {
        throw new Error("env.APIKER_ROOT_URL is undefined. Please consult the documentation");
    }
    /**
     * Check if user exists
     */
    const currentUserId = await state(OBN.EMAILTOUUID, email).get(email);
    if (!currentUserId) {
        return;
    }
    /**
     * Create an auth token that will expire in 5 minutes
     */
    const { token: tempToken } = getTokens(currentUserId, 40);
    const recipients = [
        {
            name: `${apiker.name} User`,
            email
        }
    ];
    /**
     * Verify url
     */
    const activateUrl = `${apiker.env.APIKER_ROOT_URL}/auth/verify/action?t=${encodeURIComponent(tempToken)}`;
    const template = verifyAccountTemplate.replace("{activateUrl}", activateUrl).replace("{appName}", apiker.name);
    const result = await sendEmail(emailTitle, template, recipients);
    return result;
};
/**
 * Verify user action
 */
const verifyUserProcess = async ({ state, request }) => {
    const url = new URL(request.url);
    const params = new URLSearchParams(url.search);
    const emailTitle = `${apiker.name} - Account Verified`;
    const authParam = params.get("t");
    if (!authParam) {
        return res_400();
    }
    /** We need to ensure that the token utilized was the token passed in the "t" param */
    const authToken = extractToken();
    if (authToken !== authParam) {
        return res_400("Token mismatch");
    }
    /** Get current user **Without Client ID Check!** */
    const user = await getCurrentUser(true);
    if (!user?.id) {
        return res_401();
    }
    /** Verify account */
    const updatedUser = {
        ...user,
        verified: true,
        updatedAt: Date.now()
    };
    const id = user.id;
    /** Update user */
    await state(OBN.USERS, id).put({ [id]: updatedUser });
    const recipients = [
        {
            name: `${apiker.name} User`,
            email: user.email
        }
    ];
    const template = verifyAccountSuccessTemplate.replace("{appName}", apiker.name);
    /**
     * Return an email with the user's new password
     */
    await sendEmail(emailTitle, template, recipients);
    return res_200();
};

/**
 * Responses
 */
const getAuthRoutes = () => ({
    "/auth/register": params => rateLimitRequest(AUTH_REGISTER_PREFIX, params, registerUser, REGISTER_REQUEST_LIMIT_AMOUNT_PER_HOUR),
    "/auth/login": params => rateLimitRequest(AUTH_PREFIX, params, loginUser),
    "/auth/refresh": params => rateLimitRequest(AUTH_PREFIX, params, refreshUser),
    "/auth/delete": params => rateLimitRequest(AUTH_PREFIX, params, deleteUser),
    "/auth/forgot": params => rateLimitRequest(AUTH_PREFIX, params, forgotUser),
    "/auth/forgot/reset": params => rateLimitRequest(AUTH_PREFIX, params, forgotUserReset),
    "/auth/verify": params => rateLimitRequest(AUTH_PREFIX, params, verifyUser),
    "/auth/verify/action": params => rateLimitRequest(AUTH_PREFIX, params, verifyUserProcess)
});

const BANS_PREFIX = "bans";

/**
 * Bans an entity
 * @param entity The user's ID (can be any string, but preferable a signedIp acquired through getSignedIp())
 * @param clientId The user's clientId (defaulting to getClientId())
 */
const banEntity = async (entity, clientId = getClientId()) => {
    const user = await getCurrentUser();
    return await addLogEntry(BANS_PREFIX, { issuedBy: user?.id, objectId: entity }, OBN.BANS, entity, clientId);
};
/**
 * Unbans an entity
 * @param entity The user's ID (can be any string, but preferable a signedIp acquired through getSignedIp())
 */
const unbanEntity = async (entity) => {
    if (!entity) {
        return;
    }
    return await deleteAllLogsInObject(OBN.BANS, entity);
};
/**
 * Checks whether an entity is banned
 * @param entity The user's ID (can be any string, but preferable a signedIp acquired through getSignedIp())
 */
const isEntityBanned = async (entity) => {
    const entries = await getAllLogEntries(OBN.BANS, 1, entity);
    return entries && !!entries.length;
};
/**
 * Get a list of banned entries for a given entity
 * @param entity The user's ID (can be any string, but preferable a signedIp acquired through getSignedIp())
 * @param limit The number of results to return
 */
const getBannedEntries = async (entity, limit = 10) => {
    const entries = await getAllLogEntries(OBN.BANS, limit, entity);
    return entries;
};
/**
 * Get a list of banned entries (without filtering by entity)
 * @param entity The user's ID (can be any string, but preferable a signedIp acquired through getSignedIp())
 * @param limit The number of results to return
 */
const getBannedEntities = async (limit = 10) => {
    const entries = await getAllLogEntries(OBN.BANS, limit);
    return entries;
};

const bansEndpoint = async (params) => {
    const { body, request } = params;
    const { userId } = body || {};
    if (!userId) {
        return res_400();
    }
    try {
        if (request.method === "POST") {
            await banEntity(userId);
        }
        else if (request.method === "DELETE") {
            await unbanEntity(userId);
        }
    }
    catch (e) {
        return res_400();
    }
    return res_200();
};
const searchBansEndpoint = async (params) => {
    const { matches } = params;
    const userId = matches.params.userId;
    if (!userId) {
        return res_400();
    }
    const entries = await getBannedEntries(userId);
    return res({ entries });
};

const ADMIN_LOGIN_PREFIX = "admin-login";
const defaultActions = [
    {
        id: "login",
        displayName: "Login"
    }
];
const authActions = [
    {
        id: "banUser",
        displayName: "Ban User"
    },
    {
        id: "unbanUser",
        displayName: "Unban User"
    },
    {
        id: "searchBans",
        displayName: "Search Bans"
    },
    {
        id: "sendEmail",
        displayName: "Send Email"
    },
    {
        id: "updateUser",
        displayName: "Update User"
    },
    {
        id: "deleteUser",
        displayName: "Delete User"
    },
];

const loginEndpoint = async (params) => {
    const { state, body } = params;
    const { email, password } = body || {};
    let user;
    /**
     * If there's an user, it's a login, otherwise it's a registration
     */
    if (email && password) {
        const adminIds = await state(OBN.COMMON).get("adminIds");
        const hasAdmins = !!adminIds?.length;
        if (hasAdmins) {
            user = await checkUser(email, password);
        }
        else {
            user = await registerUserAction(email, password, { role: "admin" });
        }
        if (user && await isUserAdmin(user.id)) {
            const { token } = getTokens(user?.id, 60);
            apiker.responseHeaders.set('Set-Cookie', cookie.serialize('apikerToken', `Bearer ${token}`, {
                sameSite: true,
                httpOnly: true,
                secure: true,
                maxAge: 3600 // 1hr
            }));
            /**
             * Add log entry
             */
            await addLogEntry(ADMIN_LOGIN_PREFIX);
        }
    }
    else {
        user = await getCurrentUser();
    }
    if (!user) {
        return res_401();
    }
    if (!await isUserAdmin(user.id)) {
        return res_401();
    }
    return res_200();
};

const sendEmailEndpoint = async ({ body }) => {
    const { userEmail, template } = body || {};
    if (!userEmail || !template) {
        return res_400();
    }
    let actionResult;
    if (template === "forgotPassword") {
        actionResult = await forgotUserAction(userEmail);
    }
    else if (template === "verifyAccount") {
        actionResult = await verifyUserAction(userEmail);
    }
    else {
        return res_400();
    }
    return actionResult ? actionResult : res_400();
};

const updateUserEndpoint = async ({ state, body, request }) => {
    let userEmail = "";
    let userId = "";
    let user = null;
    let returnObj = {};
    if (request.method === "GET") {
        const url = new URL(request.url);
        const params = new URLSearchParams(url.search);
        userEmail = params.get("userEmail") || "";
    }
    else if (request.method === "PUT" || request.method === "DELETE") {
        userEmail = body?.userEmail || "";
    }
    else {
        return res_400();
    }
    if (!isEmail(userEmail)) {
        return res_400();
    }
    if (request.method === "GET" || request.method === "PUT" || request.method === "DELETE") {
        /** Check if user exists */
        userId = await state(OBN.EMAILTOUUID, userEmail).get(userEmail);
        if (!userId) {
            return res_400();
        }
        user = await state(OBN.USERS, userId).get(userId);
        if (!user) {
            return res_404();
        }
    }
    let updatedFields = {};
    if (request.method === "PUT") {
        /** Do not allow user update of admin, unless same user */
        if (user?.email !== userEmail && user?.role === "admin") {
            return res_401();
        }
        const { email } = body?.updatedUser ? JSON.parse(body.updatedUser) : {};
        if (apiker.debug) {
            console.log("updatedUser", JSON.parse(body.updatedUser));
            console.log("Current Email", user.email);
            console.log("New Email", email);
        }
        /** The actual fields that will be updated */
        if (email && email !== user.email) {
            updatedFields["email"] = email;
            const formEmailDelete = await state(OBN.EMAILTOUUID, userEmail).deleteAll();
            const userEmailDelete = await state(OBN.EMAILTOUUID, user.email).deleteAll();
            const newUserEmailPut = await state(OBN.EMAILTOUUID, email).put({ [email]: user.id });
            if (apiker.debug) {
                console.log("formEmailDelete", formEmailDelete);
                console.log("userEmailDelete", userEmailDelete);
                console.log("newUserEmailPut", newUserEmailPut);
            }
        }
        if (Object.keys(updatedFields).length) {
            const newUser = { ...user, ...updatedFields };
            /** Displayed field */
            const newUserPut = await state(OBN.USERS, user.id).put({ [user.id]: newUser });
            if (apiker.debug) {
                console.log("newUserPut", newUserPut);
            }
        }
    }
    if (request.method === "PUT") {
        returnObj = {
            updatedFields: Object.keys(updatedFields)
        };
    }
    else if (request.method === "GET") {
        const savedUser = await state(OBN.USERS, userId).get(userId);
        if (!savedUser) {
            return res_500();
        }
        const partialUser = {
            id: savedUser.id,
            email: savedUser.email,
            role: savedUser.role,
            verified: savedUser.verified || false
        };
        returnObj = {
            partialUser
        };
    }
    else if (request.method === "DELETE") {
        const formEmailDelete = await state(OBN.EMAILTOUUID, userEmail).deleteAll();
        const userEmailDelete = await state(OBN.EMAILTOUUID, user.email).deleteAll();
        const userDelete = await state(OBN.USERS, user.id).deleteAll();
        const formEmailUnban = await unbanEntity(userEmail);
        const userEmailUnban = await unbanEntity(user.email);
        const userIdUnban = await unbanEntity(user.id);
        if (apiker.debug) {
            console.log("formEmailDelete", formEmailDelete);
            console.log("userEmailDelete", userEmailDelete);
            console.log("userDelete", userDelete);
            console.log("formEmailUnban", formEmailUnban);
            console.log("userEmailUnban", userEmailUnban);
            console.log("userIdUnban", userIdUnban);
        }
    }
    return res_200({ ...returnObj, success: true });
};

var css = "html, body, #app {\n    height: 100%;\n    margin: 0;\n}\n\n.navbar {\n    padding: 50px !important;\n}\n\n.btn-group {\n    display: flex;\n}\n\n.action-dropdown,\n.form-control,\n.input-group {\n    border: 2px solid #ccc;\n    display: flex;\n    justify-content: space-between;\n}\n\n.container .btn.action-btn {\n    padding: 0.5rem 1rem;\n    font-size: 20px;\n    width: 100%;\n}\n\n.container .btn.action-btn.btn-primary {\n    background: #2e3191;\n    border-color: #2e3191;\n}\n\n.container .btn.action-btn:hover {\n    opacity: 0.9;\n}\n\n.action-dropdown::after {\n    border: none !important;\n    content: \"expand_more\";\n    font-family: \"Material Symbols Outlined\";\n    font-size: 35px;\n    position: absolute;\n    right: 7px;\n    top: 0;\n}\n\n.btn:hover {\n    border-color: #ccc !important;\n}\n\nul.dropdown-menu.show {\n    display: flex;\n    width: 100%;\n    padding: 10px;\n    gap: 10px;\n    flex-flow: column;\n}\n\nul.dropdown-menu.show li {\n    background: whitesmoke;\n    border-radius: 5px;\n    flex: 1;\n}\n\na.dropdown-item {\n    border-radius: 5px;\n    text-align: center;\n}\n\n.action-wrapper {\n    border-radius: 10px;\n    border-bottom: 2px solid #ececec;\n}\n\n.signed-ip {\n    position: absolute;\n    right: 10px;\n    bottom: 10px;\n    font-size: 14px;\n    opacity: 0.6;\n}\n\n.results-container {\n    margin-top: 10px;\n    background: #f6f6f6;\n    border-radius: 5px;\n    overflow-y: auto;\n    max-height: 300px;\n    padding: 10px;\n    position: relative;\n}\n\n.results-container .results-item {\n    padding: 10px 15px;\n    border-bottom: 1px #ccc dashed;\n}\n\n.results-container .results-item:last-child {\n    border-bottom: none;\n}\n\n.results-container .results-item ul {\n    list-style: none;\n    margin: 0;\n    padding: 0;\n}\n\n.results-container .results-item ul li {\n    display: flex;\n    flex-flow: row;\n    gap: 10px;\n}\n\n.results-container .results-item ul li span.title {\n    font-weight: 500;\n    display: inline-block;\n    text-transform: capitalize;\n    width: 24%;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n    overflow: hidden;\n}\n\n.results-container .results-item ul li span.text {\n    display: inline-block;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n    overflow: hidden;\n    flex: 1;\n}\n\n.action-wrapper pre {\n    background: #e5e5e5;\n    padding: 15px;\n    border-radius: 5px;\n    white-space: pre-wrap;\n    white-space: -moz-pre-wrap;\n    white-space: -pre-wrap;\n    white-space: -o-pre-wrap;\n    word-wrap: break-word;\n}\n\n.input-group {\n    border-radius: 10px;\n    overflow: hidden;\n    box-sizing: border-box;\n    position: relative;\n}\n\n.input-group input {\n    border: none !important;\n    outline: none !important;\n    flex: 1;\n    padding: 10px 15px;\n    font-size: 20px;\n}\n\n.input-group .btn {\n    background: #2e3191;\n    color: white;\n    position: absolute;\n    right: 7px;\n    top: 50%;\n    transform: translateY(-50%);\n    border-radius: 5px !important;\n}\n\n.action-wrapper textarea {\n    width: 100%;\n    padding: 18px;\n    height: 240px;\n}";

var img = "data:image/svg+xml,%3c%3fxml version='1.0' encoding='UTF-8'%3f%3e%3csvg id='Layer_2' data-name='Layer 2' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 6.66 7.35'%3e %3cdefs%3e %3cstyle%3e .cls-1 %7b fill: %232e3191%3b %7d %3c/style%3e %3c/defs%3e %3cg id='Layer_23' data-name='Layer 23'%3e %3cpath class='cls-1' d='m3.2%2c0h.13l3.33%2c7.35H0L3.2%2c0Zm1.01%2c5.27l-.52-1.26c-.21-.51-.44-1.31-.44-1.31%2c0%2c0-.21.79-.43%2c1.31l-.52%2c1.26h1.92Z'/%3e %3c/g%3e%3c/svg%3e";

const Header = ({ children } = {}) => {
    return (React.createElement("nav", { className: "navbar navbar-expand-lg navbar-light px-3" },
        React.createElement("a", { className: "navbar-brand", href: "#" },
            React.createElement("img", { src: img, height: "59", width: "52" })),
        children));
};

const Content = ({ children } = {}) => {
    return (React.createElement("div", { className: "content mt-5" },
        React.createElement("div", { className: "container" },
            React.createElement("div", { className: "row justify-content-md-center" },
                React.createElement("div", { className: "col-lg-6" }, children)))));
};

var server_browser = {};

var reactDomServerLegacy_browser_production_min = {};

/**
 * @license React
 * react-dom-server-legacy.browser.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var aa$1=React;function l$2(a){for(var b="https://reactjs.org/docs/error-decoder.html?invariant="+a,c=1;c<arguments.length;c++)b+="&args[]="+encodeURIComponent(arguments[c]);return "Minified React error #"+a+"; visit "+b+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}
var p$1=Object.prototype.hasOwnProperty,fa$1=/^[:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD][:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\-.0-9\u00B7\u0300-\u036F\u203F-\u2040]*$/,ha$1={},ia$1={};
function ja$1(a){if(p$1.call(ia$1,a))return !0;if(p$1.call(ha$1,a))return !1;if(fa$1.test(a))return ia$1[a]=!0;ha$1[a]=!0;return !1}function r(a,b,c,d,f,e,g){this.acceptsBooleans=2===b||3===b||4===b;this.attributeName=d;this.attributeNamespace=f;this.mustUseProperty=c;this.propertyName=a;this.type=b;this.sanitizeURL=e;this.removeEmptyString=g;}var t$1={};
"children dangerouslySetInnerHTML defaultValue defaultChecked innerHTML suppressContentEditableWarning suppressHydrationWarning style".split(" ").forEach(function(a){t$1[a]=new r(a,0,!1,a,null,!1,!1);});[["acceptCharset","accept-charset"],["className","class"],["htmlFor","for"],["httpEquiv","http-equiv"]].forEach(function(a){var b=a[0];t$1[b]=new r(b,1,!1,a[1],null,!1,!1);});["contentEditable","draggable","spellCheck","value"].forEach(function(a){t$1[a]=new r(a,2,!1,a.toLowerCase(),null,!1,!1);});
["autoReverse","externalResourcesRequired","focusable","preserveAlpha"].forEach(function(a){t$1[a]=new r(a,2,!1,a,null,!1,!1);});"allowFullScreen async autoFocus autoPlay controls default defer disabled disablePictureInPicture disableRemotePlayback formNoValidate hidden loop noModule noValidate open playsInline readOnly required reversed scoped seamless itemScope".split(" ").forEach(function(a){t$1[a]=new r(a,3,!1,a.toLowerCase(),null,!1,!1);});
["checked","multiple","muted","selected"].forEach(function(a){t$1[a]=new r(a,3,!0,a,null,!1,!1);});["capture","download"].forEach(function(a){t$1[a]=new r(a,4,!1,a,null,!1,!1);});["cols","rows","size","span"].forEach(function(a){t$1[a]=new r(a,6,!1,a,null,!1,!1);});["rowSpan","start"].forEach(function(a){t$1[a]=new r(a,5,!1,a.toLowerCase(),null,!1,!1);});var ka$1=/[\-:]([a-z])/g;function la$1(a){return a[1].toUpperCase()}
"accent-height alignment-baseline arabic-form baseline-shift cap-height clip-path clip-rule color-interpolation color-interpolation-filters color-profile color-rendering dominant-baseline enable-background fill-opacity fill-rule flood-color flood-opacity font-family font-size font-size-adjust font-stretch font-style font-variant font-weight glyph-name glyph-orientation-horizontal glyph-orientation-vertical horiz-adv-x horiz-origin-x image-rendering letter-spacing lighting-color marker-end marker-mid marker-start overline-position overline-thickness paint-order panose-1 pointer-events rendering-intent shape-rendering stop-color stop-opacity strikethrough-position strikethrough-thickness stroke-dasharray stroke-dashoffset stroke-linecap stroke-linejoin stroke-miterlimit stroke-opacity stroke-width text-anchor text-decoration text-rendering underline-position underline-thickness unicode-bidi unicode-range units-per-em v-alphabetic v-hanging v-ideographic v-mathematical vector-effect vert-adv-y vert-origin-x vert-origin-y word-spacing writing-mode xmlns:xlink x-height".split(" ").forEach(function(a){var b=a.replace(ka$1,
la$1);t$1[b]=new r(b,1,!1,a,null,!1,!1);});"xlink:actuate xlink:arcrole xlink:role xlink:show xlink:title xlink:type".split(" ").forEach(function(a){var b=a.replace(ka$1,la$1);t$1[b]=new r(b,1,!1,a,"http://www.w3.org/1999/xlink",!1,!1);});["xml:base","xml:lang","xml:space"].forEach(function(a){var b=a.replace(ka$1,la$1);t$1[b]=new r(b,1,!1,a,"http://www.w3.org/XML/1998/namespace",!1,!1);});["tabIndex","crossOrigin"].forEach(function(a){t$1[a]=new r(a,1,!1,a.toLowerCase(),null,!1,!1);});
t$1.xlinkHref=new r("xlinkHref",1,!1,"xlink:href","http://www.w3.org/1999/xlink",!0,!1);["src","href","action","formAction"].forEach(function(a){t$1[a]=new r(a,1,!1,a.toLowerCase(),null,!0,!0);});
var u$1={animationIterationCount:!0,aspectRatio:!0,borderImageOutset:!0,borderImageSlice:!0,borderImageWidth:!0,boxFlex:!0,boxFlexGroup:!0,boxOrdinalGroup:!0,columnCount:!0,columns:!0,flex:!0,flexGrow:!0,flexPositive:!0,flexShrink:!0,flexNegative:!0,flexOrder:!0,gridArea:!0,gridRow:!0,gridRowEnd:!0,gridRowSpan:!0,gridRowStart:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnSpan:!0,gridColumnStart:!0,fontWeight:!0,lineClamp:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,tabSize:!0,widows:!0,zIndex:!0,zoom:!0,
fillOpacity:!0,floodOpacity:!0,stopOpacity:!0,strokeDasharray:!0,strokeDashoffset:!0,strokeMiterlimit:!0,strokeOpacity:!0,strokeWidth:!0},ma=["Webkit","ms","Moz","O"];Object.keys(u$1).forEach(function(a){ma.forEach(function(b){b=b+a.charAt(0).toUpperCase()+a.substring(1);u$1[b]=u$1[a];});});var na=/["'&<>]/;
function v(a){if("boolean"===typeof a||"number"===typeof a)return ""+a;a=""+a;var b=na.exec(a);if(b){var c="",d,f=0;for(d=b.index;d<a.length;d++){switch(a.charCodeAt(d)){case 34:b="&quot;";break;case 38:b="&amp;";break;case 39:b="&#x27;";break;case 60:b="&lt;";break;case 62:b="&gt;";break;default:continue}f!==d&&(c+=a.substring(f,d));f=d+1;c+=b;}a=f!==d?c+a.substring(f,d):c;}return a}var oa$1=/([A-Z])/g,pa$1=/^ms-/,qa$1=Array.isArray;function w$1(a,b){return {insertionMode:a,selectedValue:b}}
function ra$1(a,b,c){switch(b){case "select":return w$1(1,null!=c.value?c.value:c.defaultValue);case "svg":return w$1(2,null);case "math":return w$1(3,null);case "foreignObject":return w$1(1,null);case "table":return w$1(4,null);case "thead":case "tbody":case "tfoot":return w$1(5,null);case "colgroup":return w$1(7,null);case "tr":return w$1(6,null)}return 4<=a.insertionMode||0===a.insertionMode?w$1(1,null):a}var sa$1=new Map;
function ta$1(a,b,c){if("object"!==typeof c)throw Error(l$2(62));b=!0;for(var d in c)if(p$1.call(c,d)){var f=c[d];if(null!=f&&"boolean"!==typeof f&&""!==f){if(0===d.indexOf("--")){var e=v(d);f=v((""+f).trim());}else {e=d;var g=sa$1.get(e);void 0!==g?e=g:(g=v(e.replace(oa$1,"-$1").toLowerCase().replace(pa$1,"-ms-")),sa$1.set(e,g),e=g);f="number"===typeof f?0===f||p$1.call(u$1,d)?""+f:f+"px":v((""+f).trim());}b?(b=!1,a.push(' style="',e,":",f)):a.push(";",e,":",f);}}b||a.push('"');}
function x$1(a,b,c,d){switch(c){case "style":ta$1(a,b,d);return;case "defaultValue":case "defaultChecked":case "innerHTML":case "suppressContentEditableWarning":case "suppressHydrationWarning":return}if(!(2<c.length)||"o"!==c[0]&&"O"!==c[0]||"n"!==c[1]&&"N"!==c[1])if(b=t$1.hasOwnProperty(c)?t$1[c]:null,null!==b){switch(typeof d){case "function":case "symbol":return;case "boolean":if(!b.acceptsBooleans)return}c=b.attributeName;switch(b.type){case 3:d&&a.push(" ",c,'=""');break;case 4:!0===d?a.push(" ",c,'=""'):
!1!==d&&a.push(" ",c,'="',v(d),'"');break;case 5:isNaN(d)||a.push(" ",c,'="',v(d),'"');break;case 6:!isNaN(d)&&1<=d&&a.push(" ",c,'="',v(d),'"');break;default:b.sanitizeURL&&(d=""+d),a.push(" ",c,'="',v(d),'"');}}else if(ja$1(c)){switch(typeof d){case "function":case "symbol":return;case "boolean":if(b=c.toLowerCase().slice(0,5),"data-"!==b&&"aria-"!==b)return}a.push(" ",c,'="',v(d),'"');}}
function y$1(a,b,c){if(null!=b){if(null!=c)throw Error(l$2(60));if("object"!==typeof b||!("__html"in b))throw Error(l$2(61));b=b.__html;null!==b&&void 0!==b&&a.push(""+b);}}function ua$1(a){var b="";aa$1.Children.forEach(a,function(a){null!=a&&(b+=a);});return b}
function va$1(a,b,c,d){a.push(A(c));var f=c=null,e;for(e in b)if(p$1.call(b,e)){var g=b[e];if(null!=g)switch(e){case "children":c=g;break;case "dangerouslySetInnerHTML":f=g;break;default:x$1(a,d,e,g);}}a.push(">");y$1(a,f,c);return "string"===typeof c?(a.push(v(c)),null):c}var wa$1=/^[a-zA-Z][a-zA-Z:_\.\-\d]*$/,xa$1=new Map;function A(a){var b=xa$1.get(a);if(void 0===b){if(!wa$1.test(a))throw Error(l$2(65,a));b="<"+a;xa$1.set(a,b);}return b}
function ya$1(a,b,c,d,f){switch(b){case "select":a.push(A("select"));var e=null,g=null;for(n in c)if(p$1.call(c,n)){var h=c[n];if(null!=h)switch(n){case "children":e=h;break;case "dangerouslySetInnerHTML":g=h;break;case "defaultValue":case "value":break;default:x$1(a,d,n,h);}}a.push(">");y$1(a,g,e);return e;case "option":g=f.selectedValue;a.push(A("option"));var k=h=null,m=null;var n=null;for(e in c)if(p$1.call(c,e)){var q=c[e];if(null!=q)switch(e){case "children":h=q;break;case "selected":m=q;break;case "dangerouslySetInnerHTML":n=
q;break;case "value":k=q;default:x$1(a,d,e,q);}}if(null!=g)if(c=null!==k?""+k:ua$1(h),qa$1(g))for(d=0;d<g.length;d++){if(""+g[d]===c){a.push(' selected=""');break}}else ""+g===c&&a.push(' selected=""');else m&&a.push(' selected=""');a.push(">");y$1(a,n,h);return h;case "textarea":a.push(A("textarea"));n=g=e=null;for(h in c)if(p$1.call(c,h)&&(k=c[h],null!=k))switch(h){case "children":n=k;break;case "value":e=k;break;case "defaultValue":g=k;break;case "dangerouslySetInnerHTML":throw Error(l$2(91));default:x$1(a,d,
h,k);}null===e&&null!==g&&(e=g);a.push(">");if(null!=n){if(null!=e)throw Error(l$2(92));if(qa$1(n)&&1<n.length)throw Error(l$2(93));e=""+n;}"string"===typeof e&&"\n"===e[0]&&a.push("\n");null!==e&&a.push(v(""+e));return null;case "input":a.push(A("input"));k=n=h=e=null;for(g in c)if(p$1.call(c,g)&&(m=c[g],null!=m))switch(g){case "children":case "dangerouslySetInnerHTML":throw Error(l$2(399,"input"));case "defaultChecked":k=m;break;case "defaultValue":h=m;break;case "checked":n=m;break;case "value":e=m;break;
default:x$1(a,d,g,m);}null!==n?x$1(a,d,"checked",n):null!==k&&x$1(a,d,"checked",k);null!==e?x$1(a,d,"value",e):null!==h&&x$1(a,d,"value",h);a.push("/>");return null;case "menuitem":a.push(A("menuitem"));for(var C in c)if(p$1.call(c,C)&&(e=c[C],null!=e))switch(C){case "children":case "dangerouslySetInnerHTML":throw Error(l$2(400));default:x$1(a,d,C,e);}a.push(">");return null;case "title":a.push(A("title"));e=null;for(q in c)if(p$1.call(c,q)&&(g=c[q],null!=g))switch(q){case "children":e=g;break;case "dangerouslySetInnerHTML":throw Error(l$2(434));
default:x$1(a,d,q,g);}a.push(">");return e;case "listing":case "pre":a.push(A(b));g=e=null;for(k in c)if(p$1.call(c,k)&&(h=c[k],null!=h))switch(k){case "children":e=h;break;case "dangerouslySetInnerHTML":g=h;break;default:x$1(a,d,k,h);}a.push(">");if(null!=g){if(null!=e)throw Error(l$2(60));if("object"!==typeof g||!("__html"in g))throw Error(l$2(61));c=g.__html;null!==c&&void 0!==c&&("string"===typeof c&&0<c.length&&"\n"===c[0]?a.push("\n",c):a.push(""+c));}"string"===typeof e&&"\n"===e[0]&&a.push("\n");return e;
case "area":case "base":case "br":case "col":case "embed":case "hr":case "img":case "keygen":case "link":case "meta":case "param":case "source":case "track":case "wbr":a.push(A(b));for(var D in c)if(p$1.call(c,D)&&(e=c[D],null!=e))switch(D){case "children":case "dangerouslySetInnerHTML":throw Error(l$2(399,b));default:x$1(a,d,D,e);}a.push("/>");return null;case "annotation-xml":case "color-profile":case "font-face":case "font-face-src":case "font-face-uri":case "font-face-format":case "font-face-name":case "missing-glyph":return va$1(a,
c,b,d);case "html":return 0===f.insertionMode&&a.push("<!DOCTYPE html>"),va$1(a,c,b,d);default:if(-1===b.indexOf("-")&&"string"!==typeof c.is)return va$1(a,c,b,d);a.push(A(b));g=e=null;for(m in c)if(p$1.call(c,m)&&(h=c[m],null!=h))switch(m){case "children":e=h;break;case "dangerouslySetInnerHTML":g=h;break;case "style":ta$1(a,d,h);break;case "suppressContentEditableWarning":case "suppressHydrationWarning":break;default:ja$1(m)&&"function"!==typeof h&&"symbol"!==typeof h&&a.push(" ",m,'="',v(h),'"');}a.push(">");
y$1(a,g,e);return e}}function za$1(a,b,c){a.push('\x3c!--$?--\x3e<template id="');if(null===c)throw Error(l$2(395));a.push(c);return a.push('"></template>')}
function Aa$1(a,b,c,d){switch(c.insertionMode){case 0:case 1:return a.push('<div hidden id="'),a.push(b.segmentPrefix),b=d.toString(16),a.push(b),a.push('">');case 2:return a.push('<svg aria-hidden="true" style="display:none" id="'),a.push(b.segmentPrefix),b=d.toString(16),a.push(b),a.push('">');case 3:return a.push('<math aria-hidden="true" style="display:none" id="'),a.push(b.segmentPrefix),b=d.toString(16),a.push(b),a.push('">');case 4:return a.push('<table hidden id="'),a.push(b.segmentPrefix),
b=d.toString(16),a.push(b),a.push('">');case 5:return a.push('<table hidden><tbody id="'),a.push(b.segmentPrefix),b=d.toString(16),a.push(b),a.push('">');case 6:return a.push('<table hidden><tr id="'),a.push(b.segmentPrefix),b=d.toString(16),a.push(b),a.push('">');case 7:return a.push('<table hidden><colgroup id="'),a.push(b.segmentPrefix),b=d.toString(16),a.push(b),a.push('">');default:throw Error(l$2(397));}}
function Ba$1(a,b){switch(b.insertionMode){case 0:case 1:return a.push("</div>");case 2:return a.push("</svg>");case 3:return a.push("</math>");case 4:return a.push("</table>");case 5:return a.push("</tbody></table>");case 6:return a.push("</tr></table>");case 7:return a.push("</colgroup></table>");default:throw Error(l$2(397));}}var Ca$1=/[<\u2028\u2029]/g;
function Da$1(a){return JSON.stringify(a).replace(Ca$1,function(a){switch(a){case "<":return "\\u003c";case "\u2028":return "\\u2028";case "\u2029":return "\\u2029";default:throw Error("escapeJSStringsForInstructionScripts encountered a match it does not know how to replace. this means the match regex and the replacement characters are no longer in sync. This is a bug in React");}})}
function Ea$1(a,b){b=void 0===b?"":b;return {bootstrapChunks:[],startInlineScript:"<script>",placeholderPrefix:b+"P:",segmentPrefix:b+"S:",boundaryPrefix:b+"B:",idPrefix:b,nextSuspenseID:0,sentCompleteSegmentFunction:!1,sentCompleteBoundaryFunction:!1,sentClientRenderFunction:!1,generateStaticMarkup:a}}function Fa$1(a,b,c,d){if(c.generateStaticMarkup)return a.push(v(b)),!1;""===b?a=d:(d&&a.push("\x3c!-- --\x3e"),a.push(v(b)),a=!0);return a}
var B$1=Object.assign,Ga$1=Symbol.for("react.element"),Ha$1=Symbol.for("react.portal"),Ia$1=Symbol.for("react.fragment"),Ja$1=Symbol.for("react.strict_mode"),Ka$1=Symbol.for("react.profiler"),La$1=Symbol.for("react.provider"),Ma$1=Symbol.for("react.context"),Na$1=Symbol.for("react.forward_ref"),Oa$1=Symbol.for("react.suspense"),Pa$1=Symbol.for("react.suspense_list"),Qa$1=Symbol.for("react.memo"),Ra$1=Symbol.for("react.lazy"),Sa$1=Symbol.for("react.scope"),Ta$1=Symbol.for("react.debug_trace_mode"),Ua$1=Symbol.for("react.legacy_hidden"),
Va$1=Symbol.for("react.default_value"),Wa$1=Symbol.iterator;
function Xa$1(a){if(null==a)return null;if("function"===typeof a)return a.displayName||a.name||null;if("string"===typeof a)return a;switch(a){case Ia$1:return "Fragment";case Ha$1:return "Portal";case Ka$1:return "Profiler";case Ja$1:return "StrictMode";case Oa$1:return "Suspense";case Pa$1:return "SuspenseList"}if("object"===typeof a)switch(a.$$typeof){case Ma$1:return (a.displayName||"Context")+".Consumer";case La$1:return (a._context.displayName||"Context")+".Provider";case Na$1:var b=a.render;a=a.displayName;a||(a=b.displayName||
b.name||"",a=""!==a?"ForwardRef("+a+")":"ForwardRef");return a;case Qa$1:return b=a.displayName||null,null!==b?b:Xa$1(a.type)||"Memo";case Ra$1:b=a._payload;a=a._init;try{return Xa$1(a(b))}catch(c){}}return null}var Ya$1={};function Za$1(a,b){a=a.contextTypes;if(!a)return Ya$1;var c={},d;for(d in a)c[d]=b[d];return c}var E$1=null;
function F(a,b){if(a!==b){a.context._currentValue2=a.parentValue;a=a.parent;var c=b.parent;if(null===a){if(null!==c)throw Error(l$2(401));}else {if(null===c)throw Error(l$2(401));F(a,c);}b.context._currentValue2=b.value;}}function $a$1(a){a.context._currentValue2=a.parentValue;a=a.parent;null!==a&&$a$1(a);}function ab$1(a){var b=a.parent;null!==b&&ab$1(b);a.context._currentValue2=a.value;}
function bb$1(a,b){a.context._currentValue2=a.parentValue;a=a.parent;if(null===a)throw Error(l$2(402));a.depth===b.depth?F(a,b):bb$1(a,b);}function cb$1(a,b){var c=b.parent;if(null===c)throw Error(l$2(402));a.depth===c.depth?F(a,c):cb$1(a,c);b.context._currentValue2=b.value;}function G(a){var b=E$1;b!==a&&(null===b?ab$1(a):null===a?$a$1(b):b.depth===a.depth?F(b,a):b.depth>a.depth?bb$1(b,a):cb$1(b,a),E$1=a);}
var db$1={isMounted:function(){return !1},enqueueSetState:function(a,b){a=a._reactInternals;null!==a.queue&&a.queue.push(b);},enqueueReplaceState:function(a,b){a=a._reactInternals;a.replace=!0;a.queue=[b];},enqueueForceUpdate:function(){}};
function eb$1(a,b,c,d){var f=void 0!==a.state?a.state:null;a.updater=db$1;a.props=c;a.state=f;var e={queue:[],replace:!1};a._reactInternals=e;var g=b.contextType;a.context="object"===typeof g&&null!==g?g._currentValue2:d;g=b.getDerivedStateFromProps;"function"===typeof g&&(g=g(c,f),f=null===g||void 0===g?f:B$1({},f,g),a.state=f);if("function"!==typeof b.getDerivedStateFromProps&&"function"!==typeof a.getSnapshotBeforeUpdate&&("function"===typeof a.UNSAFE_componentWillMount||"function"===typeof a.componentWillMount))if(b=
a.state,"function"===typeof a.componentWillMount&&a.componentWillMount(),"function"===typeof a.UNSAFE_componentWillMount&&a.UNSAFE_componentWillMount(),b!==a.state&&db$1.enqueueReplaceState(a,a.state,null),null!==e.queue&&0<e.queue.length)if(b=e.queue,g=e.replace,e.queue=null,e.replace=!1,g&&1===b.length)a.state=b[0];else {e=g?b[0]:a.state;f=!0;for(g=g?1:0;g<b.length;g++){var h=b[g];h="function"===typeof h?h.call(a,e,c,d):h;null!=h&&(f?(f=!1,e=B$1({},e,h)):B$1(e,h));}a.state=e;}else e.queue=null;}
var fb$1={id:1,overflow:""};function gb$1(a,b,c){var d=a.id;a=a.overflow;var f=32-H$1(d)-1;d&=~(1<<f);c+=1;var e=32-H$1(b)+f;if(30<e){var g=f-f%5;e=(d&(1<<g)-1).toString(32);d>>=g;f-=g;return {id:1<<32-H$1(b)+f|c<<f|d,overflow:e+a}}return {id:1<<e|c<<f|d,overflow:a}}var H$1=Math.clz32?Math.clz32:hb$1,ib$1=Math.log,jb$1=Math.LN2;function hb$1(a){a>>>=0;return 0===a?32:31-(ib$1(a)/jb$1|0)|0}function kb$1(a,b){return a===b&&(0!==a||1/a===1/b)||a!==a&&b!==b}
var lb$1="function"===typeof Object.is?Object.is:kb$1,I$1=null,ob$1=null,J$1=null,K$1=null,L$1=!1,M$1=!1,N$1=0,O$1=null,P$1=0;function Q$1(){if(null===I$1)throw Error(l$2(321));return I$1}function pb$1(){if(0<P$1)throw Error(l$2(312));return {memoizedState:null,queue:null,next:null}}function qb$1(){null===K$1?null===J$1?(L$1=!1,J$1=K$1=pb$1()):(L$1=!0,K$1=J$1):null===K$1.next?(L$1=!1,K$1=K$1.next=pb$1()):(L$1=!0,K$1=K$1.next);return K$1}function rb$1(){ob$1=I$1=null;M$1=!1;J$1=null;P$1=0;K$1=O$1=null;}function sb$1(a,b){return "function"===typeof b?b(a):b}
function tb$1(a,b,c){I$1=Q$1();K$1=qb$1();if(L$1){var d=K$1.queue;b=d.dispatch;if(null!==O$1&&(c=O$1.get(d),void 0!==c)){O$1.delete(d);d=K$1.memoizedState;do d=a(d,c.action),c=c.next;while(null!==c);K$1.memoizedState=d;return [d,b]}return [K$1.memoizedState,b]}a=a===sb$1?"function"===typeof b?b():b:void 0!==c?c(b):b;K$1.memoizedState=a;a=K$1.queue={last:null,dispatch:null};a=a.dispatch=ub$1.bind(null,I$1,a);return [K$1.memoizedState,a]}
function vb$1(a,b){I$1=Q$1();K$1=qb$1();b=void 0===b?null:b;if(null!==K$1){var c=K$1.memoizedState;if(null!==c&&null!==b){var d=c[1];a:if(null===d)d=!1;else {for(var f=0;f<d.length&&f<b.length;f++)if(!lb$1(b[f],d[f])){d=!1;break a}d=!0;}if(d)return c[0]}}a=a();K$1.memoizedState=[a,b];return a}function ub$1(a,b,c){if(25<=P$1)throw Error(l$2(301));if(a===I$1)if(M$1=!0,a={action:c,next:null},null===O$1&&(O$1=new Map),c=O$1.get(b),void 0===c)O$1.set(b,a);else {for(b=c;null!==b.next;)b=b.next;b.next=a;}}function wb$1(){throw Error(l$2(394));}
function R$1(){}
var xb$1={readContext:function(a){return a._currentValue2},useContext:function(a){Q$1();return a._currentValue2},useMemo:vb$1,useReducer:tb$1,useRef:function(a){I$1=Q$1();K$1=qb$1();var b=K$1.memoizedState;return null===b?(a={current:a},K$1.memoizedState=a):b},useState:function(a){return tb$1(sb$1,a)},useInsertionEffect:R$1,useLayoutEffect:function(){},useCallback:function(a,b){return vb$1(function(){return a},b)},useImperativeHandle:R$1,useEffect:R$1,useDebugValue:R$1,useDeferredValue:function(a){Q$1();return a},useTransition:function(){Q$1();return [!1,
wb$1]},useId:function(){var a=ob$1.treeContext;var b=a.overflow;a=a.id;a=(a&~(1<<32-H$1(a)-1)).toString(32)+b;var c=S$1;if(null===c)throw Error(l$2(404));b=N$1++;a=":"+c.idPrefix+"R"+a;0<b&&(a+="H"+b.toString(32));return a+":"},useMutableSource:function(a,b){Q$1();return b(a._source)},useSyncExternalStore:function(a,b,c){if(void 0===c)throw Error(l$2(407));return c()}},S$1=null,yb$1=aa$1.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED.ReactCurrentDispatcher;function zb$1(a){console.error(a);return null}
function T$1(){}
function Ab$1(a,b,c,d,f,e,g,h,k){var m=[],n=new Set;b={destination:null,responseState:b,progressiveChunkSize:void 0===d?12800:d,status:0,fatalError:null,nextSegmentId:0,allPendingTasks:0,pendingRootTasks:0,completedRootSegment:null,abortableTasks:n,pingedTasks:m,clientRenderedBoundaries:[],completedBoundaries:[],partialBoundaries:[],onError:void 0===f?zb$1:f,onAllReady:void 0===e?T$1:e,onShellReady:void 0===g?T$1:g,onShellError:void 0===h?T$1:h,onFatalError:void 0===k?T$1:k};c=U$1(b,0,null,c,!1,!1);c.parentFlushed=
!0;a=Bb$1(b,a,null,c,n,Ya$1,null,fb$1);m.push(a);return b}function Bb$1(a,b,c,d,f,e,g,h){a.allPendingTasks++;null===c?a.pendingRootTasks++:c.pendingTasks++;var k={node:b,ping:function(){var b=a.pingedTasks;b.push(k);1===b.length&&Cb$1(a);},blockedBoundary:c,blockedSegment:d,abortSet:f,legacyContext:e,context:g,treeContext:h};f.add(k);return k}function U$1(a,b,c,d,f,e){return {status:0,id:-1,index:b,parentFlushed:!1,chunks:[],children:[],formatContext:d,boundary:c,lastPushedText:f,textEmbedded:e}}
function V$1(a,b){a=a.onError(b);if(null!=a&&"string"!==typeof a)throw Error('onError returned something with a type other than "string". onError should return a string and may return null or undefined but must not return anything else. It received something of type "'+typeof a+'" instead');return a}function W$1(a,b){var c=a.onShellError;c(b);c=a.onFatalError;c(b);null!==a.destination?(a.status=2,a.destination.destroy(b)):(a.status=1,a.fatalError=b);}
function Db$1(a,b,c,d,f){I$1={};ob$1=b;N$1=0;for(a=c(d,f);M$1;)M$1=!1,N$1=0,P$1+=1,K$1=null,a=c(d,f);rb$1();return a}function Eb$1(a,b,c,d){var f=c.render(),e=d.childContextTypes;if(null!==e&&void 0!==e){var g=b.legacyContext;if("function"!==typeof c.getChildContext)d=g;else {c=c.getChildContext();for(var h in c)if(!(h in e))throw Error(l$2(108,Xa$1(d)||"Unknown",h));d=B$1({},g,c);}b.legacyContext=d;X$1(a,b,f);b.legacyContext=g;}else X$1(a,b,f);}
function Fb(a,b){if(a&&a.defaultProps){b=B$1({},b);a=a.defaultProps;for(var c in a)void 0===b[c]&&(b[c]=a[c]);return b}return b}
function Gb$1(a,b,c,d,f){if("function"===typeof c)if(c.prototype&&c.prototype.isReactComponent){f=Za$1(c,b.legacyContext);var e=c.contextType;e=new c(d,"object"===typeof e&&null!==e?e._currentValue2:f);eb$1(e,c,d,f);Eb$1(a,b,e,c);}else {e=Za$1(c,b.legacyContext);f=Db$1(a,b,c,d,e);var g=0!==N$1;if("object"===typeof f&&null!==f&&"function"===typeof f.render&&void 0===f.$$typeof)eb$1(f,c,d,e),Eb$1(a,b,f,c);else if(g){d=b.treeContext;b.treeContext=gb$1(d,1,0);try{X$1(a,b,f);}finally{b.treeContext=d;}}else X$1(a,b,f);}else if("string"===
typeof c){f=b.blockedSegment;e=ya$1(f.chunks,c,d,a.responseState,f.formatContext);f.lastPushedText=!1;g=f.formatContext;f.formatContext=ra$1(g,c,d);Hb$1(a,b,e);f.formatContext=g;switch(c){case "area":case "base":case "br":case "col":case "embed":case "hr":case "img":case "input":case "keygen":case "link":case "meta":case "param":case "source":case "track":case "wbr":break;default:f.chunks.push("</",c,">");}f.lastPushedText=!1;}else {switch(c){case Ua$1:case Ta$1:case Ja$1:case Ka$1:case Ia$1:X$1(a,b,d.children);return;
case Pa$1:X$1(a,b,d.children);return;case Sa$1:throw Error(l$2(343));case Oa$1:a:{c=b.blockedBoundary;f=b.blockedSegment;e=d.fallback;d=d.children;g=new Set;var h={id:null,rootSegmentID:-1,parentFlushed:!1,pendingTasks:0,forceClientRender:!1,completedSegments:[],byteSize:0,fallbackAbortableTasks:g,errorDigest:null},k=U$1(a,f.chunks.length,h,f.formatContext,!1,!1);f.children.push(k);f.lastPushedText=!1;var m=U$1(a,0,null,f.formatContext,!1,!1);m.parentFlushed=!0;b.blockedBoundary=h;b.blockedSegment=m;try{if(Hb$1(a,
b,d),a.responseState.generateStaticMarkup||m.lastPushedText&&m.textEmbedded&&m.chunks.push("\x3c!-- --\x3e"),m.status=1,Y$1(h,m),0===h.pendingTasks)break a}catch(n){m.status=4,h.forceClientRender=!0,h.errorDigest=V$1(a,n);}finally{b.blockedBoundary=c,b.blockedSegment=f;}b=Bb$1(a,e,c,k,g,b.legacyContext,b.context,b.treeContext);a.pingedTasks.push(b);}return}if("object"===typeof c&&null!==c)switch(c.$$typeof){case Na$1:d=Db$1(a,b,c.render,d,f);if(0!==N$1){c=b.treeContext;b.treeContext=gb$1(c,1,0);try{X$1(a,b,d);}finally{b.treeContext=
c;}}else X$1(a,b,d);return;case Qa$1:c=c.type;d=Fb(c,d);Gb$1(a,b,c,d,f);return;case La$1:f=d.children;c=c._context;d=d.value;e=c._currentValue2;c._currentValue2=d;g=E$1;E$1=d={parent:g,depth:null===g?0:g.depth+1,context:c,parentValue:e,value:d};b.context=d;X$1(a,b,f);a=E$1;if(null===a)throw Error(l$2(403));d=a.parentValue;a.context._currentValue2=d===Va$1?a.context._defaultValue:d;a=E$1=a.parent;b.context=a;return;case Ma$1:d=d.children;d=d(c._currentValue2);X$1(a,b,d);return;case Ra$1:f=c._init;c=f(c._payload);d=Fb(c,d);Gb$1(a,
b,c,d,void 0);return}throw Error(l$2(130,null==c?c:typeof c,""));}}
function X$1(a,b,c){b.node=c;if("object"===typeof c&&null!==c){switch(c.$$typeof){case Ga$1:Gb$1(a,b,c.type,c.props,c.ref);return;case Ha$1:throw Error(l$2(257));case Ra$1:var d=c._init;c=d(c._payload);X$1(a,b,c);return}if(qa$1(c)){Ib$1(a,b,c);return}null===c||"object"!==typeof c?d=null:(d=Wa$1&&c[Wa$1]||c["@@iterator"],d="function"===typeof d?d:null);if(d&&(d=d.call(c))){c=d.next();if(!c.done){var f=[];do f.push(c.value),c=d.next();while(!c.done);Ib$1(a,b,f);}return}a=Object.prototype.toString.call(c);throw Error(l$2(31,"[object Object]"===
a?"object with keys {"+Object.keys(c).join(", ")+"}":a));}"string"===typeof c?(d=b.blockedSegment,d.lastPushedText=Fa$1(b.blockedSegment.chunks,c,a.responseState,d.lastPushedText)):"number"===typeof c&&(d=b.blockedSegment,d.lastPushedText=Fa$1(b.blockedSegment.chunks,""+c,a.responseState,d.lastPushedText));}function Ib$1(a,b,c){for(var d=c.length,f=0;f<d;f++){var e=b.treeContext;b.treeContext=gb$1(e,d,f);try{Hb$1(a,b,c[f]);}finally{b.treeContext=e;}}}
function Hb$1(a,b,c){var d=b.blockedSegment.formatContext,f=b.legacyContext,e=b.context;try{return X$1(a,b,c)}catch(k){if(rb$1(),"object"===typeof k&&null!==k&&"function"===typeof k.then){c=k;var g=b.blockedSegment,h=U$1(a,g.chunks.length,null,g.formatContext,g.lastPushedText,!0);g.children.push(h);g.lastPushedText=!1;a=Bb$1(a,b.node,b.blockedBoundary,h,b.abortSet,b.legacyContext,b.context,b.treeContext).ping;c.then(a,a);b.blockedSegment.formatContext=d;b.legacyContext=f;b.context=e;G(e);}else throw b.blockedSegment.formatContext=
d,b.legacyContext=f,b.context=e,G(e),k;}}function Jb$1(a){var b=a.blockedBoundary;a=a.blockedSegment;a.status=3;Kb$1(this,b,a);}
function Lb$1(a,b,c){var d=a.blockedBoundary;a.blockedSegment.status=3;null===d?(b.allPendingTasks--,2!==b.status&&(b.status=2,null!==b.destination&&b.destination.push(null))):(d.pendingTasks--,d.forceClientRender||(d.forceClientRender=!0,a=void 0===c?Error(l$2(432)):c,d.errorDigest=b.onError(a),d.parentFlushed&&b.clientRenderedBoundaries.push(d)),d.fallbackAbortableTasks.forEach(function(a){return Lb$1(a,b,c)}),d.fallbackAbortableTasks.clear(),b.allPendingTasks--,0===b.allPendingTasks&&(d=b.onAllReady,
d()));}function Y$1(a,b){if(0===b.chunks.length&&1===b.children.length&&null===b.children[0].boundary){var c=b.children[0];c.id=b.id;c.parentFlushed=!0;1===c.status&&Y$1(a,c);}else a.completedSegments.push(b);}
function Kb$1(a,b,c){if(null===b){if(c.parentFlushed){if(null!==a.completedRootSegment)throw Error(l$2(389));a.completedRootSegment=c;}a.pendingRootTasks--;0===a.pendingRootTasks&&(a.onShellError=T$1,b=a.onShellReady,b());}else b.pendingTasks--,b.forceClientRender||(0===b.pendingTasks?(c.parentFlushed&&1===c.status&&Y$1(b,c),b.parentFlushed&&a.completedBoundaries.push(b),b.fallbackAbortableTasks.forEach(Jb$1,a),b.fallbackAbortableTasks.clear()):c.parentFlushed&&1===c.status&&(Y$1(b,c),1===b.completedSegments.length&&
b.parentFlushed&&a.partialBoundaries.push(b)));a.allPendingTasks--;0===a.allPendingTasks&&(a=a.onAllReady,a());}
function Cb$1(a){if(2!==a.status){var b=E$1,c=yb$1.current;yb$1.current=xb$1;var d=S$1;S$1=a.responseState;try{var f=a.pingedTasks,e;for(e=0;e<f.length;e++){var g=f[e];var h=a,k=g.blockedSegment;if(0===k.status){G(g.context);try{X$1(h,g,g.node),h.responseState.generateStaticMarkup||k.lastPushedText&&k.textEmbedded&&k.chunks.push("\x3c!-- --\x3e"),g.abortSet.delete(g),k.status=1,Kb$1(h,g.blockedBoundary,k);}catch(z){if(rb$1(),"object"===typeof z&&null!==z&&"function"===typeof z.then){var m=g.ping;z.then(m,m);}else {g.abortSet.delete(g);
k.status=4;var n=g.blockedBoundary,q=z,C=V$1(h,q);null===n?W$1(h,q):(n.pendingTasks--,n.forceClientRender||(n.forceClientRender=!0,n.errorDigest=C,n.parentFlushed&&h.clientRenderedBoundaries.push(n)));h.allPendingTasks--;if(0===h.allPendingTasks){var D=h.onAllReady;D();}}}finally{}}}f.splice(0,e);null!==a.destination&&Mb$1(a,a.destination);}catch(z){V$1(a,z),W$1(a,z);}finally{S$1=d,yb$1.current=c,c===xb$1&&G(b);}}}
function Z$1(a,b,c){c.parentFlushed=!0;switch(c.status){case 0:var d=c.id=a.nextSegmentId++;c.lastPushedText=!1;c.textEmbedded=!1;a=a.responseState;b.push('<template id="');b.push(a.placeholderPrefix);a=d.toString(16);b.push(a);return b.push('"></template>');case 1:c.status=2;var f=!0;d=c.chunks;var e=0;c=c.children;for(var g=0;g<c.length;g++){for(f=c[g];e<f.index;e++)b.push(d[e]);f=Nb$1(a,b,f);}for(;e<d.length-1;e++)b.push(d[e]);e<d.length&&(f=b.push(d[e]));return f;default:throw Error(l$2(390));}}
function Nb$1(a,b,c){var d=c.boundary;if(null===d)return Z$1(a,b,c);d.parentFlushed=!0;if(d.forceClientRender)return a.responseState.generateStaticMarkup||(d=d.errorDigest,b.push("\x3c!--$!--\x3e"),b.push("<template"),d&&(b.push(' data-dgst="'),d=v(d),b.push(d),b.push('"')),b.push("></template>")),Z$1(a,b,c),a=a.responseState.generateStaticMarkup?!0:b.push("\x3c!--/$--\x3e"),a;if(0<d.pendingTasks){d.rootSegmentID=a.nextSegmentId++;0<d.completedSegments.length&&a.partialBoundaries.push(d);var f=a.responseState;
var e=f.nextSuspenseID++;f=f.boundaryPrefix+e.toString(16);d=d.id=f;za$1(b,a.responseState,d);Z$1(a,b,c);return b.push("\x3c!--/$--\x3e")}if(d.byteSize>a.progressiveChunkSize)return d.rootSegmentID=a.nextSegmentId++,a.completedBoundaries.push(d),za$1(b,a.responseState,d.id),Z$1(a,b,c),b.push("\x3c!--/$--\x3e");a.responseState.generateStaticMarkup||b.push("\x3c!--$--\x3e");c=d.completedSegments;if(1!==c.length)throw Error(l$2(391));Nb$1(a,b,c[0]);a=a.responseState.generateStaticMarkup?!0:b.push("\x3c!--/$--\x3e");
return a}function Ob$1(a,b,c){Aa$1(b,a.responseState,c.formatContext,c.id);Nb$1(a,b,c);return Ba$1(b,c.formatContext)}
function Pb$1(a,b,c){for(var d=c.completedSegments,f=0;f<d.length;f++)Qb$1(a,b,c,d[f]);d.length=0;a=a.responseState;d=c.id;c=c.rootSegmentID;b.push(a.startInlineScript);a.sentCompleteBoundaryFunction?b.push('$RC("'):(a.sentCompleteBoundaryFunction=!0,b.push('function $RC(a,b){a=document.getElementById(a);b=document.getElementById(b);b.parentNode.removeChild(b);if(a){a=a.previousSibling;var f=a.parentNode,c=a.nextSibling,e=0;do{if(c&&8===c.nodeType){var d=c.data;if("/$"===d)if(0===e)break;else e--;else"$"!==d&&"$?"!==d&&"$!"!==d||e++}d=c.nextSibling;f.removeChild(c);c=d}while(c);for(;b.firstChild;)f.insertBefore(b.firstChild,c);a.data="$";a._reactRetry&&a._reactRetry()}};$RC("'));if(null===
d)throw Error(l$2(395));c=c.toString(16);b.push(d);b.push('","');b.push(a.segmentPrefix);b.push(c);return b.push('")\x3c/script>')}
function Qb$1(a,b,c,d){if(2===d.status)return !0;var f=d.id;if(-1===f){if(-1===(d.id=c.rootSegmentID))throw Error(l$2(392));return Ob$1(a,b,d)}Ob$1(a,b,d);a=a.responseState;b.push(a.startInlineScript);a.sentCompleteSegmentFunction?b.push('$RS("'):(a.sentCompleteSegmentFunction=!0,b.push('function $RS(a,b){a=document.getElementById(a);b=document.getElementById(b);for(a.parentNode.removeChild(a);a.firstChild;)b.parentNode.insertBefore(a.firstChild,b);b.parentNode.removeChild(b)};$RS("'));b.push(a.segmentPrefix);
f=f.toString(16);b.push(f);b.push('","');b.push(a.placeholderPrefix);b.push(f);return b.push('")\x3c/script>')}
function Mb$1(a,b){try{var c=a.completedRootSegment;if(null!==c&&0===a.pendingRootTasks){Nb$1(a,b,c);a.completedRootSegment=null;var d=a.responseState.bootstrapChunks;for(c=0;c<d.length-1;c++)b.push(d[c]);c<d.length&&b.push(d[c]);}var f=a.clientRenderedBoundaries,e;for(e=0;e<f.length;e++){var g=f[e];d=b;var h=a.responseState,k=g.id,m=g.errorDigest,n=g.errorMessage,q=g.errorComponentStack;d.push(h.startInlineScript);h.sentClientRenderFunction?d.push('$RX("'):(h.sentClientRenderFunction=!0,d.push('function $RX(b,c,d,e){var a=document.getElementById(b);a&&(b=a.previousSibling,b.data="$!",a=a.dataset,c&&(a.dgst=c),d&&(a.msg=d),e&&(a.stck=e),b._reactRetry&&b._reactRetry())};$RX("'));
if(null===k)throw Error(l$2(395));d.push(k);d.push('"');if(m||n||q){d.push(",");var C=Da$1(m||"");d.push(C);}if(n||q){d.push(",");var D=Da$1(n||"");d.push(D);}if(q){d.push(",");var z=Da$1(q);d.push(z);}if(!d.push(")\x3c/script>")){a.destination=null;e++;f.splice(0,e);return}}f.splice(0,e);var ba=a.completedBoundaries;for(e=0;e<ba.length;e++)if(!Pb$1(a,b,ba[e])){a.destination=null;e++;ba.splice(0,e);return}ba.splice(0,e);var ca=a.partialBoundaries;for(e=0;e<ca.length;e++){var mb=ca[e];a:{f=a;g=b;var da=mb.completedSegments;
for(h=0;h<da.length;h++)if(!Qb$1(f,g,mb,da[h])){h++;da.splice(0,h);var nb=!1;break a}da.splice(0,h);nb=!0;}if(!nb){a.destination=null;e++;ca.splice(0,e);return}}ca.splice(0,e);var ea=a.completedBoundaries;for(e=0;e<ea.length;e++)if(!Pb$1(a,b,ea[e])){a.destination=null;e++;ea.splice(0,e);return}ea.splice(0,e);}finally{0===a.allPendingTasks&&0===a.pingedTasks.length&&0===a.clientRenderedBoundaries.length&&0===a.completedBoundaries.length&&b.push(null);}}
function Rb$1(a,b){try{var c=a.abortableTasks;c.forEach(function(c){return Lb$1(c,a,b)});c.clear();null!==a.destination&&Mb$1(a,a.destination);}catch(d){V$1(a,d),W$1(a,d);}}function Sb$1(){}
function Tb$1(a,b,c,d){var f=!1,e=null,g="",h={push:function(a){null!==a&&(g+=a);return !0},destroy:function(a){f=!0;e=a;}},k=!1;a=Ab$1(a,Ea$1(c,b?b.identifierPrefix:void 0),{insertionMode:1,selectedValue:null},Infinity,Sb$1,void 0,function(){k=!0;},void 0,void 0);Cb$1(a);Rb$1(a,d);if(1===a.status)a.status=2,h.destroy(a.fatalError);else if(2!==a.status&&null===a.destination){a.destination=h;try{Mb$1(a,h);}catch(m){V$1(a,m),W$1(a,m);}}if(f)throw e;if(!k)throw Error(l$2(426));return g}
reactDomServerLegacy_browser_production_min.renderToNodeStream=function(){throw Error(l$2(207));};reactDomServerLegacy_browser_production_min.renderToStaticMarkup=function(a,b){return Tb$1(a,b,!0,'The server used "renderToStaticMarkup" which does not support Suspense. If you intended to have the server wait for the suspended component please switch to "renderToReadableStream" which supports Suspense on the server')};reactDomServerLegacy_browser_production_min.renderToStaticNodeStream=function(){throw Error(l$2(208));};reactDomServerLegacy_browser_production_min.renderToString=function(a,b){return Tb$1(a,b,!1,'The server used "renderToString" which does not support Suspense. If you intended for this Suspense boundary to render the fallback content on the server consider throwing an Error somewhere within the Suspense boundary. If you intended to have the server wait for the suspended component please switch to "renderToReadableStream" which supports Suspense on the server')};
reactDomServerLegacy_browser_production_min.version="18.2.0";

var reactDomServer_browser_production_min = {};

/**
 * @license React
 * react-dom-server.browser.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var aa=React;function k(a){for(var b="https://reactjs.org/docs/error-decoder.html?invariant="+a,c=1;c<arguments.length;c++)b+="&args[]="+encodeURIComponent(arguments[c]);return "Minified React error #"+a+"; visit "+b+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}var l$1=null,n=0;
function p(a,b){if(0!==b.length)if(512<b.length)0<n&&(a.enqueue(new Uint8Array(l$1.buffer,0,n)),l$1=new Uint8Array(512),n=0),a.enqueue(b);else {var c=l$1.length-n;c<b.length&&(0===c?a.enqueue(l$1):(l$1.set(b.subarray(0,c),n),a.enqueue(l$1),b=b.subarray(c)),l$1=new Uint8Array(512),n=0);l$1.set(b,n);n+=b.length;}}function t(a,b){p(a,b);return !0}function ba(a){l$1&&0<n&&(a.enqueue(new Uint8Array(l$1.buffer,0,n)),l$1=null,n=0);}var ca=new TextEncoder;function u(a){return ca.encode(a)}function w(a){return ca.encode(a)}
function da(a,b){"function"===typeof a.error?a.error(b):a.close();}var x=Object.prototype.hasOwnProperty,ea=/^[:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD][:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\-.0-9\u00B7\u0300-\u036F\u203F-\u2040]*$/,fa={},ha={};
function ia(a){if(x.call(ha,a))return !0;if(x.call(fa,a))return !1;if(ea.test(a))return ha[a]=!0;fa[a]=!0;return !1}function y(a,b,c,d,f,e,g){this.acceptsBooleans=2===b||3===b||4===b;this.attributeName=d;this.attributeNamespace=f;this.mustUseProperty=c;this.propertyName=a;this.type=b;this.sanitizeURL=e;this.removeEmptyString=g;}var z={};
"children dangerouslySetInnerHTML defaultValue defaultChecked innerHTML suppressContentEditableWarning suppressHydrationWarning style".split(" ").forEach(function(a){z[a]=new y(a,0,!1,a,null,!1,!1);});[["acceptCharset","accept-charset"],["className","class"],["htmlFor","for"],["httpEquiv","http-equiv"]].forEach(function(a){var b=a[0];z[b]=new y(b,1,!1,a[1],null,!1,!1);});["contentEditable","draggable","spellCheck","value"].forEach(function(a){z[a]=new y(a,2,!1,a.toLowerCase(),null,!1,!1);});
["autoReverse","externalResourcesRequired","focusable","preserveAlpha"].forEach(function(a){z[a]=new y(a,2,!1,a,null,!1,!1);});"allowFullScreen async autoFocus autoPlay controls default defer disabled disablePictureInPicture disableRemotePlayback formNoValidate hidden loop noModule noValidate open playsInline readOnly required reversed scoped seamless itemScope".split(" ").forEach(function(a){z[a]=new y(a,3,!1,a.toLowerCase(),null,!1,!1);});
["checked","multiple","muted","selected"].forEach(function(a){z[a]=new y(a,3,!0,a,null,!1,!1);});["capture","download"].forEach(function(a){z[a]=new y(a,4,!1,a,null,!1,!1);});["cols","rows","size","span"].forEach(function(a){z[a]=new y(a,6,!1,a,null,!1,!1);});["rowSpan","start"].forEach(function(a){z[a]=new y(a,5,!1,a.toLowerCase(),null,!1,!1);});var ja=/[\-:]([a-z])/g;function ka(a){return a[1].toUpperCase()}
"accent-height alignment-baseline arabic-form baseline-shift cap-height clip-path clip-rule color-interpolation color-interpolation-filters color-profile color-rendering dominant-baseline enable-background fill-opacity fill-rule flood-color flood-opacity font-family font-size font-size-adjust font-stretch font-style font-variant font-weight glyph-name glyph-orientation-horizontal glyph-orientation-vertical horiz-adv-x horiz-origin-x image-rendering letter-spacing lighting-color marker-end marker-mid marker-start overline-position overline-thickness paint-order panose-1 pointer-events rendering-intent shape-rendering stop-color stop-opacity strikethrough-position strikethrough-thickness stroke-dasharray stroke-dashoffset stroke-linecap stroke-linejoin stroke-miterlimit stroke-opacity stroke-width text-anchor text-decoration text-rendering underline-position underline-thickness unicode-bidi unicode-range units-per-em v-alphabetic v-hanging v-ideographic v-mathematical vector-effect vert-adv-y vert-origin-x vert-origin-y word-spacing writing-mode xmlns:xlink x-height".split(" ").forEach(function(a){var b=a.replace(ja,
ka);z[b]=new y(b,1,!1,a,null,!1,!1);});"xlink:actuate xlink:arcrole xlink:role xlink:show xlink:title xlink:type".split(" ").forEach(function(a){var b=a.replace(ja,ka);z[b]=new y(b,1,!1,a,"http://www.w3.org/1999/xlink",!1,!1);});["xml:base","xml:lang","xml:space"].forEach(function(a){var b=a.replace(ja,ka);z[b]=new y(b,1,!1,a,"http://www.w3.org/XML/1998/namespace",!1,!1);});["tabIndex","crossOrigin"].forEach(function(a){z[a]=new y(a,1,!1,a.toLowerCase(),null,!1,!1);});
z.xlinkHref=new y("xlinkHref",1,!1,"xlink:href","http://www.w3.org/1999/xlink",!0,!1);["src","href","action","formAction"].forEach(function(a){z[a]=new y(a,1,!1,a.toLowerCase(),null,!0,!0);});
var B={animationIterationCount:!0,aspectRatio:!0,borderImageOutset:!0,borderImageSlice:!0,borderImageWidth:!0,boxFlex:!0,boxFlexGroup:!0,boxOrdinalGroup:!0,columnCount:!0,columns:!0,flex:!0,flexGrow:!0,flexPositive:!0,flexShrink:!0,flexNegative:!0,flexOrder:!0,gridArea:!0,gridRow:!0,gridRowEnd:!0,gridRowSpan:!0,gridRowStart:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnSpan:!0,gridColumnStart:!0,fontWeight:!0,lineClamp:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,tabSize:!0,widows:!0,zIndex:!0,zoom:!0,
fillOpacity:!0,floodOpacity:!0,stopOpacity:!0,strokeDasharray:!0,strokeDashoffset:!0,strokeMiterlimit:!0,strokeOpacity:!0,strokeWidth:!0},la=["Webkit","ms","Moz","O"];Object.keys(B).forEach(function(a){la.forEach(function(b){b=b+a.charAt(0).toUpperCase()+a.substring(1);B[b]=B[a];});});var oa=/["'&<>]/;
function C(a){if("boolean"===typeof a||"number"===typeof a)return ""+a;a=""+a;var b=oa.exec(a);if(b){var c="",d,f=0;for(d=b.index;d<a.length;d++){switch(a.charCodeAt(d)){case 34:b="&quot;";break;case 38:b="&amp;";break;case 39:b="&#x27;";break;case 60:b="&lt;";break;case 62:b="&gt;";break;default:continue}f!==d&&(c+=a.substring(f,d));f=d+1;c+=b;}a=f!==d?c+a.substring(f,d):c;}return a}
var pa=/([A-Z])/g,qa=/^ms-/,ra=Array.isArray,sa=w("<script>"),ta=w("\x3c/script>"),ua=w('<script src="'),va=w('<script type="module" src="'),wa=w('" async="">\x3c/script>'),xa=/(<\/|<)(s)(cript)/gi;function ya(a,b,c,d){return ""+b+("s"===c?"\\u0073":"\\u0053")+d}
function za(a,b,c,d,f){a=void 0===a?"":a;b=void 0===b?sa:w('<script nonce="'+C(b)+'">');var e=[];void 0!==c&&e.push(b,u((""+c).replace(xa,ya)),ta);if(void 0!==d)for(c=0;c<d.length;c++)e.push(ua,u(C(d[c])),wa);if(void 0!==f)for(d=0;d<f.length;d++)e.push(va,u(C(f[d])),wa);return {bootstrapChunks:e,startInlineScript:b,placeholderPrefix:w(a+"P:"),segmentPrefix:w(a+"S:"),boundaryPrefix:a+"B:",idPrefix:a,nextSuspenseID:0,sentCompleteSegmentFunction:!1,sentCompleteBoundaryFunction:!1,sentClientRenderFunction:!1}}
function D(a,b){return {insertionMode:a,selectedValue:b}}function Aa(a){return D("http://www.w3.org/2000/svg"===a?2:"http://www.w3.org/1998/Math/MathML"===a?3:0,null)}
function Ba(a,b,c){switch(b){case "select":return D(1,null!=c.value?c.value:c.defaultValue);case "svg":return D(2,null);case "math":return D(3,null);case "foreignObject":return D(1,null);case "table":return D(4,null);case "thead":case "tbody":case "tfoot":return D(5,null);case "colgroup":return D(7,null);case "tr":return D(6,null)}return 4<=a.insertionMode||0===a.insertionMode?D(1,null):a}var Ca=w("\x3c!-- --\x3e");function Da(a,b,c,d){if(""===b)return d;d&&a.push(Ca);a.push(u(C(b)));return !0}
var Ea=new Map,Fa=w(' style="'),Ga=w(":"),Ha=w(";");
function Ia(a,b,c){if("object"!==typeof c)throw Error(k(62));b=!0;for(var d in c)if(x.call(c,d)){var f=c[d];if(null!=f&&"boolean"!==typeof f&&""!==f){if(0===d.indexOf("--")){var e=u(C(d));f=u(C((""+f).trim()));}else {e=d;var g=Ea.get(e);void 0!==g?e=g:(g=w(C(e.replace(pa,"-$1").toLowerCase().replace(qa,"-ms-"))),Ea.set(e,g),e=g);f="number"===typeof f?0===f||x.call(B,d)?u(""+f):u(f+"px"):u(C((""+f).trim()));}b?(b=!1,a.push(Fa,e,Ga,f)):a.push(Ha,e,Ga,f);}}b||a.push(E);}
var H=w(" "),I=w('="'),E=w('"'),Ja=w('=""');
function J(a,b,c,d){switch(c){case "style":Ia(a,b,d);return;case "defaultValue":case "defaultChecked":case "innerHTML":case "suppressContentEditableWarning":case "suppressHydrationWarning":return}if(!(2<c.length)||"o"!==c[0]&&"O"!==c[0]||"n"!==c[1]&&"N"!==c[1])if(b=z.hasOwnProperty(c)?z[c]:null,null!==b){switch(typeof d){case "function":case "symbol":return;case "boolean":if(!b.acceptsBooleans)return}c=u(b.attributeName);switch(b.type){case 3:d&&a.push(H,c,Ja);break;case 4:!0===d?a.push(H,c,Ja):!1!==
d&&a.push(H,c,I,u(C(d)),E);break;case 5:isNaN(d)||a.push(H,c,I,u(C(d)),E);break;case 6:!isNaN(d)&&1<=d&&a.push(H,c,I,u(C(d)),E);break;default:b.sanitizeURL&&(d=""+d),a.push(H,c,I,u(C(d)),E);}}else if(ia(c)){switch(typeof d){case "function":case "symbol":return;case "boolean":if(b=c.toLowerCase().slice(0,5),"data-"!==b&&"aria-"!==b)return}a.push(H,u(c),I,u(C(d)),E);}}var K=w(">"),Ka=w("/>");
function L(a,b,c){if(null!=b){if(null!=c)throw Error(k(60));if("object"!==typeof b||!("__html"in b))throw Error(k(61));b=b.__html;null!==b&&void 0!==b&&a.push(u(""+b));}}function La(a){var b="";aa.Children.forEach(a,function(a){null!=a&&(b+=a);});return b}var Ma=w(' selected=""');
function Na(a,b,c,d){a.push(M(c));var f=c=null,e;for(e in b)if(x.call(b,e)){var g=b[e];if(null!=g)switch(e){case "children":c=g;break;case "dangerouslySetInnerHTML":f=g;break;default:J(a,d,e,g);}}a.push(K);L(a,f,c);return "string"===typeof c?(a.push(u(C(c))),null):c}var Oa=w("\n"),Pa=/^[a-zA-Z][a-zA-Z:_\.\-\d]*$/,Qa=new Map;function M(a){var b=Qa.get(a);if(void 0===b){if(!Pa.test(a))throw Error(k(65,a));b=w("<"+a);Qa.set(a,b);}return b}var Ra=w("<!DOCTYPE html>");
function Sa(a,b,c,d,f){switch(b){case "select":a.push(M("select"));var e=null,g=null;for(r in c)if(x.call(c,r)){var h=c[r];if(null!=h)switch(r){case "children":e=h;break;case "dangerouslySetInnerHTML":g=h;break;case "defaultValue":case "value":break;default:J(a,d,r,h);}}a.push(K);L(a,g,e);return e;case "option":g=f.selectedValue;a.push(M("option"));var m=h=null,q=null;var r=null;for(e in c)if(x.call(c,e)){var v=c[e];if(null!=v)switch(e){case "children":h=v;break;case "selected":q=v;break;case "dangerouslySetInnerHTML":r=
v;break;case "value":m=v;default:J(a,d,e,v);}}if(null!=g)if(c=null!==m?""+m:La(h),ra(g))for(d=0;d<g.length;d++){if(""+g[d]===c){a.push(Ma);break}}else ""+g===c&&a.push(Ma);else q&&a.push(Ma);a.push(K);L(a,r,h);return h;case "textarea":a.push(M("textarea"));r=g=e=null;for(h in c)if(x.call(c,h)&&(m=c[h],null!=m))switch(h){case "children":r=m;break;case "value":e=m;break;case "defaultValue":g=m;break;case "dangerouslySetInnerHTML":throw Error(k(91));default:J(a,d,h,m);}null===e&&null!==g&&(e=g);a.push(K);
if(null!=r){if(null!=e)throw Error(k(92));if(ra(r)&&1<r.length)throw Error(k(93));e=""+r;}"string"===typeof e&&"\n"===e[0]&&a.push(Oa);null!==e&&a.push(u(C(""+e)));return null;case "input":a.push(M("input"));m=r=h=e=null;for(g in c)if(x.call(c,g)&&(q=c[g],null!=q))switch(g){case "children":case "dangerouslySetInnerHTML":throw Error(k(399,"input"));case "defaultChecked":m=q;break;case "defaultValue":h=q;break;case "checked":r=q;break;case "value":e=q;break;default:J(a,d,g,q);}null!==r?J(a,d,"checked",
r):null!==m&&J(a,d,"checked",m);null!==e?J(a,d,"value",e):null!==h&&J(a,d,"value",h);a.push(Ka);return null;case "menuitem":a.push(M("menuitem"));for(var A in c)if(x.call(c,A)&&(e=c[A],null!=e))switch(A){case "children":case "dangerouslySetInnerHTML":throw Error(k(400));default:J(a,d,A,e);}a.push(K);return null;case "title":a.push(M("title"));e=null;for(v in c)if(x.call(c,v)&&(g=c[v],null!=g))switch(v){case "children":e=g;break;case "dangerouslySetInnerHTML":throw Error(k(434));default:J(a,d,v,g);}a.push(K);
return e;case "listing":case "pre":a.push(M(b));g=e=null;for(m in c)if(x.call(c,m)&&(h=c[m],null!=h))switch(m){case "children":e=h;break;case "dangerouslySetInnerHTML":g=h;break;default:J(a,d,m,h);}a.push(K);if(null!=g){if(null!=e)throw Error(k(60));if("object"!==typeof g||!("__html"in g))throw Error(k(61));c=g.__html;null!==c&&void 0!==c&&("string"===typeof c&&0<c.length&&"\n"===c[0]?a.push(Oa,u(c)):a.push(u(""+c)));}"string"===typeof e&&"\n"===e[0]&&a.push(Oa);return e;case "area":case "base":case "br":case "col":case "embed":case "hr":case "img":case "keygen":case "link":case "meta":case "param":case "source":case "track":case "wbr":a.push(M(b));
for(var F in c)if(x.call(c,F)&&(e=c[F],null!=e))switch(F){case "children":case "dangerouslySetInnerHTML":throw Error(k(399,b));default:J(a,d,F,e);}a.push(Ka);return null;case "annotation-xml":case "color-profile":case "font-face":case "font-face-src":case "font-face-uri":case "font-face-format":case "font-face-name":case "missing-glyph":return Na(a,c,b,d);case "html":return 0===f.insertionMode&&a.push(Ra),Na(a,c,b,d);default:if(-1===b.indexOf("-")&&"string"!==typeof c.is)return Na(a,c,b,d);a.push(M(b));
g=e=null;for(q in c)if(x.call(c,q)&&(h=c[q],null!=h))switch(q){case "children":e=h;break;case "dangerouslySetInnerHTML":g=h;break;case "style":Ia(a,d,h);break;case "suppressContentEditableWarning":case "suppressHydrationWarning":break;default:ia(q)&&"function"!==typeof h&&"symbol"!==typeof h&&a.push(H,u(q),I,u(C(h)),E);}a.push(K);L(a,g,e);return e}}
var Ta=w("</"),Ua=w(">"),Va=w('<template id="'),Wa=w('"></template>'),Xa=w("\x3c!--$--\x3e"),Ya=w('\x3c!--$?--\x3e<template id="'),Za=w('"></template>'),$a=w("\x3c!--$!--\x3e"),ab=w("\x3c!--/$--\x3e"),bb=w("<template"),cb=w('"'),db=w(' data-dgst="');w(' data-msg="');w(' data-stck="');var eb=w("></template>");function fb(a,b,c){p(a,Ya);if(null===c)throw Error(k(395));p(a,c);return t(a,Za)}
var gb=w('<div hidden id="'),hb=w('">'),ib=w("</div>"),jb=w('<svg aria-hidden="true" style="display:none" id="'),kb=w('">'),lb=w("</svg>"),mb=w('<math aria-hidden="true" style="display:none" id="'),nb=w('">'),ob=w("</math>"),pb=w('<table hidden id="'),qb=w('">'),rb=w("</table>"),sb=w('<table hidden><tbody id="'),tb=w('">'),ub=w("</tbody></table>"),vb=w('<table hidden><tr id="'),wb=w('">'),xb=w("</tr></table>"),yb=w('<table hidden><colgroup id="'),zb=w('">'),Ab=w("</colgroup></table>");
function Bb(a,b,c,d){switch(c.insertionMode){case 0:case 1:return p(a,gb),p(a,b.segmentPrefix),p(a,u(d.toString(16))),t(a,hb);case 2:return p(a,jb),p(a,b.segmentPrefix),p(a,u(d.toString(16))),t(a,kb);case 3:return p(a,mb),p(a,b.segmentPrefix),p(a,u(d.toString(16))),t(a,nb);case 4:return p(a,pb),p(a,b.segmentPrefix),p(a,u(d.toString(16))),t(a,qb);case 5:return p(a,sb),p(a,b.segmentPrefix),p(a,u(d.toString(16))),t(a,tb);case 6:return p(a,vb),p(a,b.segmentPrefix),p(a,u(d.toString(16))),t(a,wb);case 7:return p(a,
yb),p(a,b.segmentPrefix),p(a,u(d.toString(16))),t(a,zb);default:throw Error(k(397));}}function Cb(a,b){switch(b.insertionMode){case 0:case 1:return t(a,ib);case 2:return t(a,lb);case 3:return t(a,ob);case 4:return t(a,rb);case 5:return t(a,ub);case 6:return t(a,xb);case 7:return t(a,Ab);default:throw Error(k(397));}}
var Db=w('function $RS(a,b){a=document.getElementById(a);b=document.getElementById(b);for(a.parentNode.removeChild(a);a.firstChild;)b.parentNode.insertBefore(a.firstChild,b);b.parentNode.removeChild(b)};$RS("'),Eb=w('$RS("'),Gb=w('","'),Hb=w('")\x3c/script>'),Ib=w('function $RC(a,b){a=document.getElementById(a);b=document.getElementById(b);b.parentNode.removeChild(b);if(a){a=a.previousSibling;var f=a.parentNode,c=a.nextSibling,e=0;do{if(c&&8===c.nodeType){var d=c.data;if("/$"===d)if(0===e)break;else e--;else"$"!==d&&"$?"!==d&&"$!"!==d||e++}d=c.nextSibling;f.removeChild(c);c=d}while(c);for(;b.firstChild;)f.insertBefore(b.firstChild,c);a.data="$";a._reactRetry&&a._reactRetry()}};$RC("'),
Jb=w('$RC("'),Kb=w('","'),Lb=w('")\x3c/script>'),Mb=w('function $RX(b,c,d,e){var a=document.getElementById(b);a&&(b=a.previousSibling,b.data="$!",a=a.dataset,c&&(a.dgst=c),d&&(a.msg=d),e&&(a.stck=e),b._reactRetry&&b._reactRetry())};$RX("'),Nb=w('$RX("'),Ob=w('"'),Pb=w(")\x3c/script>"),Qb=w(","),Rb=/[<\u2028\u2029]/g;
function Sb(a){return JSON.stringify(a).replace(Rb,function(a){switch(a){case "<":return "\\u003c";case "\u2028":return "\\u2028";case "\u2029":return "\\u2029";default:throw Error("escapeJSStringsForInstructionScripts encountered a match it does not know how to replace. this means the match regex and the replacement characters are no longer in sync. This is a bug in React");}})}
var N=Object.assign,Tb=Symbol.for("react.element"),Ub=Symbol.for("react.portal"),Vb=Symbol.for("react.fragment"),Wb=Symbol.for("react.strict_mode"),Xb=Symbol.for("react.profiler"),Yb=Symbol.for("react.provider"),Zb=Symbol.for("react.context"),$b=Symbol.for("react.forward_ref"),ac=Symbol.for("react.suspense"),bc=Symbol.for("react.suspense_list"),cc=Symbol.for("react.memo"),dc=Symbol.for("react.lazy"),ec=Symbol.for("react.scope"),fc=Symbol.for("react.debug_trace_mode"),gc=Symbol.for("react.legacy_hidden"),
hc=Symbol.for("react.default_value"),ic=Symbol.iterator;
function jc(a){if(null==a)return null;if("function"===typeof a)return a.displayName||a.name||null;if("string"===typeof a)return a;switch(a){case Vb:return "Fragment";case Ub:return "Portal";case Xb:return "Profiler";case Wb:return "StrictMode";case ac:return "Suspense";case bc:return "SuspenseList"}if("object"===typeof a)switch(a.$$typeof){case Zb:return (a.displayName||"Context")+".Consumer";case Yb:return (a._context.displayName||"Context")+".Provider";case $b:var b=a.render;a=a.displayName;a||(a=b.displayName||
b.name||"",a=""!==a?"ForwardRef("+a+")":"ForwardRef");return a;case cc:return b=a.displayName||null,null!==b?b:jc(a.type)||"Memo";case dc:b=a._payload;a=a._init;try{return jc(a(b))}catch(c){}}return null}var kc={};function lc(a,b){a=a.contextTypes;if(!a)return kc;var c={},d;for(d in a)c[d]=b[d];return c}var O=null;
function P(a,b){if(a!==b){a.context._currentValue=a.parentValue;a=a.parent;var c=b.parent;if(null===a){if(null!==c)throw Error(k(401));}else {if(null===c)throw Error(k(401));P(a,c);}b.context._currentValue=b.value;}}function mc(a){a.context._currentValue=a.parentValue;a=a.parent;null!==a&&mc(a);}function nc(a){var b=a.parent;null!==b&&nc(b);a.context._currentValue=a.value;}
function oc(a,b){a.context._currentValue=a.parentValue;a=a.parent;if(null===a)throw Error(k(402));a.depth===b.depth?P(a,b):oc(a,b);}function pc(a,b){var c=b.parent;if(null===c)throw Error(k(402));a.depth===c.depth?P(a,c):pc(a,c);b.context._currentValue=b.value;}function Q(a){var b=O;b!==a&&(null===b?nc(a):null===a?mc(b):b.depth===a.depth?P(b,a):b.depth>a.depth?oc(b,a):pc(b,a),O=a);}
var qc={isMounted:function(){return !1},enqueueSetState:function(a,b){a=a._reactInternals;null!==a.queue&&a.queue.push(b);},enqueueReplaceState:function(a,b){a=a._reactInternals;a.replace=!0;a.queue=[b];},enqueueForceUpdate:function(){}};
function rc(a,b,c,d){var f=void 0!==a.state?a.state:null;a.updater=qc;a.props=c;a.state=f;var e={queue:[],replace:!1};a._reactInternals=e;var g=b.contextType;a.context="object"===typeof g&&null!==g?g._currentValue:d;g=b.getDerivedStateFromProps;"function"===typeof g&&(g=g(c,f),f=null===g||void 0===g?f:N({},f,g),a.state=f);if("function"!==typeof b.getDerivedStateFromProps&&"function"!==typeof a.getSnapshotBeforeUpdate&&("function"===typeof a.UNSAFE_componentWillMount||"function"===typeof a.componentWillMount))if(b=
a.state,"function"===typeof a.componentWillMount&&a.componentWillMount(),"function"===typeof a.UNSAFE_componentWillMount&&a.UNSAFE_componentWillMount(),b!==a.state&&qc.enqueueReplaceState(a,a.state,null),null!==e.queue&&0<e.queue.length)if(b=e.queue,g=e.replace,e.queue=null,e.replace=!1,g&&1===b.length)a.state=b[0];else {e=g?b[0]:a.state;f=!0;for(g=g?1:0;g<b.length;g++){var h=b[g];h="function"===typeof h?h.call(a,e,c,d):h;null!=h&&(f?(f=!1,e=N({},e,h)):N(e,h));}a.state=e;}else e.queue=null;}
var sc={id:1,overflow:""};function tc(a,b,c){var d=a.id;a=a.overflow;var f=32-uc(d)-1;d&=~(1<<f);c+=1;var e=32-uc(b)+f;if(30<e){var g=f-f%5;e=(d&(1<<g)-1).toString(32);d>>=g;f-=g;return {id:1<<32-uc(b)+f|c<<f|d,overflow:e+a}}return {id:1<<e|c<<f|d,overflow:a}}var uc=Math.clz32?Math.clz32:vc,wc=Math.log,xc=Math.LN2;function vc(a){a>>>=0;return 0===a?32:31-(wc(a)/xc|0)|0}function yc(a,b){return a===b&&(0!==a||1/a===1/b)||a!==a&&b!==b}
var zc="function"===typeof Object.is?Object.is:yc,R=null,Ac=null,Bc=null,S=null,T=!1,Cc=!1,U=0,V=null,Dc=0;function W(){if(null===R)throw Error(k(321));return R}function Ec(){if(0<Dc)throw Error(k(312));return {memoizedState:null,queue:null,next:null}}function Fc(){null===S?null===Bc?(T=!1,Bc=S=Ec()):(T=!0,S=Bc):null===S.next?(T=!1,S=S.next=Ec()):(T=!0,S=S.next);return S}function Gc(){Ac=R=null;Cc=!1;Bc=null;Dc=0;S=V=null;}function Hc(a,b){return "function"===typeof b?b(a):b}
function Ic(a,b,c){R=W();S=Fc();if(T){var d=S.queue;b=d.dispatch;if(null!==V&&(c=V.get(d),void 0!==c)){V.delete(d);d=S.memoizedState;do d=a(d,c.action),c=c.next;while(null!==c);S.memoizedState=d;return [d,b]}return [S.memoizedState,b]}a=a===Hc?"function"===typeof b?b():b:void 0!==c?c(b):b;S.memoizedState=a;a=S.queue={last:null,dispatch:null};a=a.dispatch=Jc.bind(null,R,a);return [S.memoizedState,a]}
function Kc(a,b){R=W();S=Fc();b=void 0===b?null:b;if(null!==S){var c=S.memoizedState;if(null!==c&&null!==b){var d=c[1];a:if(null===d)d=!1;else {for(var f=0;f<d.length&&f<b.length;f++)if(!zc(b[f],d[f])){d=!1;break a}d=!0;}if(d)return c[0]}}a=a();S.memoizedState=[a,b];return a}function Jc(a,b,c){if(25<=Dc)throw Error(k(301));if(a===R)if(Cc=!0,a={action:c,next:null},null===V&&(V=new Map),c=V.get(b),void 0===c)V.set(b,a);else {for(b=c;null!==b.next;)b=b.next;b.next=a;}}
function Lc(){throw Error(k(394));}function Mc(){}
var Oc={readContext:function(a){return a._currentValue},useContext:function(a){W();return a._currentValue},useMemo:Kc,useReducer:Ic,useRef:function(a){R=W();S=Fc();var b=S.memoizedState;return null===b?(a={current:a},S.memoizedState=a):b},useState:function(a){return Ic(Hc,a)},useInsertionEffect:Mc,useLayoutEffect:function(){},useCallback:function(a,b){return Kc(function(){return a},b)},useImperativeHandle:Mc,useEffect:Mc,useDebugValue:Mc,useDeferredValue:function(a){W();return a},useTransition:function(){W();
return [!1,Lc]},useId:function(){var a=Ac.treeContext;var b=a.overflow;a=a.id;a=(a&~(1<<32-uc(a)-1)).toString(32)+b;var c=Nc;if(null===c)throw Error(k(404));b=U++;a=":"+c.idPrefix+"R"+a;0<b&&(a+="H"+b.toString(32));return a+":"},useMutableSource:function(a,b){W();return b(a._source)},useSyncExternalStore:function(a,b,c){if(void 0===c)throw Error(k(407));return c()}},Nc=null,Pc=aa.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED.ReactCurrentDispatcher;function Qc(a){console.error(a);return null}
function X(){}
function Rc(a,b,c,d,f,e,g,h,m){var q=[],r=new Set;b={destination:null,responseState:b,progressiveChunkSize:void 0===d?12800:d,status:0,fatalError:null,nextSegmentId:0,allPendingTasks:0,pendingRootTasks:0,completedRootSegment:null,abortableTasks:r,pingedTasks:q,clientRenderedBoundaries:[],completedBoundaries:[],partialBoundaries:[],onError:void 0===f?Qc:f,onAllReady:void 0===e?X:e,onShellReady:void 0===g?X:g,onShellError:void 0===h?X:h,onFatalError:void 0===m?X:m};c=Sc(b,0,null,c,!1,!1);c.parentFlushed=
!0;a=Tc(b,a,null,c,r,kc,null,sc);q.push(a);return b}function Tc(a,b,c,d,f,e,g,h){a.allPendingTasks++;null===c?a.pendingRootTasks++:c.pendingTasks++;var m={node:b,ping:function(){var b=a.pingedTasks;b.push(m);1===b.length&&Uc(a);},blockedBoundary:c,blockedSegment:d,abortSet:f,legacyContext:e,context:g,treeContext:h};f.add(m);return m}function Sc(a,b,c,d,f,e){return {status:0,id:-1,index:b,parentFlushed:!1,chunks:[],children:[],formatContext:d,boundary:c,lastPushedText:f,textEmbedded:e}}
function Y(a,b){a=a.onError(b);if(null!=a&&"string"!==typeof a)throw Error('onError returned something with a type other than "string". onError should return a string and may return null or undefined but must not return anything else. It received something of type "'+typeof a+'" instead');return a}function Vc(a,b){var c=a.onShellError;c(b);c=a.onFatalError;c(b);null!==a.destination?(a.status=2,da(a.destination,b)):(a.status=1,a.fatalError=b);}
function Wc(a,b,c,d,f){R={};Ac=b;U=0;for(a=c(d,f);Cc;)Cc=!1,U=0,Dc+=1,S=null,a=c(d,f);Gc();return a}function Xc(a,b,c,d){var f=c.render(),e=d.childContextTypes;if(null!==e&&void 0!==e){var g=b.legacyContext;if("function"!==typeof c.getChildContext)d=g;else {c=c.getChildContext();for(var h in c)if(!(h in e))throw Error(k(108,jc(d)||"Unknown",h));d=N({},g,c);}b.legacyContext=d;Z(a,b,f);b.legacyContext=g;}else Z(a,b,f);}
function Yc(a,b){if(a&&a.defaultProps){b=N({},b);a=a.defaultProps;for(var c in a)void 0===b[c]&&(b[c]=a[c]);return b}return b}
function Zc(a,b,c,d,f){if("function"===typeof c)if(c.prototype&&c.prototype.isReactComponent){f=lc(c,b.legacyContext);var e=c.contextType;e=new c(d,"object"===typeof e&&null!==e?e._currentValue:f);rc(e,c,d,f);Xc(a,b,e,c);}else {e=lc(c,b.legacyContext);f=Wc(a,b,c,d,e);var g=0!==U;if("object"===typeof f&&null!==f&&"function"===typeof f.render&&void 0===f.$$typeof)rc(f,c,d,e),Xc(a,b,f,c);else if(g){d=b.treeContext;b.treeContext=tc(d,1,0);try{Z(a,b,f);}finally{b.treeContext=d;}}else Z(a,b,f);}else if("string"===
typeof c){f=b.blockedSegment;e=Sa(f.chunks,c,d,a.responseState,f.formatContext);f.lastPushedText=!1;g=f.formatContext;f.formatContext=Ba(g,c,d);$c(a,b,e);f.formatContext=g;switch(c){case "area":case "base":case "br":case "col":case "embed":case "hr":case "img":case "input":case "keygen":case "link":case "meta":case "param":case "source":case "track":case "wbr":break;default:f.chunks.push(Ta,u(c),Ua);}f.lastPushedText=!1;}else {switch(c){case gc:case fc:case Wb:case Xb:case Vb:Z(a,b,d.children);return;
case bc:Z(a,b,d.children);return;case ec:throw Error(k(343));case ac:a:{c=b.blockedBoundary;f=b.blockedSegment;e=d.fallback;d=d.children;g=new Set;var h={id:null,rootSegmentID:-1,parentFlushed:!1,pendingTasks:0,forceClientRender:!1,completedSegments:[],byteSize:0,fallbackAbortableTasks:g,errorDigest:null},m=Sc(a,f.chunks.length,h,f.formatContext,!1,!1);f.children.push(m);f.lastPushedText=!1;var q=Sc(a,0,null,f.formatContext,!1,!1);q.parentFlushed=!0;b.blockedBoundary=h;b.blockedSegment=q;try{if($c(a,
b,d),q.lastPushedText&&q.textEmbedded&&q.chunks.push(Ca),q.status=1,ad(h,q),0===h.pendingTasks)break a}catch(r){q.status=4,h.forceClientRender=!0,h.errorDigest=Y(a,r);}finally{b.blockedBoundary=c,b.blockedSegment=f;}b=Tc(a,e,c,m,g,b.legacyContext,b.context,b.treeContext);a.pingedTasks.push(b);}return}if("object"===typeof c&&null!==c)switch(c.$$typeof){case $b:d=Wc(a,b,c.render,d,f);if(0!==U){c=b.treeContext;b.treeContext=tc(c,1,0);try{Z(a,b,d);}finally{b.treeContext=c;}}else Z(a,b,d);return;case cc:c=
c.type;d=Yc(c,d);Zc(a,b,c,d,f);return;case Yb:f=d.children;c=c._context;d=d.value;e=c._currentValue;c._currentValue=d;g=O;O=d={parent:g,depth:null===g?0:g.depth+1,context:c,parentValue:e,value:d};b.context=d;Z(a,b,f);a=O;if(null===a)throw Error(k(403));d=a.parentValue;a.context._currentValue=d===hc?a.context._defaultValue:d;a=O=a.parent;b.context=a;return;case Zb:d=d.children;d=d(c._currentValue);Z(a,b,d);return;case dc:f=c._init;c=f(c._payload);d=Yc(c,d);Zc(a,b,c,d,void 0);return}throw Error(k(130,
null==c?c:typeof c,""));}}
function Z(a,b,c){b.node=c;if("object"===typeof c&&null!==c){switch(c.$$typeof){case Tb:Zc(a,b,c.type,c.props,c.ref);return;case Ub:throw Error(k(257));case dc:var d=c._init;c=d(c._payload);Z(a,b,c);return}if(ra(c)){bd(a,b,c);return}null===c||"object"!==typeof c?d=null:(d=ic&&c[ic]||c["@@iterator"],d="function"===typeof d?d:null);if(d&&(d=d.call(c))){c=d.next();if(!c.done){var f=[];do f.push(c.value),c=d.next();while(!c.done);bd(a,b,f);}return}a=Object.prototype.toString.call(c);throw Error(k(31,"[object Object]"===
a?"object with keys {"+Object.keys(c).join(", ")+"}":a));}"string"===typeof c?(d=b.blockedSegment,d.lastPushedText=Da(b.blockedSegment.chunks,c,a.responseState,d.lastPushedText)):"number"===typeof c&&(d=b.blockedSegment,d.lastPushedText=Da(b.blockedSegment.chunks,""+c,a.responseState,d.lastPushedText));}function bd(a,b,c){for(var d=c.length,f=0;f<d;f++){var e=b.treeContext;b.treeContext=tc(e,d,f);try{$c(a,b,c[f]);}finally{b.treeContext=e;}}}
function $c(a,b,c){var d=b.blockedSegment.formatContext,f=b.legacyContext,e=b.context;try{return Z(a,b,c)}catch(m){if(Gc(),"object"===typeof m&&null!==m&&"function"===typeof m.then){c=m;var g=b.blockedSegment,h=Sc(a,g.chunks.length,null,g.formatContext,g.lastPushedText,!0);g.children.push(h);g.lastPushedText=!1;a=Tc(a,b.node,b.blockedBoundary,h,b.abortSet,b.legacyContext,b.context,b.treeContext).ping;c.then(a,a);b.blockedSegment.formatContext=d;b.legacyContext=f;b.context=e;Q(e);}else throw b.blockedSegment.formatContext=
d,b.legacyContext=f,b.context=e,Q(e),m;}}function cd(a){var b=a.blockedBoundary;a=a.blockedSegment;a.status=3;dd(this,b,a);}
function ed(a,b,c){var d=a.blockedBoundary;a.blockedSegment.status=3;null===d?(b.allPendingTasks--,2!==b.status&&(b.status=2,null!==b.destination&&b.destination.close())):(d.pendingTasks--,d.forceClientRender||(d.forceClientRender=!0,a=void 0===c?Error(k(432)):c,d.errorDigest=b.onError(a),d.parentFlushed&&b.clientRenderedBoundaries.push(d)),d.fallbackAbortableTasks.forEach(function(a){return ed(a,b,c)}),d.fallbackAbortableTasks.clear(),b.allPendingTasks--,0===b.allPendingTasks&&(d=b.onAllReady,d()));}
function ad(a,b){if(0===b.chunks.length&&1===b.children.length&&null===b.children[0].boundary){var c=b.children[0];c.id=b.id;c.parentFlushed=!0;1===c.status&&ad(a,c);}else a.completedSegments.push(b);}
function dd(a,b,c){if(null===b){if(c.parentFlushed){if(null!==a.completedRootSegment)throw Error(k(389));a.completedRootSegment=c;}a.pendingRootTasks--;0===a.pendingRootTasks&&(a.onShellError=X,b=a.onShellReady,b());}else b.pendingTasks--,b.forceClientRender||(0===b.pendingTasks?(c.parentFlushed&&1===c.status&&ad(b,c),b.parentFlushed&&a.completedBoundaries.push(b),b.fallbackAbortableTasks.forEach(cd,a),b.fallbackAbortableTasks.clear()):c.parentFlushed&&1===c.status&&(ad(b,c),1===b.completedSegments.length&&
b.parentFlushed&&a.partialBoundaries.push(b)));a.allPendingTasks--;0===a.allPendingTasks&&(a=a.onAllReady,a());}
function Uc(a){if(2!==a.status){var b=O,c=Pc.current;Pc.current=Oc;var d=Nc;Nc=a.responseState;try{var f=a.pingedTasks,e;for(e=0;e<f.length;e++){var g=f[e];var h=a,m=g.blockedSegment;if(0===m.status){Q(g.context);try{Z(h,g,g.node),m.lastPushedText&&m.textEmbedded&&m.chunks.push(Ca),g.abortSet.delete(g),m.status=1,dd(h,g.blockedBoundary,m);}catch(G){if(Gc(),"object"===typeof G&&null!==G&&"function"===typeof G.then){var q=g.ping;G.then(q,q);}else {g.abortSet.delete(g);m.status=4;var r=g.blockedBoundary,
v=G,A=Y(h,v);null===r?Vc(h,v):(r.pendingTasks--,r.forceClientRender||(r.forceClientRender=!0,r.errorDigest=A,r.parentFlushed&&h.clientRenderedBoundaries.push(r)));h.allPendingTasks--;if(0===h.allPendingTasks){var F=h.onAllReady;F();}}}finally{}}}f.splice(0,e);null!==a.destination&&fd(a,a.destination);}catch(G){Y(a,G),Vc(a,G);}finally{Nc=d,Pc.current=c,c===Oc&&Q(b);}}}
function gd(a,b,c){c.parentFlushed=!0;switch(c.status){case 0:var d=c.id=a.nextSegmentId++;c.lastPushedText=!1;c.textEmbedded=!1;a=a.responseState;p(b,Va);p(b,a.placeholderPrefix);a=u(d.toString(16));p(b,a);return t(b,Wa);case 1:c.status=2;var f=!0;d=c.chunks;var e=0;c=c.children;for(var g=0;g<c.length;g++){for(f=c[g];e<f.index;e++)p(b,d[e]);f=hd(a,b,f);}for(;e<d.length-1;e++)p(b,d[e]);e<d.length&&(f=t(b,d[e]));return f;default:throw Error(k(390));}}
function hd(a,b,c){var d=c.boundary;if(null===d)return gd(a,b,c);d.parentFlushed=!0;if(d.forceClientRender)d=d.errorDigest,t(b,$a),p(b,bb),d&&(p(b,db),p(b,u(C(d))),p(b,cb)),t(b,eb),gd(a,b,c);else if(0<d.pendingTasks){d.rootSegmentID=a.nextSegmentId++;0<d.completedSegments.length&&a.partialBoundaries.push(d);var f=a.responseState;var e=f.nextSuspenseID++;f=w(f.boundaryPrefix+e.toString(16));d=d.id=f;fb(b,a.responseState,d);gd(a,b,c);}else if(d.byteSize>a.progressiveChunkSize)d.rootSegmentID=a.nextSegmentId++,
a.completedBoundaries.push(d),fb(b,a.responseState,d.id),gd(a,b,c);else {t(b,Xa);c=d.completedSegments;if(1!==c.length)throw Error(k(391));hd(a,b,c[0]);}return t(b,ab)}function id(a,b,c){Bb(b,a.responseState,c.formatContext,c.id);hd(a,b,c);return Cb(b,c.formatContext)}
function jd(a,b,c){for(var d=c.completedSegments,f=0;f<d.length;f++)kd(a,b,c,d[f]);d.length=0;a=a.responseState;d=c.id;c=c.rootSegmentID;p(b,a.startInlineScript);a.sentCompleteBoundaryFunction?p(b,Jb):(a.sentCompleteBoundaryFunction=!0,p(b,Ib));if(null===d)throw Error(k(395));c=u(c.toString(16));p(b,d);p(b,Kb);p(b,a.segmentPrefix);p(b,c);return t(b,Lb)}
function kd(a,b,c,d){if(2===d.status)return !0;var f=d.id;if(-1===f){if(-1===(d.id=c.rootSegmentID))throw Error(k(392));return id(a,b,d)}id(a,b,d);a=a.responseState;p(b,a.startInlineScript);a.sentCompleteSegmentFunction?p(b,Eb):(a.sentCompleteSegmentFunction=!0,p(b,Db));p(b,a.segmentPrefix);f=u(f.toString(16));p(b,f);p(b,Gb);p(b,a.placeholderPrefix);p(b,f);return t(b,Hb)}
function fd(a,b){l$1=new Uint8Array(512);n=0;try{var c=a.completedRootSegment;if(null!==c&&0===a.pendingRootTasks){hd(a,b,c);a.completedRootSegment=null;var d=a.responseState.bootstrapChunks;for(c=0;c<d.length-1;c++)p(b,d[c]);c<d.length&&t(b,d[c]);}var f=a.clientRenderedBoundaries,e;for(e=0;e<f.length;e++){var g=f[e];d=b;var h=a.responseState,m=g.id,q=g.errorDigest,r=g.errorMessage,v=g.errorComponentStack;p(d,h.startInlineScript);h.sentClientRenderFunction?p(d,Nb):(h.sentClientRenderFunction=!0,p(d,
Mb));if(null===m)throw Error(k(395));p(d,m);p(d,Ob);if(q||r||v)p(d,Qb),p(d,u(Sb(q||"")));if(r||v)p(d,Qb),p(d,u(Sb(r||"")));v&&(p(d,Qb),p(d,u(Sb(v))));if(!t(d,Pb));}f.splice(0,e);var A=a.completedBoundaries;for(e=0;e<A.length;e++)if(!jd(a,b,A[e]));A.splice(0,e);ba(b);l$1=new Uint8Array(512);n=0;var F=a.partialBoundaries;for(e=0;e<F.length;e++){var G=F[e];a:{f=a;g=b;var ma=G.completedSegments;for(h=0;h<ma.length;h++)if(!kd(f,
g,G,ma[h])){h++;ma.splice(0,h);var Fb=!1;break a}ma.splice(0,h);Fb=!0;}if(!Fb){a.destination=null;e++;F.splice(0,e);return}}F.splice(0,e);var na=a.completedBoundaries;for(e=0;e<na.length;e++)if(!jd(a,b,na[e]));na.splice(0,e);}finally{ba(b),0===a.allPendingTasks&&0===a.pingedTasks.length&&0===a.clientRenderedBoundaries.length&&0===a.completedBoundaries.length&&b.close();}}
function ld(a,b){try{var c=a.abortableTasks;c.forEach(function(c){return ed(c,a,b)});c.clear();null!==a.destination&&fd(a,a.destination);}catch(d){Y(a,d),Vc(a,d);}}
reactDomServer_browser_production_min.renderToReadableStream=function(a,b){return new Promise(function(c,d){var f,e,g=new Promise(function(a,b){e=a;f=b;}),h=Rc(a,za(b?b.identifierPrefix:void 0,b?b.nonce:void 0,b?b.bootstrapScriptContent:void 0,b?b.bootstrapScripts:void 0,b?b.bootstrapModules:void 0),Aa(b?b.namespaceURI:void 0),b?b.progressiveChunkSize:void 0,b?b.onError:void 0,e,function(){var a=new ReadableStream({type:"bytes",pull:function(a){if(1===h.status)h.status=2,da(a,h.fatalError);else if(2!==h.status&&null===h.destination){h.destination=
a;try{fd(h,a);}catch(A){Y(h,A),Vc(h,A);}}},cancel:function(){ld(h);}},{highWaterMark:0});a.allReady=g;c(a);},function(a){g.catch(function(){});d(a);},f);if(b&&b.signal){var m=b.signal,q=function(){ld(h,m.reason);m.removeEventListener("abort",q);};m.addEventListener("abort",q);}Uc(h);})};reactDomServer_browser_production_min.version="18.2.0";

var l, s;
{
  l = reactDomServerLegacy_browser_production_min;
  s = reactDomServer_browser_production_min;
}

server_browser.version = l.version;
server_browser.renderToString = l.renderToString;
server_browser.renderToStaticMarkup = l.renderToStaticMarkup;
server_browser.renderToNodeStream = l.renderToNodeStream;
server_browser.renderToStaticNodeStream = l.renderToStaticNodeStream;
server_browser.renderToReadableStream = s.renderToReadableStream;

const pageHeader = (styles = "") => `
    <!DOCTYPE html>
    <html lang="en">
        <head>
            <title>Apiker</title>
            <meta name="viewport" content="width=device-width, initial-scale=1">
            <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-T3c6CoIi6uLrA9TneNEoa7RxnatzjcDSCmG1MXxSR1GAsXEV/Dwwykc2MPK8M2HN" crossorigin="anonymous">
            <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined:opsz,wght,FILL,GRAD@20..48,100..700,0..1,-50..200" />
            <style>
                * {
                    --bs-primary: #2e3191;
                    --bs-dropdown-link-active-bg: #2e3191;
                }
                body {
                    margin: 0px;
                }
                .material-symbols-outlined {
                    font-variation-settings:
                    'FILL' 0,
                    'wght' 400,
                    'GRAD' 0,
                    'opsz' 24
                }
                ${styles}
            </style>
        </head>
        <body>
            <div id="app">
`;
const pageFooter = (prepend = "") => `
        </div>
        <script src="https://cdn.jsdelivr.net/npm/react@18.2.0/umd/react.production.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/react-dom@18.2.0/umd/react-dom.production.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/js/bootstrap.bundle.min.js" integrity="sha384-C6RzsynM9kWDrMNeT87bh95OGNyZPhcTNXj1NW7RuBCsyN/o0jlpcV8Qyq46cDfL" crossorigin="anonymous"></script>
        <script src="/admp/static.js"></script>
        ${prepend}
    </body>
    </html>
`;
const wrapPage = (pageContent, styles = "") => resRaw(pageHeader(styles) + pageContent + pageFooter());
const wrapReactPage = (componentName, pageComponent, props = {}, styles = "") => {
    let pageContent = server_browser.renderToString(pageComponent);
    apiker.responseHeaders.set("Content-Security-Policy", "frame-ancestors 'none';");
    apiker.responseHeaders.set("X-Frame-Options", "deny");
    return resRaw(pageHeader(styles) + pageContent + pageFooter(`
        <script>
            window.appRoot = (action, componentName, props = {}) => {
                const domNode = document.getElementById("app");
                const root = ReactDOM.createRoot(domNode);

                const componentProps = {
                    ...props
                };

                if(!window.initializeAppHelper){
                    window.initializeAppHelper = (componentName) => ({
                        setProps: (newProps) => root.render(pages[componentName](newProps))
                    });
                }

                if(action === "hydrate"){
                    pages.ReactDOM.hydrate(pages[componentName](componentProps), app);

                } else if (action === "render") {
                    root.render(pages[componentName](componentProps));
                }
            };
            window.appRoot("hydrate", "${componentName}", ${JSON.stringify(props)});
        </script>
    `));
};

const getAppHelper = (pageName) => globalThis?.initializeAppHelper?.(pageName) || {};

const Login = (props) => {
    const { isSetup, pageName = "", csrfToken = "" } = props;
    const { setProps } = getAppHelper(pageName);
    const onSubmit = () => {
        const formData = new FormData();
        Array.from(document.querySelectorAll("input")).forEach(input => {
            const key = input.getAttribute("id");
            formData.append(key, input.value);
        });
        fetch('/admp/login', {
            method: 'post',
            body: formData,
            headers: { "X-Apiker-Csrf": csrfToken }
        })
            .then(r => r.json().then(res => ({ status: r.status, body: res })))
            .then(data => {
            const { status } = data;
            const isSucessful = status === 200;
            const action = isSucessful ? undefined : props.action;
            const message = isSucessful ? "Sucess! You can now select a new action" : "Failure returned by the endpoint.";
            setProps({
                ...props,
                action,
                actions: authActions,
                dialog: { className: isSucessful ? "alert-primary" : "alert-danger", message }
            });
        })
            .catch(error => {
            setProps({
                ...props,
                dialog: { className: "alert-danger", message: error?.message }
            });
        });
    };
    return (React.createElement("div", { className: "action-wrapper" },
        isSetup && (React.createElement("div", { className: "alert alert-primary mb-0", role: "alert" }, "Welcome to Apiker! Please setup your account in order to manage your app.")),
        React.createElement("form", { className: "login-form", onSubmit: onSubmit },
            React.createElement("input", { className: "form-control form-control-lg mt-2", id: "email", type: "email", placeholder: "Email" }),
            React.createElement("input", { className: "form-control form-control-lg mt-2", id: "password", type: "password", placeholder: "Password" }),
            React.createElement("button", { className: "btn btn-primary mt-2 action-btn", type: "submit" }, isSetup ? "Setup User" : "Submit"))));
};

const Dialog = (props) => {
    const [showDialog, setShowDialog] = React.useState(false);
    const { dialog, pageName = "" } = props;
    const { className, message } = dialog || {};
    const { setProps } = getAppHelper(pageName);
    const onClose = () => {
        setProps({
            ...props,
            dialog: undefined
        });
    };
    React.useEffect(() => {
        if (dialog) {
            setShowDialog(true);
            setTimeout(() => {
                setShowDialog(false);
            }, 2000);
        }
    }, [dialog]);
    return (React.createElement("div", null,
        React.createElement("div", { className: `alert ${className} mt-0 mb-0 alert-dismissible fade ${showDialog ? "show" : ""}`, role: "alert" },
            React.createElement("strong", null, "Status:"),
            " ",
            message,
            React.createElement("button", { type: "button", className: "btn-close", onClick: onClose }))));
};

const BanUser = (props) => {
    const { pageName = "", csrfToken = "" } = props;
    const { setProps } = getAppHelper(pageName);
    const onSubmit = () => {
        const formData = new FormData();
        Array.from(document.querySelectorAll("input")).forEach(input => {
            const key = input.getAttribute("id");
            formData.append(key, input.value);
        });
        fetch('/admp/bans', {
            method: 'post',
            body: formData,
            headers: { "X-Apiker-Csrf": csrfToken }
        })
            .then(r => r.json().then(res => ({ status: r.status, body: res })))
            .then(data => {
            const { status } = data;
            const isSucessful = status === 200;
            const message = isSucessful ? "Action performed successfully" : "Failure returned by the endpoint.";
            setProps({
                ...props,
                dialog: { className: isSucessful ? "alert-primary" : "alert-danger", message }
            });
        })
            .catch(error => {
            setProps({
                ...props,
                dialog: { className: "alert-danger", message: error?.message }
            });
        });
    };
    return (React.createElement("div", { className: "action-wrapper" },
        React.createElement("form", { className: "login-form", onSubmit: onSubmit },
            React.createElement("input", { className: "form-control form-control-lg mt-2", id: "userId", type: "text", placeholder: "User ID" }),
            React.createElement("button", { className: "btn btn-primary mt-2 action-btn", type: "submit" }, "Submit"))));
};

const UnbanUser = (props) => {
    const { pageName = "", csrfToken = "" } = props;
    const { setProps } = getAppHelper(pageName);
    const onSubmit = () => {
        const formData = new FormData();
        Array.from(document.querySelectorAll("input")).forEach(input => {
            const key = input.getAttribute("id");
            formData.append(key, input.value);
        });
        fetch('/admp/bans', {
            method: 'delete',
            body: formData,
            headers: { "X-Apiker-Csrf": csrfToken }
        })
            .then(r => r.json().then(res => ({ status: r.status, body: res })))
            .then(data => {
            const { status } = data;
            const isSucessful = status === 200;
            const message = isSucessful ? "Action performed successfully" : "Failure returned by the endpoint.";
            setProps({
                ...props,
                dialog: { className: isSucessful ? "alert-primary" : "alert-danger", message }
            });
        })
            .catch(error => {
            setProps({
                ...props,
                dialog: { className: "alert-danger", message: error?.message }
            });
        });
    };
    return (React.createElement("div", { className: "action-wrapper" },
        React.createElement("form", { className: "login-form", onSubmit: onSubmit },
            React.createElement("input", { className: "form-control form-control-lg mt-2", id: "userId", type: "text", placeholder: "User ID" }),
            React.createElement("button", { className: "btn btn-primary mt-2 action-btn", type: "submit" }, "Submit"))));
};

const SearchBans = (props) => {
    const { pageName = "", csrfToken = "" } = props;
    const { setProps } = getAppHelper(pageName);
    const [results, setResults] = React.useState([]);
    const onSubmit = () => {
        const data = {};
        Array.from(document.querySelectorAll("input")).forEach(input => {
            const key = input.getAttribute("id");
            data[key] = input.value;
        });
        if (!data.userId) {
            setProps({
                ...props,
                dialog: { className: "alert-danger", message: "You must provide an user id" }
            });
        }
        fetch(`/admp/bans/${data.userId}`, {
            method: 'get',
            headers: { "X-Apiker-Csrf": csrfToken }
        })
            .then(r => r.json().then(res => ({ status: r.status, body: res })))
            .then(data => {
            const { status, body = {} } = data;
            const { entries = [] } = body;
            const isSucessful = status === 200;
            const mappedEntries = entries.map(({ time, id, clientId, countryCode, pathname, issuedBy }) => ({
                time, id, clientId, countryCode, pathname, issuedBy
            }));
            const message = isSucessful ? "Action performed successfully" : "Failure returned by the endpoint.";
            setProps({
                ...props,
                dialog: { className: isSucessful ? "alert-primary" : "alert-danger", message }
            });
            setResults(mappedEntries);
        })
            .catch(error => {
            setProps({
                ...props,
                dialog: { className: "alert-danger", message: error?.message }
            });
        });
    };
    return (React.createElement("div", { className: "action-wrapper" },
        React.createElement("form", { className: "login-form", onSubmit: onSubmit },
            React.createElement("input", { className: "form-control form-control-lg mt-2", id: "userId", type: "text", placeholder: "User ID" }),
            React.createElement("button", { className: "btn btn-primary mt-2 action-btn", type: "submit" }, "Submit")),
        (results && results.length) ? results.map(({ time, id, clientId, countryCode, pathname, issuedBy }) => (React.createElement("div", { className: "results-container" },
            React.createElement("div", { className: "results-item" },
                React.createElement("ul", null,
                    React.createElement("li", null,
                        React.createElement("span", { className: "title" }, "time"),
                        " ",
                        React.createElement("span", { className: "text", title: new Date(time).toLocaleString() }, new Date(time).toLocaleString())),
                    React.createElement("li", null,
                        React.createElement("span", { className: "title" }, "id"),
                        " ",
                        React.createElement("span", { className: "text", title: id }, id)),
                    React.createElement("li", null,
                        React.createElement("span", { className: "title" }, "clientId"),
                        " ",
                        React.createElement("span", { className: "text", title: clientId }, clientId)),
                    React.createElement("li", null,
                        React.createElement("span", { className: "title" }, "countryCode"),
                        " ",
                        React.createElement("span", { className: "text", title: countryCode }, countryCode)),
                    React.createElement("li", null,
                        React.createElement("span", { className: "title" }, "pathname"),
                        " ",
                        React.createElement("span", { className: "text", title: pathname }, pathname)),
                    React.createElement("li", null,
                        React.createElement("span", { className: "title" }, "issuedBy"),
                        " ",
                        React.createElement("span", { className: "text", title: issuedBy }, issuedBy))))))) : null));
};

const emailTemplates = {
    forgotPassword: forgotPasswordTemplate,
    verifyAccount: verifyAccountTemplate
};
const SendEmail = (props) => {
    const [template, setTemplate] = React.useState();
    const { pageName = "", csrfToken = "" } = props;
    const { setProps } = getAppHelper(pageName);
    const onDropdownItemClick = (selectedTemplate) => {
        setTemplate(selectedTemplate);
    };
    const onSubmit = () => {
        const formData = new FormData();
        if (!template) {
            return;
        }
        Array.from(document.querySelectorAll("input")).forEach(input => {
            const key = input.getAttribute("id");
            formData.append(key, input.value);
        });
        formData.append("template", template);
        fetch('/admp/email', {
            method: 'post',
            body: formData,
            headers: { "X-Apiker-Csrf": csrfToken }
        })
            .then(r => r.json().then(res => ({ status: r.status, body: res })))
            .then(data => {
            const { status } = data;
            const isSucessful = status === 200 || status === 201;
            const message = isSucessful ? "Action performed successfully" : "Failure returned by the endpoint.";
            setProps({
                ...props,
                dialog: { className: isSucessful ? "alert-primary" : "alert-danger", message }
            });
        })
            .catch(error => {
            setProps({
                ...props,
                dialog: { className: "alert-danger", message: error?.message }
            });
        });
    };
    const selectTemplateDropdown = (React.createElement("div", { className: "btn-group mt-2" },
        React.createElement("button", { className: "btn btn-transparent btn-lg dropdown-toggle action-dropdown", type: "button", id: "main-dropdown", "data-bs-toggle": "dropdown", "aria-expanded": "false" }, template ? template : "Email template"),
        React.createElement("ul", { className: "dropdown-menu", "aria-labelledby": "main-dropdown" }, Object.keys(emailTemplates).map((templateName) => {
            return (React.createElement("li", { key: templateName },
                React.createElement("a", { className: "dropdown-item", href: "#", onClick: () => onDropdownItemClick(templateName) }, templateName)));
        }))));
    return (React.createElement("div", { className: "action-wrapper" },
        React.createElement("div", { className: "alert alert-warning mb-0 mt-2", role: "alert" },
            React.createElement("b", null, "Note:"),
            " This option requires the \"email\" and \"authRoutes\" options to be enabled."),
        React.createElement("form", { className: "login-form", onSubmit: onSubmit },
            React.createElement("input", { className: "form-control form-control-lg mt-2", id: "userEmail", type: "email", placeholder: "User Email" }),
            selectTemplateDropdown,
            template ? (React.createElement("pre", { className: "m-0 mt-2" },
                React.createElement("code", null, emailTemplates[template]))) : null,
            React.createElement("button", { className: "btn btn-primary mt-2 action-btn", type: "submit" }, "Submit"))));
};

const InputGroup = ({ onButtonClick, onChange, buttonLabel, value }) => {
    React.useEffect(() => {
        const handleInputWidth = () => {
            const inputElem = document.querySelector("#input-group-1 input");
            const buttonElem = document.querySelector("#input-group-1 button");
            const offsetWidth = parseFloat(buttonElem.offsetWidth);
            inputElem.style.maxWidth = `calc(100% - ${offsetWidth}px - 15px)`;
        };
        window.addEventListener("resize", handleInputWidth);
        handleInputWidth();
    }, []);
    return (React.createElement("div", { className: "input-group mt-2", id: "input-group-1" },
        React.createElement("input", { className: "form-control form-control-lg", id: "userEmail", type: "email", placeholder: "User Email", onChange: onChange, value: value }),
        React.createElement("button", { className: "btn btn-outline-secondary", type: "button", onClick: onButtonClick }, buttonLabel)));
};
const UpdateUser = (props) => {
    const initialValue = React.useRef("");
    const [partialUser, setPartialUser] = React.useState("");
    const [userEmail, setUserEmail] = React.useState("");
    const { pageName = "", csrfToken = "" } = props;
    const { setProps } = getAppHelper(pageName);
    const onUserSeek = () => {
        console.log("onUserEmailChange", userEmail);
        fetch('/admp/user?' + new URLSearchParams({ userEmail }), {
            method: 'get',
            headers: { "X-Apiker-Csrf": csrfToken }
        })
            .then(r => r.json().then(res => ({ status: r.status, body: res })))
            .then(data => {
            const { status, body: { partialUser: bodyPartialUser } = {} } = data;
            const isSucessful = status === 200;
            if (!isSucessful) {
                setProps({
                    ...props,
                    dialog: { className: "alert-danger", message: "User not found!" }
                });
            }
            else {
                if (bodyPartialUser) {
                    const stringifiedPartialUser = JSON.stringify(bodyPartialUser);
                    trySetPartialUser(stringifiedPartialUser, (output) => {
                        initialValue.current = output;
                    });
                    setProps({
                        ...props,
                        dialog: { className: "alert-primary", message: "Action performed successfully" }
                    });
                }
                else {
                    setProps({
                        ...props,
                        dialog: { className: "alert-danger", message: "Endpoint error" }
                    });
                }
            }
            console.log(data);
        })
            .catch(error => {
            console.log(error);
        });
    };
    const onSubmit = () => {
        if (!userEmail.trim()) {
            setProps({
                ...props,
                dialog: { className: "alert-danger", message: "You must provide the user email" }
            });
            return;
        }
        if (!initialValue.current || !partialUser || (initialValue.current === partialUser)) {
            setProps({
                ...props,
                dialog: { className: "alert-danger", message: "Please fill out the fields correctly" }
            });
            return;
        }
        const formData = new FormData();
        Array.from(document.querySelectorAll("input")).forEach(input => {
            const key = input.getAttribute("id");
            formData.append(key, input.value);
        });
        formData.append("updatedUser", partialUser);
        fetch('/admp/user', {
            method: 'put',
            body: formData,
            headers: { "X-Apiker-Csrf": csrfToken }
        })
            .then(r => r.json().then(res => ({ status: r.status, body: res })))
            .then(data => {
            const { status } = data;
            const isSucessful = status === 200;
            const message = isSucessful ? "Action performed successfully" : "Failure returned by the endpoint.";
            setProps({
                ...props,
                dialog: { className: isSucessful ? "alert-primary" : "alert-danger", message }
            });
        })
            .catch(error => {
            setProps({
                ...props,
                dialog: { className: "alert-danger", message: error?.message }
            });
        });
    };
    const trySetPartialUser = (inputPartialUser, callback) => {
        let parsedValue;
        try {
            parsedValue = JSON.parse(inputPartialUser);
        }
        catch (e) { }
        if (parsedValue) {
            const stringifiedPartialUser = JSON.stringify(parsedValue);
            setPartialUser(stringifiedPartialUser);
            if (callback) {
                callback(stringifiedPartialUser);
            }
        }
    };
    console.log("partialUser", partialUser);
    return (React.createElement("div", { className: "action-wrapper" },
        React.createElement("form", { className: "login-form", onSubmit: onSubmit },
            React.createElement(InputGroup, { value: userEmail, onButtonClick: onUserSeek, onChange: e => setUserEmail(e.target.value), buttonLabel: "Find" }),
            partialUser ? (React.createElement("textarea", { className: "m-0 mt-2", onChange: e => trySetPartialUser(e.target.value), value: JSON.stringify(JSON.parse(partialUser), null, 2) })) : null,
            React.createElement("button", { className: "btn btn-primary mt-2 action-btn", type: "submit" }, "Submit"))));
};

const DeleteUser = (props) => {
    const [shouldAskConfirm, setShouldAskConfirm] = React.useState(false);
    const [isConfirmed, setIsConfirmed] = React.useState(false);
    const { pageName = "", csrfToken = "" } = props;
    const { setProps } = getAppHelper(pageName);
    const onSubmit = () => {
        const userEmail = document.getElementById("userEmail")?.value;
        if (!userEmail.trim()) {
            setProps({
                ...props,
                dialog: { className: "alert-danger", message: "You must provide the user email" }
            });
            return;
        }
        if (!shouldAskConfirm || !isConfirmed) {
            setShouldAskConfirm(true);
            return;
        }
        const formData = new FormData();
        Array.from(document.querySelectorAll("input")).forEach(input => {
            const key = input.getAttribute("id");
            formData.append(key, input.value);
        });
        fetch('/admp/user', {
            method: 'delete',
            body: formData,
            headers: { "X-Apiker-Csrf": csrfToken }
        })
            .then(r => r.json().then(res => ({ status: r.status, body: res })))
            .then(data => {
            const { status } = data;
            const isSucessful = status === 200;
            const message = isSucessful ? "Action performed successfully" : "Failure returned by the endpoint.";
            setProps({
                ...props,
                dialog: { className: isSucessful ? "alert-primary" : "alert-danger", message }
            });
        })
            .catch(error => {
            setProps({
                ...props,
                dialog: { className: "alert-danger", message: error?.message }
            });
        });
    };
    return (React.createElement("div", { className: "action-wrapper" },
        React.createElement("form", { className: "login-form", onSubmit: onSubmit },
            React.createElement("input", { className: "form-control form-control-lg mt-2", id: "userEmail", type: "text", placeholder: "User Email" }),
            (isConfirmed || !shouldAskConfirm) ? (React.createElement("button", { className: "btn btn-primary mt-2 action-btn", type: "submit" }, "Submit")) : (React.createElement("button", { className: "btn btn-danger mt-2 action-btn", type: "button", onClick: () => { setIsConfirmed(true); } }, "Are you sure? This cannot be undone")))));
};

//@ts-ignore
const adminPanelPage = async ({ state }) => {
    const pageName = "AdminPanelPage";
    const adminIds = await state(OBN.COMMON).get("adminIds");
    const hasAdmins = !!adminIds?.length;
    const user = await getCurrentUser();
    const isAdminLoggedIn = user?.role === "admin";
    const csrfToken = createJWT({ sub: user?.id, pageName }, 60);
    const userSignedIp = isAdminLoggedIn ? getSignedIp() : undefined;
    const props = { isSetup: !hasAdmins, pageName, csrfToken, isAdminLoggedIn, userSignedIp };
    return wrapReactPage('AdminPanelPage', React.createElement(AdminPanelPage, { ...props }), props, css);
};
const actionsComponent = {
    login: Login,
    banUser: BanUser,
    unbanUser: UnbanUser,
    searchBans: SearchBans,
    sendEmail: SendEmail,
    updateUser: UpdateUser,
    deleteUser: DeleteUser
};
const AdminPanelPage = (props) => {
    let { userSignedIp, isAdminLoggedIn, action, actions = defaultActions, dialog, pageName = "" } = props;
    const { setProps } = getAppHelper(pageName);
    let ActionComponent = action ? actionsComponent[action.id] : null;
    if (isAdminLoggedIn) {
        actions = authActions;
    }
    const onDropdownItemClick = (action) => {
        setProps({ ...props, action, dialog: undefined });
    };
    const actionDropdown = (React.createElement("div", { className: "btn-group" },
        React.createElement("button", { className: "btn btn-transparent btn-lg dropdown-toggle action-dropdown", type: "button", id: "main-dropdown", "data-bs-toggle": "dropdown", "aria-expanded": "false" }, action ? action.displayName : "Select action"),
        React.createElement("ul", { className: "dropdown-menu", "aria-labelledby": "main-dropdown" }, actions.map((currentAction) => {
            const { id, displayName } = currentAction;
            return (React.createElement("li", { key: id },
                React.createElement("a", { className: "dropdown-item", href: "#", onClick: () => onDropdownItemClick(currentAction) }, displayName)));
        }))));
    return (React.createElement(React.Fragment, null,
        React.createElement(Header, null, dialog && React.createElement(Dialog, { ...props })),
        React.createElement(Content, null,
            actionDropdown,
            ActionComponent && React.createElement(ActionComponent, { ...props }),
            userSignedIp && React.createElement("div", { className: "signed-ip" },
                "Your ID: ",
                userSignedIp))));
};

const GEOLOCATION_ENDPOINT = "http://ip-api.com/json/";

const getCurrentUserGeodata = () => {
    const { headers } = apiker.requestParams;
    const ip = headers.get("CF-Connecting-IP");
    return getUserGeodata(ip);
};
const getUserGeodata = (ip) => {
    if (!ip)
        return Promise.resolve({});
    return fetch(GEOLOCATION_ENDPOINT + ip).then(res => res.json());
};

const adminCsrfCheckMiddleware = async (params, handlerFn) => {
    const { headers } = apiker.requestParams;
    const csrfToken = headers.get("X-Apiker-Csrf");
    const parsedCsrfToken = parseJWT(csrfToken);
    if (!csrfToken || !parsedCsrfToken) {
        return res_401();
    }
    if (parsedCsrfToken.sub) {
        const user = await getCurrentUser();
        if (user?.id !== parsedCsrfToken.sub) {
            return res_401();
        }
    }
    if (handlerFn) {
        return handlerFn(params);
    }
};
const adminWhitelistMiddleware = async (params, handlerFn) => {
    if (apiker.env.ADMP_IP_WHITELIST || apiker.env.ADMP_ISP_WHITELIST || apiker.env.ADMP_CITY_WHITELIST) {
        const { headers } = apiker.requestParams;
        const ip = headers.get("CF-Connecting-IP");
        const userGeoloc = await getCurrentUserGeodata();
        if (apiker.env.ADMP_IP_WHITELIST && ip !== apiker.env.ADMP_IP_WHITELIST) {
            return res_401();
        }
        if (apiker.env.ADMP_ISP_WHITELIST && userGeoloc.isp !== apiker.env.ADMP_ISP_WHITELIST) {
            return res_401();
        }
        if (apiker.env.ADMP_CITY_WHITELIST && userGeoloc.city !== apiker.env.ADMP_CITY_WHITELIST) {
            return res_401();
        }
    }
    if (handlerFn) {
        return handlerFn(params);
    }
};
const adminMiddleware = async (params, handlerFn = () => res_204()) => {
    return forwardToMiddleware(params, [
        adminCsrfCheckMiddleware,
        adminWhitelistMiddleware,
        handlerFn
    ]);
};

/**
 * Responses
 */
const getAdminRoutes = () => ({
    // Entry endpoints under global ratelimit
    "/admp": adminPanelPage,
    "/admp/static.js": adminPanelStatic,
    // Login endpoint only checks for CSRF
    "/admp/login": (params) => adminCsrfCheckMiddleware(params, loginEndpoint),
    // Check for admin logged in and CSRF
    "/admp/bans": (params) => adminMiddleware(params, bansEndpoint),
    "/admp/bans/:userId": (params) => adminMiddleware(params, searchBansEndpoint),
    "/admp/email": (params) => adminMiddleware(params, sendEmailEndpoint),
    "/admp/user": (params) => adminMiddleware(params, updateUserEndpoint),
});
const adminPanelStatic = () => {
    return resRaw(apikerPagesStatic, "text/javascript");
};

class ResponseParams {
    errors = [];
    /**
     * Sets an error response
     */
    setError = (errorMessage) => {
        this.errors.push(errorMessage);
    };
    /**
     * Gets the last error response
     */
    getLastError = () => {
        return this.errors.length ?
            [...this.errors].pop()
            : null;
    };
}

/**
 * Apiker class definition.
 * ⚠️ Please do not instantiate this class and use the "apiker" exported instance instead.
 */
class Apiker {
    name = "Apiker";
    routes = {};
    controllers = {};
    debug = false;
    objectVersion = "V1";
    objects;
    objectStateMapping;
    authRoutes;
    env;
    requestParams;
    responseParams = new ResponseParams();
    responseHeaders;
    firewall;
    adminPanel;
    email;
    timings = {};
    defaultObjectName = "Common";
    /**
     * Initialize Apiker, perform basic validation
     */
    init = (options = {}) => {
        try {
            /**
             * Extract options
             */
            const { routes, controllers = {}, objects, exports, firewall, adminPanel = false, authRoutes = false, name = "Apiker", email, debug } = options;
            /**
             * Apply defaults to objectStateMapping
             */
            const objectStateMapping = {
                CounterUser: OBMT.SIGNEDIP,
                RateLimit: OBMT.SIGNEDIP,
                Logs: OBMT.SIGNEDIP,
                Bans: "userId",
                ...(options.objectStateMapping || {})
            };
            /**
             * Check for required params
             */
            if (!(routes && objects && exports)) {
                throw new Error("Missing required parameters, please consult the Apiker documentation");
            }
            /**
             * Assign options
             */
            this.setProps({ routes, controllers, objects, authRoutes, adminPanel, firewall, name, email, debug, objectStateMapping });
            /**
             * If authRoutes option is set to true, set auth routes
             */
            if (authRoutes) {
                this.routes = {
                    ...getAuthRoutes(),
                    ...this.routes
                };
            }
            /**
             * If adminPanel option is set to true, set admin panel routes
             */
            if (adminPanel) {
                this.routes = {
                    ...getAdminRoutes(),
                    ...this.routes
                };
            }
            /**
             * Prepare worker exports
             */
            const workerExports = {
                handlers: {
                    fetch: handleEntryRequest
                }
            };
            /**
             * Adding named objects to exports
             */
            this.objects.forEach((objectName) => {
                workerExports[objectName] = this.getObjectClassDefinition(objectName);
            });
            Object.assign(exports, workerExports);
        }
        catch (e) {
            return new Response(e.message);
        }
    };
    /**
     * Set options
     */
    setProps = (options = {}) => {
        Object.assign(this, options);
    };
    /**
     * Creates a durable object class definition
     */
    getObjectClassDefinition = (objectName) => {
        return ({ [objectName]: class extends ObjectBase {
            } })[objectName];
    };
}
/**
 * Instance of the Apiker class
 */
const apiker = new Apiker();

export { Apiker, EMAIL_API_ENDPOINT, FIREWALL_ENDPOINT, FIREWALL_RATELIMIT_PREFIX, FIREWALL_REQUESTS_MINUTE, MAX_STR_LEN, MIN_STR_LEN, OBMT, OBN, RESPONSE_HEADERS_DEFAULT, RESPONSE_MESSAGES, ResponseParams, addLogEntry, addUniqueLogEntry, apiker, banEntity, checkUser, compare_bcrypt, createJWT, decodeString, deleteAllLogsInObject, deleteAllObjectState, deleteLogEntries, deleteObjectState, deleteUserLogEntries, elapsedSinceRequestStart, encodeString, extractToken, firewallBanIP, firewallMiddleware, firewallUnbanIP, forgotPasswordTemplate, forgotUser, forgotUserAction, forgotUserReset, forwardToMiddleware, getAllLogEntries, getAuthRoutes, getBannedEntities, getBannedEntries, getClientId, getCurrentUser, getCurrentUserGeodata, getEnvObject, getFirewallBannedEntryId, getLogEntries, getLogParams, getObjectState, getRawIp, getSignedIp, getStateMethods, getTokens, getUserGeodata, getUserLogEntries, getUserLogPropertyName, handleEntryRequest, hash_bcrypt, isCurrentUserAdmin, isEmail, isEntityBanned, isRateLimitReached, isRequiredLength, isUserAdmin, listObjectState, loginUser, loginUserAction, measureTiming, newPasswordTemplate, pageFooter, pageHeader, parseJWT, parseObjectStateMapping, putObjectState, randomHash, randomHash_SHA1, rateLimitRequest, readRequestBody, refreshUser, registerUser, registerUserAction, res, resRaw, res_200, res_204, res_400, res_401, res_404, res_429, res_500, sendEmail, sign, sign_sha1, sign_sha256, unbanEntity, verifyAccountSuccessTemplate, verifyAccountTemplate, wrapPage, wrapReactPage };
